@@ -231,7 +231,7 @@ class Bake:
     def resolve_contrib_dependencies (self, module, fmod, configuration):
         """ Handles the contrib type dependencies"""
         for dep in module.dependencies ():
-            dep_mod = configuration.lookup (dep.name())
+            dep_mod = configuration.lookup (dep._name)
             if dep_mod.mtype() == "ns-contrib":
                 # Do not prepend contrib prefix to user supplied contrib name more than once
                 if not(module.get_source().attribute("module_directory").value.startswith(fmod + '/contrib')):
@@ -679,14 +679,14 @@ class Bake:
             deps.add_dst(m, wrapper.function)
         # Review the dependencies of all the configured modules
         for m in configuration.modules():
-            for dependency in m.dependencies():
-                src = configuration.lookup (dependency.name())
+            for dependency in m.dependencies():                
+                src = configuration.lookup (dependency._name)
                 
                 # verifies if the dependency really exists in the configuration
                 # if not we could have a problem of a corrupt, or badly 
                 # configured xml file, e.g. misspelled module name  
                 if src is None:
-                    self._error('Dependency "%s" not found' % dependency.name())
+                    self._error('Dependency "%s" not found' % dependency._name)
                  
                 if not src in configuration.disabled():
                     # if it is set to add even the optional modules, or the 
@@ -1376,8 +1376,8 @@ class Bake:
                 print('  depends on:')
                 for dependsOn in mod.dependencies():
                     print('     %s (optional:%s)' % 
-                          (dependsOn.name(), dependsOn.is_optional())) 
-                    depen[mod.name()][dependsOn.name()]=  dependsOn.is_optional()
+                          (dependsOn._name, dependsOn.is_optional())) 
+                    depen[mod.name()][dependsOn._name]=  dependsOn.is_optional()
             elif not options.brief == True:
                 print('  No dependencies!')
                 
