@@ -167,11 +167,11 @@ main (int argc, char *argv[])
     {
       wifi.EnableLogComponents ();
     }
-  wifi.SetStandard (WIFI_PHY_STANDARD_80211b);
+  wifi.SetStandard (WIFI_STANDARD_80211b);
 
   /** Wifi PHY **/
   /***************************************************************************/
-  YansWifiPhyHelper wifiPhy = YansWifiPhyHelper::Default ();
+  YansWifiPhyHelper wifiPhy;
 
   /** wifi channel **/
   YansWifiChannelHelper wifiChannel;
