@@ -42,7 +42,7 @@ main (int argc, char *argv[])
 
   // Allow the user to override any of the defaults and the above
   // DefaultValue::Bind ()s at run-time, via command-line arguments
-  CommandLine cmd;
+  CommandLine cmd (__FILE__);
   cmd.Parse (argc, argv);
 
   Ptr<Node> nA = CreateObject<Node> ();
