@@ -9,6 +9,9 @@
 # See test.py for more information.
 cpp_examples = [
     ("traffic-control", "True", "True"),
+    ("red-vs-nlred", "True", "True"),
+    ("red-vs-fengadaptive", "True", "True"),
+    ("queue-discs-benchmark --simDuration=10", "True", "True"),
 ]
 
 # A list of Python examples to run in order to ensure that they remain
