@@ -139,7 +139,7 @@ main (int argc, char *argv[])
   NodeContainer wifiApNodes;
   wifiApNodes.Create (2);
 
-  SpectrumWifiPhyHelper spectrumPhy = SpectrumWifiPhyHelper::Default ();
+  SpectrumWifiPhyHelper spectrumPhy;
   Ptr<MultiModelSpectrumChannel> spectrumChannel = CreateObject<MultiModelSpectrumChannel> ();
   Ptr<FriisPropagationLossModel> lossModel = CreateObject<FriisPropagationLossModel> ();
   spectrumChannel->AddPropagationLossModel (lossModel);
@@ -153,7 +153,7 @@ main (int argc, char *argv[])
   //TODO: add parameter to configure CCA-PD
 
   WifiHelper wifi;
-  wifi.SetStandard (WIFI_PHY_STANDARD_80211ax_5GHZ);
+  wifi.SetStandard (WIFI_STANDARD_80211ax_5GHZ);
   if (enableObssPd)
     {
       wifi.SetObssPdAlgorithm ("ns3::ConstantObssPdAlgorithm",
