@@ -20,11 +20,13 @@
 
 
 #include <ns3/log.h>
+#include <ns3/double.h>
 
 #include "antenna-model.h"
 #include "isotropic-antenna-model.h"
 
 
+
 namespace ns3 {
 
 NS_LOG_COMPONENT_DEFINE ("IsotropicAntennaModel");
@@ -39,6 +41,11 @@ IsotropicAntennaModel::GetTypeId ()
     .SetParent<AntennaModel> ()
     .SetGroupName("Antenna")
     .AddConstructor<IsotropicAntennaModel> ()
+    .AddAttribute ("Gain",
+                   "The gain of the antenna in dB",
+                   DoubleValue (0),
+                   MakeDoubleAccessor (&IsotropicAntennaModel::m_gainDb),
+                   MakeDoubleChecker<double> ())
   ;
   return tid;
 }
@@ -52,7 +59,7 @@ double
 IsotropicAntennaModel::GetGainDb (Angles a)
 {
   NS_LOG_FUNCTION (this << a);
-  return 0.0;
+  return m_gainDb;
 }
 
 }
