@@ -151,8 +151,13 @@ private:
   void ConnectionFailed (Ptr<Socket> socket);
   /**
    * \brief Send more data as soon as some has been transmitted.
+   *
+   * Used in socket's SetSendCallback - params are forced by it.
+   *
+   * \param socket socket to use
+   * \param unused actually unused
    */
-  void DataSend (Ptr<Socket>, uint32_t); // for socket's SetSendCallback
+  void DataSend (Ptr<Socket> socket, uint32_t unused);
 };
 
 } // namespace ns3
