@@ -741,7 +741,7 @@ ThreeGppHttpClient::EnterParsingTime ()
       const Time parsingTime = m_httpVariables->GetParsingTime ();
       NS_LOG_INFO (this << " The parsing of this main object"
                         << " will complete in "
-                        << parsingTime.GetSeconds () << " seconds.");
+                        << parsingTime.As (Time::S) << ".");
       m_eventParseMainObject = Simulator::Schedule (
           parsingTime, &ThreeGppHttpClient::ParseMainObject, this);
       SwitchToState (PARSING_MAIN_OBJECT);
@@ -804,7 +804,7 @@ ThreeGppHttpClient::EnterReadingTime ()
     {
       const Time readingTime = m_httpVariables->GetReadingTime ();
       NS_LOG_INFO (this << " Client will finish reading this web page in "
-                        << readingTime.GetSeconds () << " seconds.");
+                        << readingTime.As (Time::S) << ".");
 
       // Schedule a request of another main object once the reading time expires.
       m_eventRequestMainObject = Simulator::Schedule (
@@ -827,24 +827,24 @@ ThreeGppHttpClient::CancelAllPendingEvents ()
   if (!Simulator::IsExpired (m_eventRequestMainObject))
     {
       NS_LOG_INFO (this << " Canceling RequestMainObject() which is due in "
-                        << Simulator::GetDelayLeft (m_eventRequestMainObject).GetSeconds ()
-                        << " seconds.");
+                        << Simulator::GetDelayLeft (m_eventRequestMainObject).As (Time::S)
+                        << ".");
       Simulator::Cancel (m_eventRequestMainObject);
     }
 
   if (!Simulator::IsExpired (m_eventRequestEmbeddedObject))
     {
       NS_LOG_INFO (this << " Canceling RequestEmbeddedObject() which is due in "
-                        << Simulator::GetDelayLeft (m_eventRequestEmbeddedObject).GetSeconds ()
-                        << " seconds.");
+                        << Simulator::GetDelayLeft (m_eventRequestEmbeddedObject).As (Time::S)
+                        << ".");
       Simulator::Cancel (m_eventRequestEmbeddedObject);
     }
 
   if (!Simulator::IsExpired (m_eventParseMainObject))
     {
       NS_LOG_INFO (this << " Canceling ParseMainObject() which is due in "
-                        << Simulator::GetDelayLeft (m_eventParseMainObject).GetSeconds ()
-                        << " seconds.");
+                        << Simulator::GetDelayLeft (m_eventParseMainObject).As (Time::S)
+                        << ".");
       Simulator::Cancel (m_eventParseMainObject);
     }
 }
