@@ -77,6 +77,7 @@ UdpClient::UdpClient ()
 {
   NS_LOG_FUNCTION (this);
   m_sent = 0;
+  m_totalTx = 0;
   m_socket = 0;
   m_sendEvent = EventId ();
 }
@@ -155,6 +156,27 @@ UdpClient::StartApplication (void)
         }
     }
 
+#ifdef NS3_LOG_ENABLE
+  std::stringstream peerAddressStringStream;
+  if (Ipv4Address::IsMatchingType (m_peerAddress))
+    {
+      peerAddressStringStream << Ipv4Address::ConvertFrom (m_peerAddress);
+    }
+  else if (Ipv6Address::IsMatchingType (m_peerAddress))
+    {
+      peerAddressStringStream << Ipv6Address::ConvertFrom (m_peerAddress);
+    }
+  else if (InetSocketAddress::IsMatchingType (m_peerAddress))
+    {
+      peerAddressStringStream << InetSocketAddress::ConvertFrom (m_peerAddress).GetIpv4 ();
+    }
+  else if (Inet6SocketAddress::IsMatchingType (m_peerAddress))
+    {
+      peerAddressStringStream << Inet6SocketAddress::ConvertFrom (m_peerAddress).GetIpv6 ();
+    }
+  m_peerAddressString = peerAddressStringStream.str();
+#endif // NS3_LOG_ENABLE
+
   m_socket->SetRecvCallback (MakeNullCallback<void, Ptr<Socket> > ());
   m_socket->SetAllowBroadcast (true);
   m_sendEvent = Simulator::Schedule (Seconds (0.0), &UdpClient::Send, this);
@@ -177,30 +199,24 @@ UdpClient::Send (void)
   Ptr<Packet> p = Create<Packet> (m_size-(8+4)); // 8+4 : the size of the seqTs header
   p->AddHeader (seqTs);
 
-  std::stringstream peerAddressStringStream;
-  if (Ipv4Address::IsMatchingType (m_peerAddress))
-    {
-      peerAddressStringStream << Ipv4Address::ConvertFrom (m_peerAddress);
-    }
-  else if (Ipv6Address::IsMatchingType (m_peerAddress))
-    {
-      peerAddressStringStream << Ipv6Address::ConvertFrom (m_peerAddress);
-    }
-
   if ((m_socket->Send (p)) >= 0)
     {
       ++m_sent;
-      NS_LOG_INFO ("TraceDelay TX " << m_size << " bytes to "
-                                    << peerAddressStringStream.str () << " Uid: "
+      m_totalTx += p->GetSize ();
+#ifdef NS3_LOG_ENABLE
+    NS_LOG_INFO ("TraceDelay TX " << m_size << " bytes to "
+                                    << m_peerAddressString << " Uid: "
                                     << p->GetUid () << " Time: "
-                                    << (Simulator::Now ()).GetSeconds ());
-
+                                    << (Simulator::Now ()).As (Time::S));
+#endif // NS3_LOG_ENABLE
     }
+#ifdef NS3_LOG_ENABLE
   else
     {
       NS_LOG_INFO ("Error while sending " << m_size << " bytes to "
-                                          << peerAddressStringStream.str ());
+                                          << m_peerAddressString);
     }
+#endif // NS3_LOG_ENABLE
 
   if (m_sent < m_count)
     {
@@ -208,4 +224,12 @@ UdpClient::Send (void)
     }
 }
 
+
+uint64_t
+UdpClient::GetTotalTx () const
+{
+  return m_totalTx;
+}
+
+
 } // Namespace ns3
