@@ -559,6 +559,7 @@ Ipv4ClickRouting::RouteInput  (Ptr<const Packet> p, const Ipv4Header &header,
 void
 Ipv4ClickRouting::PrintRoutingTable (Ptr<OutputStreamWrapper> stream, Time::Unit unit) const
 {
+  *stream->GetStream () << "\nCLICK Routing table printing is not yet implemented, skipping.\n";
 }
 
 void
@@ -609,7 +610,7 @@ int simclick_sim_send (simclick_node_t *simnode,
                        int ifid, int type, const unsigned char* data, int len,
                        simclick_simpacketinfo *pinfo)
 {
-  NS_LOG_DEBUG ("simclick_sim_send called at " << ns3::Simulator::Now ().GetSeconds () << ": " << ifid << " " << type << " " << data << " " << len);
+  NS_LOG_DEBUG ("simclick_sim_send called at " << ns3::Simulator::Now ().As (ns3::Time::S) << ": " << ifid << " " << type << " " << data << " " << len);
 
   if (simnode == NULL)
     {
