@@ -26,6 +26,12 @@ FileConfig::~FileConfig ()
 {
 }
 
+void
+FileConfig::SetSaveDeprecated (bool saveDeprecated)
+{
+  m_saveDeprecated = saveDeprecated;
+}
+
 NoneFileConfig::NoneFileConfig ()
 {
 }
