@@ -30,7 +30,7 @@
  * \deprecated This method will go away in future versions of ns-3.
  * See instead TheNewWay()
  */
-NS_DEPRECATED
+NS_DEPRECATED_3_XX
 void SomethingUseful (void);
 /*
  * Do something more useful.
