@@ -37,22 +37,26 @@
 using namespace ns3;
 
 namespace {
-  
+
 /**
  * Round a double number to the given precision.
- * For example, `dround(0.234, 0.1) = 0.2` 
+ * For example, `dround(0.234, 0.1) = 0.2`
  * and `dround(0.257, 0.1) = 0.3`
  * \param [in] number The number to round.
  * \param [in] precision The least significant digit to keep in the rounding.
- * \returns \p number rounded to \p precision.
+ * \returns \pname{number} rounded to \pname{precision}.
  */
 double dround (double number, double precision)
 {
   number /= precision;
   if (number >= 0)
-    number = std::floor (number + 0.5);
+    {
+      number = std::floor (number + 0.5);
+    }
   else
-    number = std::ceil (number - 0.5);
+    {
+      number = std::ceil (number - 0.5);
+    }
   number *= precision;
   return number;
 }
@@ -68,13 +72,13 @@ double dround (double number, double precision)
  */
 static GnuplotDataset
 Histogram (Ptr<RandomVariableStream> rndvar,
-            unsigned int probes, double precision,
-            const std::string& title, bool impulses = false)
+           unsigned int probes, double precision,
+           const std::string& title, bool impulses = false)
 {
   typedef std::map<double, unsigned int> histogram_maptype;
   histogram_maptype histogram;
 
-  for(unsigned int i = 0; i < probes; ++i)
+  for (unsigned int i = 0; i < probes; ++i)
     {
       double val = dround ( rndvar->GetValue (), precision );
 
@@ -89,8 +93,8 @@ Histogram (Ptr<RandomVariableStream> rndvar,
       data.SetStyle (Gnuplot2dDataset::IMPULSES);
     }
 
-  for(histogram_maptype::const_iterator hi = histogram.begin ();
-      hi != histogram.end (); ++hi)
+  for (histogram_maptype::const_iterator hi = histogram.begin ();
+       hi != histogram.end (); ++hi)
     {
       data.Add (hi->first, (double)hi->second / (double)probes / precision);
     }
@@ -103,9 +107,9 @@ Histogram (Ptr<RandomVariableStream> rndvar,
 
 int main (int argc, char *argv[])
 {
-  CommandLine cmd;
-  cmd.Parse(argc, argv);
-  
+  CommandLine cmd (__FILE__);
+  cmd.Parse (argc, argv);
+
   unsigned int probes = 1000000;
   double precision = 0.01;
 
@@ -122,7 +126,7 @@ int main (int argc, char *argv[])
     x->SetAttribute ("Max", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x, probes, precision,
-                                  "UniformRandomVariable [0.0 .. 1.0)") );
+                                 "UniformRandomVariable [0.0 .. 1.0)") );
     plot.AddDataset ( Gnuplot2dFunction ("1.0",
                                          "0 <= x && x <= 1 ? 1.0 : 0") );
 
@@ -139,7 +143,7 @@ int main (int argc, char *argv[])
     x1->SetAttribute ("Mean", DoubleValue (0.5));
 
     plot.AddDataset ( Histogram (x1, probes, precision,
-                                  "ExponentialRandomVariable m=0.5") );
+                                 "ExponentialRandomVariable m=0.5") );
 
     plot.AddDataset ( Gnuplot2dFunction ("ExponentialDistribution mean 0.5",
                                          "ExpDist(x, 0.5)") );
@@ -148,7 +152,7 @@ int main (int argc, char *argv[])
     x2->SetAttribute ("Mean", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x2, probes, precision,
-                                  "ExponentialRandomVariable m=1") );
+                                 "ExponentialRandomVariable m=1") );
 
     plot.AddDataset ( Gnuplot2dFunction ("ExponentialDistribution mean 1.0",
                                          "ExpDist(x, 1.0)") );
@@ -157,7 +161,7 @@ int main (int argc, char *argv[])
     x3->SetAttribute ("Mean", DoubleValue (1.5));
 
     plot.AddDataset ( Histogram (x3, probes, precision,
-                                  "ExponentialRandomVariable m=1.5") );
+                                 "ExponentialRandomVariable m=1.5") );
 
     plot.AddDataset ( Gnuplot2dFunction ("ExponentialDistribution mean 1.5",
                                          "ExpDist(x, 1.5)") );
@@ -175,21 +179,21 @@ int main (int argc, char *argv[])
     x1->SetAttribute ("Shape", DoubleValue (1.5));
 
     plot.AddDataset ( Histogram (x1, probes, precision,
-                                  "ParetoRandomVariable scale=1.0 shape=1.5") );
+                                 "ParetoRandomVariable scale=1.0 shape=1.5") );
 
     Ptr<ParetoRandomVariable> x2 = CreateObject<ParetoRandomVariable> ();
     x2->SetAttribute ("Scale", DoubleValue (1.0));
     x2->SetAttribute ("Shape", DoubleValue (2.0));
 
     plot.AddDataset ( Histogram (x2, probes, precision,
-                                  "ParetoRandomVariable scale=1.0 shape=2.0") );
+                                 "ParetoRandomVariable scale=1.0 shape=2.0") );
 
     Ptr<ParetoRandomVariable> x3 = CreateObject<ParetoRandomVariable> ();
     x3->SetAttribute ("Scale", DoubleValue (1.0));
     x3->SetAttribute ("Shape", DoubleValue (2.5));
 
     plot.AddDataset ( Histogram (x3, probes, precision,
-                                  "ParetoRandomVariable scale=1.0 shape=2.5") );
+                                 "ParetoRandomVariable scale=1.0 shape=2.5") );
 
     gnuplots.AddPlot (plot);
   }
@@ -204,21 +208,21 @@ int main (int argc, char *argv[])
     x1->SetAttribute ("Shape", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x1, probes, precision,
-                                  "WeibullRandomVariable scale=1.0 shape=1.0") );
+                                 "WeibullRandomVariable scale=1.0 shape=1.0") );
 
     Ptr<WeibullRandomVariable> x2 = CreateObject<WeibullRandomVariable> ();
     x2->SetAttribute ("Scale", DoubleValue (1.0));
     x2->SetAttribute ("Shape", DoubleValue (2.0));
 
     plot.AddDataset ( Histogram (x2, probes, precision,
-                                  "WeibullRandomVariable scale=1.0 shape=2.0") );
+                                 "WeibullRandomVariable scale=1.0 shape=2.0") );
 
     Ptr<WeibullRandomVariable> x3 = CreateObject<WeibullRandomVariable> ();
     x3->SetAttribute ("Scale", DoubleValue (1.0));
     x3->SetAttribute ("Shape", DoubleValue (3.0));
 
     plot.AddDataset ( Histogram (x3, probes, precision,
-                                  "WeibullRandomVariable scale=1.0 shape=3.0") );
+                                 "WeibullRandomVariable scale=1.0 shape=3.0") );
 
     gnuplots.AddPlot (plot);
   }
@@ -234,7 +238,7 @@ int main (int argc, char *argv[])
     x1->SetAttribute ("Variance", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x1, probes, precision,
-                                  "NormalRandomVariable m=0.0 v=1.0") );
+                                 "NormalRandomVariable m=0.0 v=1.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("NormalDist {/Symbol m}=0.0 {/Symbol s}=1.0",
                                          "NormalDist(x,0.0,1.0)") );
@@ -244,7 +248,7 @@ int main (int argc, char *argv[])
     x2->SetAttribute ("Variance", DoubleValue (2.0));
 
     plot.AddDataset ( Histogram (x2, probes, precision,
-                                  "NormalRandomVariable m=0.0 v=2.0") );
+                                 "NormalRandomVariable m=0.0 v=2.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("NormalDist {/Symbol m}=0.0 {/Symbol s}=sqrt(2.0)",
                                          "NormalDist(x,0.0,sqrt(2.0))") );
@@ -254,7 +258,7 @@ int main (int argc, char *argv[])
     x3->SetAttribute ("Variance", DoubleValue (3.0));
 
     plot.AddDataset ( Histogram (x3, probes, precision,
-                                  "NormalRandomVariable m=0.0 v=3.0") );
+                                 "NormalRandomVariable m=0.0 v=3.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("NormalDist {/Symbol m}=0.0 {/Symbol s}=sqrt(3.0)",
                                          "NormalDist(x,0.0,sqrt(3.0))") );
@@ -313,7 +317,7 @@ int main (int argc, char *argv[])
     x1->SetAttribute ("Sigma", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x1, probes, precision,
-                                  "LogNormalRandomVariable m=0.0 s=1.0") );
+                                 "LogNormalRandomVariable m=0.0 s=1.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("LogNormalDist(x, 0.0, 1.0)",
                                          "LogNormalDist(x, 0.0, 1.0)") );
@@ -323,14 +327,14 @@ int main (int argc, char *argv[])
     x2->SetAttribute ("Sigma", DoubleValue (0.5));
 
     plot.AddDataset ( Histogram (x2, probes, precision,
-                                  "LogNormalRandomVariable m=0.0 s=0.5") );
+                                 "LogNormalRandomVariable m=0.0 s=0.5") );
 
     Ptr<LogNormalRandomVariable> x3 = CreateObject<LogNormalRandomVariable> ();
     x3->SetAttribute ("Mu", DoubleValue (0.0));
     x3->SetAttribute ("Sigma", DoubleValue (0.25));
 
     plot.AddDataset ( Histogram (x3, probes, precision,
-                                  "LogNormalRandomVariable m=0.0 s=0.25") );
+                                 "LogNormalRandomVariable m=0.0 s=0.25") );
 
     plot.AddDataset ( Gnuplot2dFunction ("LogNormalDist(x, 0.0, 0.25)",
                                          "LogNormalDist(x, 0.0, 0.25)") );
@@ -340,14 +344,14 @@ int main (int argc, char *argv[])
     x4->SetAttribute ("Sigma", DoubleValue (0.125));
 
     plot.AddDataset ( Histogram (x4, probes, precision,
-                                  "LogNormalRandomVariable m=0.0 s=0.125") );
+                                 "LogNormalRandomVariable m=0.0 s=0.125") );
 
     Ptr<LogNormalRandomVariable> x5 = CreateObject<LogNormalRandomVariable> ();
     x5->SetAttribute ("Mu", DoubleValue (0.0));
     x5->SetAttribute ("Sigma", DoubleValue (2.0));
 
     plot.AddDataset ( Histogram (x5, probes, precision,
-                                  "LogNormalRandomVariable m=0.0 s=2.0") );
+                                 "LogNormalRandomVariable m=0.0 s=2.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("LogNormalDist(x, 0.0, 2.0)",
                                          "LogNormalDist(x, 0.0, 2.0)") );
@@ -357,7 +361,7 @@ int main (int argc, char *argv[])
     x6->SetAttribute ("Sigma", DoubleValue (2.5));
 
     plot.AddDataset ( Histogram (x6, probes, precision,
-                                  "LogNormalRandomVariable m=0.0 s=2.5") );
+                                 "LogNormalRandomVariable m=0.0 s=2.5") );
 
     gnuplots.AddPlot (plot);
   }
@@ -373,7 +377,7 @@ int main (int argc, char *argv[])
     x1->SetAttribute ("Mean", DoubleValue (0.5));
 
     plot.AddDataset ( Histogram (x1, probes, precision,
-                                  "TriangularRandomVariable [0.0 .. 1.0) m=0.5") );
+                                 "TriangularRandomVariable [0.0 .. 1.0) m=0.5") );
 
     Ptr<TriangularRandomVariable> x2 = CreateObject<TriangularRandomVariable> ();
     x2->SetAttribute ("Min", DoubleValue (0.0));
@@ -381,7 +385,7 @@ int main (int argc, char *argv[])
     x2->SetAttribute ("Mean", DoubleValue (0.4));
 
     plot.AddDataset ( Histogram (x2, probes, precision,
-                                  "TriangularRandomVariable [0.0 .. 1.0) m=0.4") );
+                                 "TriangularRandomVariable [0.0 .. 1.0) m=0.4") );
 
     Ptr<TriangularRandomVariable> x3 = CreateObject<TriangularRandomVariable> ();
     x3->SetAttribute ("Min", DoubleValue (0.0));
@@ -389,7 +393,7 @@ int main (int argc, char *argv[])
     x3->SetAttribute ("Mean", DoubleValue (0.65));
 
     plot.AddDataset ( Histogram (x3, probes, precision,
-                                  "TriangularRandomVariable [0.0 .. 1.0) m=0.65") );
+                                 "TriangularRandomVariable [0.0 .. 1.0) m=0.65") );
 
     gnuplots.AddPlot (plot);
   }
@@ -408,7 +412,7 @@ int main (int argc, char *argv[])
     x1->SetAttribute ("Beta", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x1, probes, precision,
-                                  "GammaRandomVariable a=1.0 b=1.0") );
+                                 "GammaRandomVariable a=1.0 b=1.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("{/Symbol g}(x, 1.0, 1.0)",
                                          "GammaDist(x, 1.0, 1.0)") );
@@ -418,7 +422,7 @@ int main (int argc, char *argv[])
     x2->SetAttribute ("Beta", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x2, probes, precision,
-                                  "GammaRandomVariable a=1.5 b=1.0") );
+                                 "GammaRandomVariable a=1.5 b=1.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("{/Symbol g}(x, 1.5, 1.0)",
                                          "GammaDist(x, 1.5, 1.0)") );
@@ -428,7 +432,7 @@ int main (int argc, char *argv[])
     x3->SetAttribute ("Beta", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x3, probes, precision,
-                                  "GammaRandomVariable a=2.0 b=1.0") );
+                                 "GammaRandomVariable a=2.0 b=1.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("{/Symbol g}(x, 2.0, 1.0)",
                                          "GammaDist(x, 2.0, 1.0)") );
@@ -438,7 +442,7 @@ int main (int argc, char *argv[])
     x4->SetAttribute ("Beta", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x4, probes, precision,
-                                  "GammaRandomVariable a=4.0 b=1.0") );
+                                 "GammaRandomVariable a=4.0 b=1.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("{/Symbol g}(x, 4.0, 1.0)",
                                          "GammaDist(x, 4.0, 1.0)") );
@@ -448,7 +452,7 @@ int main (int argc, char *argv[])
     x5->SetAttribute ("Beta", DoubleValue (2.0));
 
     plot.AddDataset ( Histogram (x5, probes, precision,
-                                  "GammaRandomVariable a=2.0 b=2.0") );
+                                 "GammaRandomVariable a=2.0 b=2.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("{/Symbol g}(x, 2.0, 2.0)",
                                          "GammaDist(x, 2.0, 2.0)") );
@@ -458,7 +462,7 @@ int main (int argc, char *argv[])
     x6->SetAttribute ("Beta", DoubleValue (3.0));
 
     plot.AddDataset ( Histogram (x6, probes, precision,
-                                  "GammaRandomVariable a=2.5 b=3.0") );
+                                 "GammaRandomVariable a=2.5 b=3.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("{/Symbol g}(x, 2.5, 3.0)",
                                          "GammaDist(x, 2.5, 3.0)") );
@@ -468,7 +472,7 @@ int main (int argc, char *argv[])
     x7->SetAttribute ("Beta", DoubleValue (4.5));
 
     plot.AddDataset ( Histogram (x7, probes, precision,
-                                  "GammaRandomVariable a=2.5 b=4.5") );
+                                 "GammaRandomVariable a=2.5 b=4.5") );
 
     plot.AddDataset ( Gnuplot2dFunction ("{/Symbol g}(x, 2.5, 4.5)",
                                          "GammaDist(x, 2.5, 4.5)") );
@@ -489,7 +493,7 @@ int main (int argc, char *argv[])
     x1->SetAttribute ("Lambda", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x1, probes, precision,
-                                  "ErlangRandomVariable k=1 {/Symbol l}=1.0") );
+                                 "ErlangRandomVariable k=1 {/Symbol l}=1.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("Erlang(x, 1, 1.0)",
                                          "ErlangDist(x, 1, 1.0)") );
@@ -499,7 +503,7 @@ int main (int argc, char *argv[])
     x2->SetAttribute ("Lambda", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x2, probes, precision,
-                                  "ErlangRandomVariable k=2 {/Symbol l}=1.0") );
+                                 "ErlangRandomVariable k=2 {/Symbol l}=1.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("Erlang(x, 2, 1.0)",
                                          "ErlangDist(x, 2, 1.0)") );
@@ -509,7 +513,7 @@ int main (int argc, char *argv[])
     x3->SetAttribute ("Lambda", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x3, probes, precision,
-                                  "ErlangRandomVariable k=3 {/Symbol l}=1.0") );
+                                 "ErlangRandomVariable k=3 {/Symbol l}=1.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("Erlang(x, 3, 1.0)",
                                          "ErlangDist(x, 3, 1.0)") );
@@ -519,7 +523,7 @@ int main (int argc, char *argv[])
     x4->SetAttribute ("Lambda", DoubleValue (1.0));
 
     plot.AddDataset ( Histogram (x4, probes, precision,
-                                  "ErlangRandomVariable k=5 {/Symbol l}=1.0") );
+                                 "ErlangRandomVariable k=5 {/Symbol l}=1.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("Erlang(x, 5, 1.0)",
                                          "ErlangDist(x, 5, 1.0)") );
@@ -529,7 +533,7 @@ int main (int argc, char *argv[])
     x5->SetAttribute ("Lambda", DoubleValue (2.0));
 
     plot.AddDataset ( Histogram (x5, probes, precision,
-                                  "ErlangRandomVariable k=2 {/Symbol l}=2.0") );
+                                 "ErlangRandomVariable k=2 {/Symbol l}=2.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("Erlang(x, 2, 2.0)",
                                          "ErlangDist(x, 2, 2.0)") );
@@ -539,7 +543,7 @@ int main (int argc, char *argv[])
     x6->SetAttribute ("Lambda", DoubleValue (3.0));
 
     plot.AddDataset ( Histogram (x6, probes, precision,
-                                  "ErlangRandomVariable k=2 {/Symbol l}=3.0") );
+                                 "ErlangRandomVariable k=2 {/Symbol l}=3.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("Erlang(x, 2, 3.0)",
                                          "ErlangDist(x, 2, 3.0)") );
@@ -549,7 +553,7 @@ int main (int argc, char *argv[])
     x7->SetAttribute ("Lambda", DoubleValue (5.0));
 
     plot.AddDataset ( Histogram (x7, probes, precision,
-                                  "ErlangRandomVariable k=2 {/Symbol l}=5.0") );
+                                 "ErlangRandomVariable k=2 {/Symbol l}=5.0") );
 
     plot.AddDataset ( Gnuplot2dFunction ("Erlang(x, 2, 5.0)",
                                          "ErlangDist(x, 2, 5.0)") );
