@@ -22,6 +22,7 @@
 #include "log.h"
 #include <algorithm>  // find_if
 #include <sstream>
+#include <numeric> // std::accumulate
 
 /**
  * \file
@@ -112,7 +113,17 @@ EnumChecker::GetValue (const std::string name) const
   auto it = std::find_if (m_valueSet.begin (), m_valueSet.end (),
                           [name] (Value v) { return v.second == name; } );
   NS_ASSERT_MSG (it != m_valueSet.end (),
-                 "name " << name << " not a valid enum value. Missed entry in MakeEnumChecker?");
+                 "name " << name << " is not a valid enum value. Missed entry in MakeEnumChecker?\nAvailable values: " <<
+                 std::accumulate (m_valueSet.begin (), m_valueSet.end (), std::string{}, [](std::string a, Value v) {
+                   if (a.empty ())
+                     {
+                       return v.second;
+                     }
+                   else
+                     {
+                       return std::move (a) + ", " + v.second;
+                     }
+                 }));
   return it->first;
 }
 bool
@@ -176,144 +187,4 @@ EnumChecker::Copy (const AttributeValue &source, AttributeValue &destination) co
 }
 
 
-Ptr<const AttributeChecker>
-MakeEnumChecker (int v1, std::string n1,
-                 int v2, std::string n2,
-                 int v3, std::string n3,
-                 int v4, std::string n4,
-                 int v5, std::string n5,
-                 int v6, std::string n6,
-                 int v7, std::string n7,
-                 int v8, std::string n8,
-                 int v9, std::string n9,
-                 int v10, std::string n10,
-                 int v11, std::string n11,
-                 int v12, std::string n12,
-                 int v13, std::string n13,
-                 int v14, std::string n14,
-                 int v15, std::string n15,
-                 int v16, std::string n16,
-                 int v17, std::string n17,
-                 int v18, std::string n18,
-                 int v19, std::string n19,
-                 int v20, std::string n20,
-                 int v21, std::string n21,
-                 int v22, std::string n22)
-{
-  NS_LOG_FUNCTION (v1 << n1 << v2 << n2 << v3 << n3 << v4 << n4 << v5 << n5 <<
-                   v6 << n6 << v7 << n7 << v8 << n8 << v9 << n9 << v10 << n10 <<
-                   v11 << n11 << v12 << n12 << v13 << n13 << v14 << n14 <<
-                   v15 << n15 << v16 << n16 << v17 << n17 << v18 << n18 <<
-                   v19 << n19 << v20 << n20 << v21 << n21 << v22 << n22);
-  Ptr<EnumChecker> checker = Create<EnumChecker> ();
-  checker->AddDefault (v1, n1);
-  if (n2 == "")
-    {
-      return checker;
-    }
-  checker->Add (v2, n2);
-  if (n3 == "")
-    {
-      return checker;
-    }
-  checker->Add (v3, n3);
-  if (n4 == "")
-    {
-      return checker;
-    }
-  checker->Add (v4, n4);
-  if (n5 == "")
-    {
-      return checker;
-    }
-  checker->Add (v5, n5);
-  if (n6 == "")
-    {
-      return checker;
-    }
-  checker->Add (v6, n6);
-  if (n7 == "")
-    {
-      return checker;
-    }
-  checker->Add (v7, n7);
-  if (n8 == "")
-    {
-      return checker;
-    }
-  checker->Add (v8, n8);
-  if (n9 == "")
-    {
-      return checker;
-    }
-  checker->Add (v9, n9);
-  if (n10 == "")
-    {
-      return checker;
-    }
-  checker->Add (v10, n10);
-  if (n11 == "")
-    {
-      return checker;
-    }
-  checker->Add (v11, n11);
-  if (n12 == "")
-    {
-      return checker;
-    }
-  checker->Add (v12, n12);
-  if (n13 == "")
-    {
-      return checker;
-    }
-  checker->Add (v13, n13);
-  if (n14 == "")
-    {
-      return checker;
-    }
-  checker->Add (v14, n14);
-  if (n15 == "")
-    {
-      return checker;
-    }
-  checker->Add (v15, n15);
-  if (n16 == "")
-    {
-      return checker;
-    }
-  checker->Add (v16, n16);
-  if (n17 == "")
-    {
-      return checker;
-    }
-  checker->Add (v17, n17);
-  if (n18 == "")
-    {
-      return checker;
-    }
-  checker->Add (v18, n18);
-  if (n19 == "")
-    {
-      return checker;
-    }
-  checker->Add (v19, n19);
-  if (n20 == "")
-    {
-      return checker;
-    }
-  checker->Add (v20, n20);
-  if (n21 == "")
-    {
-      return checker;
-    }
-  checker->Add (v21, n21);
-  if (n22 == "")
-    {
-      return checker;
-    }
-  checker->Add (v22, n22);
-  return checker;
-}
-
-
 } // namespace ns3
