@@ -89,6 +89,11 @@ public:
    * \param [in] args The arguments to the functor
    */
   void operator() (Ts... args) const;
+  /**
+   * \brief Checks if the Callbacks list is empty.
+   * \return true if the Callbacks list is empty.
+   */
+  bool IsEmpty () const;
 
   /**
    *  TracedCallback signature for POD.
@@ -188,6 +193,13 @@ TracedCallback<Ts...>::operator() (Ts... args) const
     }
 }
 
+template <typename... Ts>
+bool
+TracedCallback<Ts...>::IsEmpty () const
+{
+  return m_callbackList.empty ();
+}
+
 } // namespace ns3
 
 #endif /* TRACED_CALLBACK_H */
