@@ -29,7 +29,7 @@
  */
 
 namespace ns3 {
-  
+
 /**
  * \ingroup object
  *  Inspect a type to deduce its features.
@@ -45,7 +45,8 @@ private:
    *  Not a const type.
    *  \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct UnConst
+  template <typename U>
+  struct UnConst
   {
     typedef U Result;                             /**< Non-const type.       */
   };
@@ -53,7 +54,8 @@ private:
    *  Const type.
    *  \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct UnConst<const U>
+  template <typename U>
+  struct UnConst<const U>
   {
     typedef U Result;                             /**< Non-const type.       */
   };
@@ -61,55 +63,81 @@ private:
    *  Not a reference type.
    *  \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct ReferenceTraits
+  template <typename U>
+  struct ReferenceTraits
   {
-    /** Value. */  enum { IsReference = 0         /**< Not a reference type. */ };
+    /** Value. */
+    enum
+    {
+      IsReference = 0                             /**< Not a reference type. */
+    };
     typedef U ReferencedType;                     /**< Base type.            */
   };
   /**
    *  Reference type.
    *  \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct ReferenceTraits<U&>
+  template <typename U>
+  struct ReferenceTraits<U&>
   {
-    /** Value. */  enum { IsReference = 1         /**< Reference type.       */ };
+    /** Value. */
+    enum
+    {
+      IsReference = 1                             /**< Reference type.       */
+    };
     typedef U ReferencedType;                     /**< Base type.            */
   };
   /**
    *  Not a pointer type.
    *  \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct PointerTraits
+  template <typename U>
+  struct PointerTraits
   {
-    /** Value. */  enum { IsPointer = 0,          /**< Not a pointer type.   */
-                          IsPtr = 0               /**< Not a Ptr type.       */};
+    /** Value. */
+    enum
+    {
+      IsPointer = 0,                              /**< Not a pointer type.   */
+      IsPtr = 0                                   /**< Not a Ptr type.       */
+    };
     typedef U PointeeType;                        /**< Base type.            */
   };
   /**
    *  Pointer type.
    *  \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct PointerTraits<U *>
+  template <typename U>
+  struct PointerTraits<U *>
   {
-    /** Value. */  enum { IsPointer = 1,          /**< Pointer type.         */
-                          IsPtr = 0               /**< Not a Ptr type.       */};
+    /** Value. */
+    enum
+    {
+      IsPointer = 1,                              /**< Pointer type.         */
+      IsPtr = 0                                   /**< Not a Ptr type.       */
+    };
     typedef U PointeeType;                        /**< Pointee type.         */
-  };  
+  };
   /**
    *  Ptr type.
    *  \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct PointerTraits<ns3::Ptr<U> >
+  template <typename U>
+  struct PointerTraits<ns3::Ptr<U> >
   {
-    /** Value. */  enum { IsPointer = 0,          /**< Not a pointer type.   */
-                          IsPtr = 1               /**< Ptr type.             */};
+    /** Value. */
+    enum
+    {
+      IsPointer = 0,                              /**< Not a pointer type.   */
+      IsPtr = 1                                   /**< Ptr type.             */
+    };
     typedef U PointeeType;                        /**< Pointee type.         */
   };
   /**
    * Base type, after removing \c &, \c * and \c const.
    * \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct Base
+  template <typename U>
+  struct Base
   {
     typedef U Type;                               /**< Base type.            */
   };
@@ -117,7 +145,8 @@ private:
    * Base type, after removing \c &.
    * \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct Base <U &>
+  template <typename U>
+  struct Base <U &>
   {
     typedef typename Base<U>::Type Type;          /**< Base type.            */
   };
@@ -125,7 +154,8 @@ private:
    * Base type, after removing \c *.
    * \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct Base <U *>
+  template <typename U>
+  struct Base <U *>
   {
     typedef typename Base<U>::Type  Type;         /**< Base type.            */
   };
@@ -133,7 +163,8 @@ private:
    * Base type, after removing \c const.
    * \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct Base <const U >
+  template <typename U>
+  struct Base <const U >
   {
     typedef typename Base<U>::Type  Type;         /**< Base type.            */
   };
@@ -141,7 +172,8 @@ private:
    * Base type of a Ptr.
    * \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct PtrBase
+  template <typename U>
+  struct PtrBase
   {
     typedef U Type;                               /**< Base type.            */
   };
@@ -149,7 +181,8 @@ private:
    * Base type of a Ptr.
    * \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct PtrBase <ns3::Ptr<U> >
+  template <typename U>
+  struct PtrBase <ns3::Ptr<U> >
   {
     typedef U Type;                               /**< Base type.            */
   };
@@ -157,9 +190,14 @@ private:
    *  Not a function pointer type.
    *  \tparam U \deduced The type being inspected.
    */
-  template <typename U> struct FunctionPtrTraits
+  template <typename U>
+  struct FunctionPtrTraits
   {
-    /** Value. */  enum { IsFunctionPointer = 0   /**< Not a function pointer. */ };
+    /** Value. */
+    enum
+    {
+      IsFunctionPointer = 0                       /**< Not a function pointer. */
+    };
     typedef NullType ReturnType;                  /**< Return type.            */
   };
   /**
@@ -169,8 +207,15 @@ private:
   template <typename U>
   struct FunctionPtrTraits <U (*)(void)>
   {
-    /** Value. */  enum { IsFunctionPointer = 1   /**< Function pointer.     */ };
-    /** Value. */  enum { nArgs = 0               /**< Number of arguments.  */ };
+    /** Value. */
+    enum
+    {
+      IsFunctionPointer = 1                       /**< Function pointer.     */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 0                                   /**< Number of arguments.  */
+    };
     typedef U ReturnType;                         /**< Return type.          */
   };
   /**
@@ -182,8 +227,15 @@ private:
             typename V1>
   struct FunctionPtrTraits <U (*)(V1)>
   {
-    /** Value. */  enum { IsFunctionPointer = 1   /**< Function pointer.     */ };
-    /** Value. */  enum { nArgs = 1               /**< Number of arguments.  */ };
+    /** Value. */
+    enum
+    {
+      IsFunctionPointer = 1                       /**< Function pointer.     */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 1                                   /**< Number of arguments.  */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef V1 Arg1Type;                          /**< First argument type.  */
   };
@@ -197,8 +249,15 @@ private:
             typename V1, typename V2>
   struct FunctionPtrTraits <U (*)(V1,V2)>
   {
-    /** Value. */  enum { IsFunctionPointer = 1   /**< Function pointer.     */ };
-    /** Value. */  enum { nArgs = 2               /**< Number of arguments.  */ };
+    /** Value. */
+    enum
+    {
+      IsFunctionPointer = 1                       /**< Function pointer.     */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 2                                   /**< Number of arguments.  */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef V1 Arg1Type;                          /**< First argument type.  */
     typedef V2 Arg2Type;                          /**< Second argument type. */
@@ -214,8 +273,15 @@ private:
             typename V1, typename V2, typename V3>
   struct FunctionPtrTraits <U (*)(V1,V2,V3)>
   {
-    /** Value. */  enum { IsFunctionPointer = 1   /**< Function pointer.     */ };
-    /** Value. */  enum { nArgs = 3               /**< Number of arguments.  */ };
+    /** Value. */
+    enum
+    {
+      IsFunctionPointer = 1                       /**< Function pointer.     */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 3                                   /**< Number of arguments.  */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef V1 Arg1Type;                          /**< First argument type.  */
     typedef V2 Arg2Type;                          /**< Second argument type. */
@@ -234,8 +300,15 @@ private:
             typename V4>
   struct FunctionPtrTraits <U (*)(V1,V2,V3,V4)>
   {
-    /** Value. */  enum { IsFunctionPointer = 1   /**< Function pointer.     */ };
-    /** Value. */  enum { nArgs = 4               /**< Number of arguments.  */ };
+    /** Value. */
+    enum
+    {
+      IsFunctionPointer = 1                       /**< Function pointer.     */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 4                                   /**< Number of arguments.  */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef V1 Arg1Type;                          /**< First argument type.  */
     typedef V2 Arg2Type;                          /**< Second argument type. */
@@ -256,8 +329,15 @@ private:
             typename V4, typename V5>
   struct FunctionPtrTraits <U (*)(V1,V2,V3,V4,V5)>
   {
-    /** Value. */  enum { IsFunctionPointer = 1   /**< Function pointer.     */ };
-    /** Value. */  enum { nArgs = 5               /**< Number of arguments.  */ };
+    /** Value. */
+    enum
+    {
+      IsFunctionPointer = 1                       /**< Function pointer.     */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 5                                   /**< Number of arguments.  */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef V1 Arg1Type;                          /**< First argument type.  */
     typedef V2 Arg2Type;                          /**< Second argument type. */
@@ -280,8 +360,15 @@ private:
             typename V4, typename V5, typename V6>
   struct FunctionPtrTraits <U (*)(V1,V2,V3,V4,V5,V6)>
   {
-    /** Value. */  enum { IsFunctionPointer = 1   /**< Function pointer.     */ };
-    /** Value. */  enum { nArgs = 6               /**< Number of arguments.  */ };
+    /** Value. */
+    enum
+    {
+      IsFunctionPointer = 1                       /**< Function pointer.     */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 6                                   /**< Number of arguments.  */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef V1 Arg1Type;                          /**< First argument type.  */
     typedef V2 Arg2Type;                          /**< Second argument type. */
@@ -294,9 +381,14 @@ private:
    *  Not a pointer to member type.
    *  \tparam U \deduced Return type.
    */
-  template <typename U> struct PtrToMemberTraits
+  template <typename U>
+  struct PtrToMemberTraits
   {
-    /** Value. */  enum { IsPointerToMember = 0   /**< Not a pointer to member.    */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 0                       /**< Not a pointer to member.    */
+    };
   };
   /**
    *  Pointer to member function.
@@ -304,10 +396,17 @@ private:
    *  \tparam V \deduced Class type.
    */
   template <typename U,  typename V>
-  struct PtrToMemberTraits <U (V::*) (void)>
+  struct PtrToMemberTraits <U (V::*)(void)>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 0               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 0                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.                */
   };
   /**
@@ -316,10 +415,17 @@ private:
    *  \tparam V \deduced Class type.
    */
   template <typename U,  typename V>
-  struct PtrToMemberTraits <U (V::*) (void) const>
+  struct PtrToMemberTraits <U (V::*)(void) const>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 0               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 0                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.                */
   };
   /**
@@ -330,10 +436,17 @@ private:
    */
   template <typename U,  typename V,
             typename W1>
-  struct PtrToMemberTraits <U (V::*) (W1)>
+  struct PtrToMemberTraits <U (V::*)(W1)>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 1               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 1                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
   };
@@ -345,10 +458,17 @@ private:
    */
   template <typename U,  typename V,
             typename W1>
-  struct PtrToMemberTraits <U (V::*) (W1) const>
+  struct PtrToMemberTraits <U (V::*)(W1) const>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 1               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 1                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
   };
@@ -361,10 +481,17 @@ private:
    */
   template <typename U,  typename V,
             typename W1, typename W2>
-  struct PtrToMemberTraits <U (V::*) (W1,W2)>
+  struct PtrToMemberTraits <U (V::*)(W1,W2)>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 2               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 2                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
     typedef W2 Arg2Type;                          /**< Second argument type. */
@@ -378,10 +505,17 @@ private:
    */
   template <typename U,  typename V,
             typename W1, typename W2>
-  struct PtrToMemberTraits <U (V::*) (W1,W2) const>
+  struct PtrToMemberTraits <U (V::*)(W1,W2) const>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 2               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 2                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
     typedef W2 Arg2Type;                          /**< Second argument type. */
@@ -396,10 +530,17 @@ private:
    */
   template <typename U,  typename V,
             typename W1, typename W2, typename W3>
-  struct PtrToMemberTraits <U (V::*) (W1,W2,W3)>
+  struct PtrToMemberTraits <U (V::*)(W1,W2,W3)>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 3               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 3                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
     typedef W2 Arg2Type;                          /**< Second argument type. */
@@ -415,10 +556,17 @@ private:
    */
   template <typename U,  typename V,
             typename W1, typename W2, typename W3>
-  struct PtrToMemberTraits <U (V::*) (W1,W2,W3) const>
+  struct PtrToMemberTraits <U (V::*)(W1,W2,W3) const>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 3               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 3                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
     typedef W2 Arg2Type;                          /**< Second argument type. */
@@ -436,10 +584,17 @@ private:
   template <typename U,  typename V,
             typename W1, typename W2, typename W3,
             typename W4>
-  struct PtrToMemberTraits <U (V::*) (W1,W2,W3,W4)>
+  struct PtrToMemberTraits <U (V::*)(W1,W2,W3,W4)>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 4               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 4                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
     typedef W2 Arg2Type;                          /**< Second argument type. */
@@ -458,10 +613,17 @@ private:
   template <typename U,  typename V,
             typename W1, typename W2, typename W3,
             typename W4>
-  struct PtrToMemberTraits <U (V::*) (W1,W2,W3,W4) const>
+  struct PtrToMemberTraits <U (V::*)(W1,W2,W3,W4) const>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 4               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 4                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
     typedef W2 Arg2Type;                          /**< Second argument type. */
@@ -481,10 +643,17 @@ private:
   template <typename U,  typename V,
             typename W1, typename W2, typename W3,
             typename W4, typename W5>
-  struct PtrToMemberTraits <U (V::*) (W1,W2,W3,W4,W5)>
+  struct PtrToMemberTraits <U (V::*)(W1,W2,W3,W4,W5)>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 5               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 5                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
     typedef W2 Arg2Type;                          /**< Second argument type. */
@@ -505,10 +674,17 @@ private:
   template <typename U,  typename V,
             typename W1, typename W2, typename W3,
             typename W4, typename W5>
-  struct PtrToMemberTraits <U (V::*) (W1,W2,W3,W4,W5) const>
+  struct PtrToMemberTraits <U (V::*)(W1,W2,W3,W4,W5) const>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 5               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 5                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
     typedef W2 Arg2Type;                          /**< Second argument type. */
@@ -530,10 +706,17 @@ private:
   template <typename U,  typename V,
             typename W1, typename W2, typename W3,
             typename W4, typename W5, typename W6>
-  struct PtrToMemberTraits <U (V::*) (W1,W2,W3,W4,W5,W6)>
+  struct PtrToMemberTraits <U (V::*)(W1,W2,W3,W4,W5,W6)>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 6               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 6                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
     typedef W2 Arg2Type;                          /**< Second argument type. */
@@ -556,10 +739,17 @@ private:
   template <typename U,  typename V,
             typename W1, typename W2, typename W3,
             typename W4, typename W5, typename W6>
-  struct PtrToMemberTraits <U (V::*) (W1,W2,W3,W4,W5,W6) const>
+  struct PtrToMemberTraits <U (V::*)(W1,W2,W3,W4,W5,W6) const>
   {
-    /** Value. */  enum { IsPointerToMember = 1   /**< Pointer to member function. */ };
-    /** Value. */  enum { nArgs = 6               /**< Number of arguments.        */ };
+    /** Value. */
+    enum
+    {
+      IsPointerToMember = 1                       /**< Pointer to member function. */
+    };
+    /** Value. */ enum
+    {
+      nArgs = 6                                   /**< Number of arguments.        */
+    };
     typedef U ReturnType;                         /**< Return type.          */
     typedef W1 Arg1Type;                          /**< First argument type.  */
     typedef W2 Arg2Type;                          /**< Second argument type. */
@@ -581,7 +771,8 @@ public:
   /** Ptr base type. */
   typedef typename PtrBase<T>::Type PtrBaseType;
   /** Predicates. */
-  enum {
+  enum
+  {
     /** Pointer to member predicate. */
     IsPointerToMember = PtrToMemberTraits<T>::IsPointerToMember,
     /** Pointer predicate. */
