@@ -65,7 +65,7 @@ main (int argc, char *argv[])
   Ipv6Address ipv6AddressBase = Ipv6Address("2001::");
   Ipv6Prefix ipv6AddressPrefix = Ipv6Prefix(64);
 
-  CommandLine cmd;
+  CommandLine cmd (__FILE__);
   cmd.AddValue ("nSpokes", "Number of spoke nodes to place in the star", nSpokes);
   cmd.AddValue ("useIpv6", "Use Ipv6", useIpv6);
   cmd.Parse (argc, argv);
