@@ -241,10 +241,10 @@ RoutingProtocol::PrintRoutingTable (Ptr<OutputStreamWrapper> stream, Time::Unit
 {
   *stream->GetStream () << "Node: " << m_ipv4->GetObject<Node> ()->GetId ()
                         << ", Time: " << Now ().As (unit)
-                        << ", Local time: " << GetObject<Node> ()->GetLocalTime ().As (unit)
+                        << ", Local time: " << m_ipv4->GetObject<Node> ()->GetLocalTime ().As (unit)
                         << ", DSDV Routing table" << std::endl;
 
-  m_routingTable.Print (stream);
+  m_routingTable.Print (stream, unit);
   *stream->GetStream () << std::endl;
 }
 
@@ -666,8 +666,8 @@ RoutingProtocol::RecvDsdv (Ptr<Socket> socket)
                       NS_LOG_DEBUG ("Received update with better sequence number and changed metric.Waiting for WST");
                       Time tempSettlingtime = GetSettlingTime (dsdvHeader.GetDst ());
                       advTableEntry.SetSettlingTime (tempSettlingtime);
-                      NS_LOG_DEBUG ("Added Settling Time:" << tempSettlingtime.GetSeconds ()
-                                                           << "s as there is no event running for this route");
+                      NS_LOG_DEBUG ("Added Settling Time:" << tempSettlingtime.As (Time::S)
+                                                           << " as there is no event running for this route");
                       event = Simulator::Schedule (tempSettlingtime,&RoutingProtocol::SendTriggeredUpdate,this);
                       m_advRoutingTable.AddIpv4Event (dsdvHeader.GetDst (),event);
                       NS_LOG_DEBUG ("EventCreated EventUID: " << event.GetUid ());
@@ -706,7 +706,7 @@ RoutingProtocol::RecvDsdv (Ptr<Socket> socket)
                       advTableEntry.SetHop (dsdvHeader.GetHopCount ());
                       Time tempSettlingtime = GetSettlingTime (dsdvHeader.GetDst ());
                       advTableEntry.SetSettlingTime (tempSettlingtime);
-                      NS_LOG_DEBUG ("Added Settling Time," << tempSettlingtime.GetSeconds ()
+                      NS_LOG_DEBUG ("Added Settling Time," << tempSettlingtime.As (Time::S)
                                                            << " as there is no current event running for this route");
                       event = Simulator::Schedule (tempSettlingtime,&RoutingProtocol::SendTriggeredUpdate,this);
                       m_advRoutingTable.AddIpv4Event (dsdvHeader.GetDst (),event);
@@ -913,7 +913,7 @@ RoutingProtocol::SendPeriodicUpdate ()
           NS_LOG_DEBUG ("Forwarding details are, Destination: " << dsdvHeader.GetDst ()
                                                                 << ", SeqNo:" << dsdvHeader.GetDstSeqno ()
                                                                 << ", HopCount:" << dsdvHeader.GetHopCount ()
-                                                                << ", LifeTime: " << i->second.GetLifeTime ().GetSeconds ());
+                                                                << ", LifeTime: " << i->second.GetLifeTime ().As (Time::S));
         }
       for (std::map<Ipv4Address, RoutingTableEntry>::const_iterator rmItr = removedAddresses.begin (); rmItr
            != removedAddresses.end (); ++rmItr)
@@ -1196,11 +1196,11 @@ RoutingProtocol::GetSettlingTime (Ipv4Address address)
         }
       else
         {
-          NS_LOG_DEBUG ("Route SettlingTime: " << mainrt.GetSettlingTime ().GetSeconds ()
-                                               << " and LifeTime:" << mainrt.GetLifeTime ().GetSeconds ());
-          weightedTime = Time (m_weightedFactor * mainrt.GetSettlingTime ().GetSeconds () + (1.0 - m_weightedFactor)
-                               * mainrt.GetLifeTime ().GetSeconds ());
-          NS_LOG_DEBUG ("Calculated weightedTime:" << weightedTime.GetSeconds ());
+          NS_LOG_DEBUG ("Route SettlingTime: " << mainrt.GetSettlingTime ().As (Time::S)
+                                               << " and LifeTime:" << mainrt.GetLifeTime ().As (Time::S));
+          weightedTime = m_weightedFactor * mainrt.GetSettlingTime ()  +
+            (1.0 - m_weightedFactor) * mainrt.GetLifeTime ();
+          NS_LOG_DEBUG ("Calculated weightedTime:" << weightedTime.As (Time::S));
           return weightedTime;
         }
     }
