@@ -35,7 +35,7 @@ NS_LOG_COMPONENT_DEFINE ("RealtimeDummyNetworkExample");
 int
 main (int argc, char *argv[])
 {
-  CommandLine cmd;
+  CommandLine cmd (__FILE__);
   cmd.Parse (argc, argv);
 
   GlobalValue::Bind ("SimulatorImplementationType", StringValue ("ns3::RealtimeSimulatorImpl"));
