@@ -119,6 +119,7 @@ public:
    * \brief prints the neighbor cache of all nodes at a particular time.
    * \param printTime the time at which the neighbor cache is supposed to be printed.
    * \param stream The output stream object to use
+   * \param unit The time unit to be used in the report
    *
    * This method calls the PrintArpCache() method of the
    * ArpCache associated with each Ipv4Interface stored in the Ipv4 object, for all nodes at the
@@ -128,12 +129,13 @@ public:
      \endverbatim
    * Note that the MAC address is printed as "type"-"size"-"actual address"
    */
-  static void PrintNeighborCacheAllAt (Time printTime, Ptr<OutputStreamWrapper> stream);
+  static void PrintNeighborCacheAllAt (Time printTime, Ptr<OutputStreamWrapper> stream, Time::Unit unit = Time::S);
 
   /**
    * \brief prints the neighbor cache of all nodes at regular intervals specified by user.
    * \param printInterval the time interval for which the neighbor cache is supposed to be printed.
    * \param stream The output stream object to use
+   * \param unit The time unit to be used in the report
    *
    * This method calls the PrintArpCache() method of the
    * ArpCache associated with each Ipv4Interface stored in the Ipv4 object, for all nodes at the
@@ -143,13 +145,14 @@ public:
      \endverbatim
    * Note that the MAC address is printed as "type"-"size"-"actual address"
    */
-  static void PrintNeighborCacheAllEvery (Time printInterval, Ptr<OutputStreamWrapper> stream);
+  static void PrintNeighborCacheAllEvery (Time printInterval, Ptr<OutputStreamWrapper> stream, Time::Unit unit = Time::S);
 
   /**
    * \brief prints the neighbor cache of a node at a particular time.
    * \param printTime the time at which the neighbor cache is supposed to be printed.
    * \param node The node ptr for which we need the neighbor cache to be printed
    * \param stream The output stream object to use
+   * \param unit The time unit to be used in the report
    *
    * This method calls the PrintArpCache() method of the
    * ArpCache associated with each Ipv4Interface stored in the Ipv4 object, for all nodes at the
@@ -159,13 +162,14 @@ public:
      \endverbatim
    * Note that the MAC address is printed as "type"-"size"-"actual address"
    */
-  static void PrintNeighborCacheAt (Time printTime, Ptr<Node> node, Ptr<OutputStreamWrapper> stream);
+  static void PrintNeighborCacheAt (Time printTime, Ptr<Node> node, Ptr<OutputStreamWrapper> stream, Time::Unit unit = Time::S);
 
   /**
    * \brief prints the neighbor cache of a node at regular intervals specified by user.
    * \param printInterval the time interval for which the neighbor cache is supposed to be printed.
    * \param node The node ptr for which we need the neighbor cache to be printed
    * \param stream The output stream object to use
+   * \param unit The time unit to be used in the report
    *
    * This method calls the PrintArpCache() method of the
    * ArpCache associated with each Ipv4Interface stored in the Ipv4 object, for all nodes at the
@@ -175,7 +179,7 @@ public:
      \endverbatim
    * Note that the MAC address is printed as "type"-"size"-"actual address"
    */
-  static void PrintNeighborCacheEvery (Time printInterval, Ptr<Node> node, Ptr<OutputStreamWrapper> stream);
+  static void PrintNeighborCacheEvery (Time printInterval, Ptr<Node> node, Ptr<OutputStreamWrapper> stream, Time::Unit unit = Time::S);
 
   /**
    * \brief Request a specified routing protocol &lt;T&gt; from Ipv4RoutingProtocol protocol
@@ -219,6 +223,7 @@ private:
    * \brief prints the neighbor cache of a node.
    * \param node The node ptr for which we need the neighbor cache to be printed
    * \param stream The output stream object to use
+   * \param unit The time unit to be used in the report
    *
    * This method calls the PrintArpCache() method of the
    * ArpCache associated with each Ipv4Interface stored in the Ipv4 object, for all nodes at the
@@ -228,13 +233,14 @@ private:
      \endverbatim
    * Note that the MAC address is printed as "type"-"size"-"actual address"
    */
-  static void PrintArpCache (Ptr<Node> node, Ptr<OutputStreamWrapper> stream);
+  static void PrintArpCache (Ptr<Node> node, Ptr<OutputStreamWrapper> stream, Time::Unit unit = Time::S);
 
   /**
    * \brief prints the neighbor cache of a node at regular intervals specified by user.
    * \param printInterval the time interval for which the neighbor cache is supposed to be printed.
    * \param node The node ptr for which we need the neighbor cache to be printed
    * \param stream The output stream object to use
+   * \param unit The time unit to be used in the report
    *
    * This method calls the PrintArpCache() method of the
    * ArpCache associated with each Ipv4Interface stored in the Ipv4 object, for all nodes at the
@@ -244,7 +250,7 @@ private:
      \endverbatim
    * Note that the MAC address is printed as "type"-"size"-"actual address"
    */
-  static void PrintArpCacheEvery (Time printInterval, Ptr<Node> node, Ptr<OutputStreamWrapper> stream);
+  static void PrintArpCacheEvery (Time printInterval, Ptr<Node> node, Ptr<OutputStreamWrapper> stream, Time::Unit unit = Time::S);
 };
 
 
