@@ -51,8 +51,9 @@ public:
   /**
    * \brief Construct an Ipv4StaticRoutingHelper from another previously 
    * initialized instance (Copy Constructor).
+   * \param o object to be copied
    */
-  Ipv4StaticRoutingHelper (const Ipv4StaticRoutingHelper &);
+  Ipv4StaticRoutingHelper (const Ipv4StaticRoutingHelper &o);
 
   /**
    * \returns pointer to clone of this Ipv4StaticRoutingHelper
