@@ -685,12 +685,14 @@ public:
    * \brief Getflags.
    * \return the flags value
    */
+  NS_DEPRECATED_3_34
   uint8_t GetFlags () const;
 
   /**
    * \brief Setflags.
    * \param f the flags value
    */
+  NS_DEPRECATED_3_34
   void SetFlags (uint8_t f);
 
   /**
@@ -728,11 +730,6 @@ private:
    */
   bool m_flagH;
 
-  /**
-   * \brief The flags field value.
-   */
-  uint8_t m_flags;
-
   /**
    * \brief The lifetime value.
    */
@@ -1500,6 +1497,17 @@ public:
    */
   virtual TypeId GetInstanceTypeId () const;
 
+  /**
+   * \brief Icmpv6 Option Prefix Information flag field values
+   */
+  typedef enum
+  {
+    NONE         = 0,   //!< No flags
+    ROUTERADDR   = 32,  //!< Router Address
+    AUTADDRCONF  = 64,  //!< Autonomous Address Configuration
+    ONLINK       = 128  //!< On-link
+  } Flags_t;
+
   /**
    * \brief Get the prefix length.
    * \return prefix length
