@@ -68,12 +68,11 @@ Ipv6Interface::Ipv6Interface ()
 
 Ipv6Interface::~Ipv6Interface ()
 {
-  NS_LOG_FUNCTION_NOARGS ();
 }
 
 void Ipv6Interface::DoDispose ()
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   m_node = 0;
   m_device = 0;
   m_tc = 0;
@@ -83,7 +82,7 @@ void Ipv6Interface::DoDispose ()
 
 void Ipv6Interface::DoSetup ()
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
 
   if (m_node == 0 || m_device == 0)
     {
@@ -94,47 +93,17 @@ void Ipv6Interface::DoSetup ()
   if (!DynamicCast<LoopbackNetDevice> (m_device)) /* no autoconf for ip6-localhost */
     {
       Address addr = GetDevice ()->GetAddress ();
-
-      if (Mac64Address::IsMatchingType (addr))
-        {
-          Ipv6InterfaceAddress ifaddr = Ipv6InterfaceAddress (Ipv6Address::MakeAutoconfiguredLinkLocalAddress (Mac64Address::ConvertFrom (addr)), Ipv6Prefix (64));
-          AddAddress (ifaddr);
-          m_linkLocalAddress = ifaddr;
-        }
-      else if (Mac48Address::IsMatchingType (addr))
-        {
-          Ipv6InterfaceAddress ifaddr = Ipv6InterfaceAddress (Ipv6Address::MakeAutoconfiguredLinkLocalAddress (Mac48Address::ConvertFrom (addr)), Ipv6Prefix (64));
-          AddAddress (ifaddr);
-          m_linkLocalAddress = ifaddr;
-        }
-      else if (Mac16Address::IsMatchingType (addr))
-        {
-          Ipv6InterfaceAddress ifaddr = Ipv6InterfaceAddress (Ipv6Address::MakeAutoconfiguredLinkLocalAddress (Mac16Address::ConvertFrom (addr)), Ipv6Prefix (64));
-          AddAddress (ifaddr);
-          m_linkLocalAddress = ifaddr;
-        }
-      else if (Mac8Address::IsMatchingType (addr))
-        {
-          Ipv6InterfaceAddress ifaddr = Ipv6InterfaceAddress (Ipv6Address::MakeAutoconfiguredLinkLocalAddress (Mac8Address::ConvertFrom (addr)), Ipv6Prefix (64));
-          AddAddress (ifaddr);
-          m_linkLocalAddress = ifaddr;
-        }
-      else
-        {
-          NS_FATAL_ERROR ("IPv6 autoconf for this kind of address not implemented.");
-        }
+      Ipv6InterfaceAddress ifaddr = Ipv6InterfaceAddress (Ipv6Address::MakeAutoconfiguredLinkLocalAddress (addr), Ipv6Prefix (64));
+      AddAddress (ifaddr);
+      m_linkLocalAddress = ifaddr;
     }
   else
     {
       return; /* no NDISC cache for ip6-localhost */
     }
+  int32_t interfaceId = m_node->GetObject<Ipv6> ()->GetInterfaceForDevice (m_device);
+  Ptr<Icmpv6L4Protocol> icmpv6 = DynamicCast<Icmpv6L4Protocol> (m_node->GetObject<Ipv6> ()->GetProtocol (Icmpv6L4Protocol::GetStaticProtocolNumber (), interfaceId));
 
-  Ptr<IpL4Protocol> proto = m_node->GetObject<Ipv6> ()->GetProtocol (Icmpv6L4Protocol::GetStaticProtocolNumber ());
-  Ptr<Icmpv6L4Protocol> icmpv6;
-  if (proto)
-    {
-      icmpv6 = proto->GetObject <Icmpv6L4Protocol> ();
-    }
   if (icmpv6 && !m_ndCache)
     {
       m_ndCache = icmpv6->CreateCache (m_device, this);
@@ -145,14 +114,12 @@ void Ipv6Interface::SetNode (Ptr<Node> node)
 {
   NS_LOG_FUNCTION (this << node);
   m_node = node;
-  DoSetup ();
 }
 
 void Ipv6Interface::SetDevice (Ptr<NetDevice> device)
 {
   NS_LOG_FUNCTION (this << device);
   m_device = device;
-  DoSetup ();
 }
 
 void
@@ -164,7 +131,7 @@ Ipv6Interface::SetTrafficControl (Ptr<TrafficControlLayer> tc)
 
 Ptr<NetDevice> Ipv6Interface::GetDevice () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return m_device;
 }
 
@@ -176,25 +143,25 @@ void Ipv6Interface::SetMetric (uint16_t metric)
 
 uint16_t Ipv6Interface::GetMetric () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return m_metric;
 }
 
 bool Ipv6Interface::IsUp () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return m_ifup;
 }
 
 bool Ipv6Interface::IsDown () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return !m_ifup;
 }
 
 void Ipv6Interface::SetUp ()
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
 
   if (m_ifup)
     {
@@ -206,7 +173,7 @@ void Ipv6Interface::SetUp ()
 
 void Ipv6Interface::SetDown ()
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   m_ifup = false;
   m_addresses.clear ();
   m_ndCache->Flush ();
@@ -214,7 +181,7 @@ void Ipv6Interface::SetDown ()
 
 bool Ipv6Interface::IsForwarding () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return m_forwarding;
 }
 
@@ -226,7 +193,7 @@ void Ipv6Interface::SetForwarding (bool forwarding)
 
 bool Ipv6Interface::AddAddress (Ipv6InterfaceAddress iface)
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this << iface);
   Ipv6Address addr = iface.GetAddress ();
 
   /* DAD handling */
@@ -246,17 +213,21 @@ bool Ipv6Interface::AddAddress (Ipv6InterfaceAddress iface)
       if (!addr.IsAny () || !addr.IsLocalhost ())
         {
           /* DAD handling */
-          Ptr<IpL4Protocol> proto = m_node->GetObject<Ipv6> ()->GetProtocol (Icmpv6L4Protocol::GetStaticProtocolNumber ());
-          Ptr<Icmpv6L4Protocol> icmpv6;
-          if (proto)
-            {
-              icmpv6 = proto->GetObject <Icmpv6L4Protocol> ();
-            }
 
-          if (icmpv6 && icmpv6->IsAlwaysDad ())
+          int32_t interfaceId = m_node->GetObject<Ipv6> ()->GetInterfaceForDevice (m_device);
+          Ptr<Icmpv6L4Protocol> icmpv6 = DynamicCast<Icmpv6L4Protocol> (m_node->GetObject<Ipv6> ()->GetProtocol (Icmpv6L4Protocol::GetStaticProtocolNumber (), interfaceId));
+
+          if (icmpv6)
             {
-              Simulator::Schedule (Seconds (0.), &Icmpv6L4Protocol::DoDAD, icmpv6, addr, this);
-              Simulator::Schedule (Seconds (1.), &Icmpv6L4Protocol::FunctionDadTimeout, icmpv6, this, addr);
+              if (icmpv6->IsAlwaysDad ())
+                {
+                  Simulator::Schedule (Seconds (0.), &Icmpv6L4Protocol::DoDAD, icmpv6, addr, this);
+                  Simulator::Schedule (Seconds (1.), &Icmpv6L4Protocol::FunctionDadTimeout, icmpv6, this, addr);
+                }
+              else
+                {
+                  Simulator::Schedule (Seconds (0.), &Icmpv6L4Protocol::FunctionDadTimeout, icmpv6, this, addr);
+                }
             }
         }
       return true;
@@ -269,7 +240,7 @@ bool Ipv6Interface::AddAddress (Ipv6InterfaceAddress iface)
 Ipv6InterfaceAddress Ipv6Interface::GetLinkLocalAddress () const
 {
   /* IPv6 interface has always at least one IPv6 link-local address */
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
 
   return m_linkLocalAddress;
 }
@@ -316,7 +287,7 @@ Ipv6InterfaceAddress Ipv6Interface::GetAddress (uint32_t index) const
 
 uint32_t Ipv6Interface::GetNAddresses () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return m_addresses.size ();
 }
 
@@ -430,8 +401,11 @@ void Ipv6Interface::Send (Ptr<Packet> p, const Ipv6Header & hdr, Ipv6Address des
   /* other address */
   if (m_device->NeedsArp ())
     {
-      NS_LOG_LOGIC ("Needs ARP" << " " << dest);
-      Ptr<Icmpv6L4Protocol> icmpv6 = ipv6->GetIcmpv6 ();
+      NS_LOG_LOGIC ("Needs NDISC " << dest);
+
+      int32_t interfaceId = m_node->GetObject<Ipv6> ()->GetInterfaceForDevice (m_device);
+      Ptr<Icmpv6L4Protocol> icmpv6 = DynamicCast<Icmpv6L4Protocol> (m_node->GetObject<Ipv6> ()->GetProtocol (Icmpv6L4Protocol::GetStaticProtocolNumber (), interfaceId));
+
       Address hardwareDestination;
       bool found = false;
 
@@ -459,7 +433,7 @@ void Ipv6Interface::Send (Ptr<Packet> p, const Ipv6Header & hdr, Ipv6Address des
     }
   else
     {
-      NS_LOG_LOGIC ("Doesn't need ARP");
+      NS_LOG_LOGIC ("Doesn't need NDISC");
       m_tc->Send (m_device, Create<Ipv6QueueDiscItem> (p, m_device->GetBroadcast (), Ipv6L3Protocol::PROT_NUMBER, hdr));
     }
 }
@@ -472,7 +446,7 @@ void Ipv6Interface::SetCurHopLimit (uint8_t curHopLimit)
 
 uint8_t Ipv6Interface::GetCurHopLimit () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return m_curHopLimit;
 }
 
@@ -484,7 +458,7 @@ void Ipv6Interface::SetBaseReachableTime (uint16_t baseReachableTime)
 
 uint16_t Ipv6Interface::GetBaseReachableTime () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return m_baseReachableTime;
 }
 
@@ -496,7 +470,7 @@ void Ipv6Interface::SetReachableTime (uint16_t reachableTime)
 
 uint16_t Ipv6Interface::GetReachableTime () const
 {
-  NS_LOG_FUNCTION_NOARGS (); 
+  NS_LOG_FUNCTION (this);
   return m_reachableTime;
 }
 
@@ -508,7 +482,7 @@ void Ipv6Interface::SetRetransTimer (uint16_t retransTimer)
 
 uint16_t Ipv6Interface::GetRetransTimer () const
 {
-  NS_LOG_FUNCTION_NOARGS (); 
+  NS_LOG_FUNCTION (this);
   return m_retransTimer;
 }
 
