@@ -51,31 +51,6 @@ private:
   virtual int32_t DoClassify (Ptr<QueueDiscItem> item) const = 0;
 };
 
-
-/**
- * \ingroup internet
- *
- * FqCoDelIpv6PacketFilter is the filter to be added to the FQCoDel
- * queue disc to simulate the behavior of the fq-codel Linux queue disc.
- *
- */
-class FqCoDelIpv6PacketFilter : public Ipv6PacketFilter {
-public:
-  /**
-   * \brief Get the type ID.
-   * \return the object TypeId
-   */
-  static TypeId GetTypeId (void);
-
-  FqCoDelIpv6PacketFilter ();
-  virtual ~FqCoDelIpv6PacketFilter ();
-
-private:
-  virtual int32_t DoClassify (Ptr<QueueDiscItem> item) const;
-
-  uint32_t m_perturbation; //!< hash perturbation value
-};
-
 } // namespace ns3
 
 #endif /* IPV6_PACKET_FILTER */
