@@ -264,6 +264,14 @@ private:
   /// Iterator for container for the multicast routes
   typedef std::list<Ipv6MulticastRoutingTableEntry *>::iterator MulticastRoutesI;
 
+  /**
+   * \brief Checks if a route is already present in the forwarding table.
+   * \param route route
+   * \param metric metric of route
+   * \return true if the route/metric is already in the forwarding table
+   */
+  bool LookupRoute (const Ipv6RoutingTableEntry &route, uint32_t metric);
+
   /**
    * \brief Lookup in the forwarding table for destination.
    * \param dest destination address
