@@ -186,9 +186,10 @@ public:
    * \brief Add an address on the specified IPv6 interface.
    * \param interface Interface number of an IPv6 interface
    * \param address Ipv6InterfaceAddress address to associate with the underlying IPv6 interface
+   * \param addOnLinkRoute add on-link route to the network (default true)
    * \returns true if the operation succeeded
    */
-  virtual bool AddAddress (uint32_t interface, Ipv6InterfaceAddress address) = 0;
+  virtual bool AddAddress (uint32_t interface, Ipv6InterfaceAddress address, bool addOnLinkRoute = true) = 0;
 
   /**
    * \brief Get number of addresses on specified IPv6 interface.
