@@ -20,11 +20,12 @@
 #ifndef TCPHIGHSPEED_H
 #define TCPHIGHSPEED_H
 
-#include "ns3/tcp-congestion-ops.h"
-#include "ns3/tcp-recovery-ops.h"
+#include "tcp-congestion-ops.h"
 
 namespace ns3 {
 
+class TcpSocketState;
+
 /**
  * \ingroup congestionOps
  *
