@@ -111,9 +111,9 @@ public:
  * - CA_DISORDER
  * - CA_RECOVERY
  * - CA_LOSS
+ * - CA_CWR
  *
- * Another one (CA_CWR) is present but not used. For more information, see
- * the TcpCongState_t documentation.
+ * For more information, see the TcpCongState_t documentation.
  *
  * Congestion control interface
  * ---------------------------
@@ -317,6 +317,11 @@ public:
    */
   uint32_t GetRetxThresh (void) const { return m_retxThresh; }
 
+  /**
+   * \brief Callback pointer for pacing rate trace chaining
+   */
+  TracedCallback<DataRate, DataRate>  m_pacingRateTrace;
+
   /**
    * \brief Callback pointer for cWnd trace chaining
    */
@@ -362,6 +367,13 @@ public:
    */
   TracedCallback<Time, Time> m_lastRttTrace;
 
+  /**
+   * \brief Callback function to hook to TcpSocketState pacing rate
+   * \param oldValue old pacing rate value
+   * \param newValue new pacing rate value
+   */
+  void UpdatePacingRateTrace (DataRate oldValue, DataRate newValue);
+
   /**
    * \brief Callback function to hook to TcpSocketState congestion window
    * \param oldValue old cWnd value
@@ -521,6 +533,7 @@ public:
   /**
    * \brief Checks for CE codepoint
    *
+   * \param tos the TOS byte to check
    * \return true if TOS has CE codepoint set; otherwise false
    */
   inline bool CheckEcnCe (uint8_t tos) const
@@ -547,6 +560,18 @@ public:
    */
   void SetUseEcn (TcpSocketState::UseEcn_t useEcn);
 
+  /**
+   * \brief Enable or disable pacing
+   * \param pacing Boolean to enable or disable pacing
+   */
+  void SetPacingStatus (bool pacing);
+
+  /**
+   * \brief Enable or disable pacing of the initial window
+   * \param paceWindow Boolean to enable or disable pacing of the initial window
+   */
+  void SetPaceInitialWindow (bool paceWindow);
+
   // Necessary implementations of null functions from ns3::Socket
   virtual enum SocketErrno GetErrno (void) const;    // returns m_errno
   virtual enum SocketType GetSocketType (void) const; // returns socket type
@@ -672,6 +697,7 @@ protected:
    * \param seq the sequence number of packet's TCP header
    * \param tcpHeaderSize the size of packet's TCP header
    * \param tcpPayloadSize the size of TCP payload
+   * \return true if the TCP segment is valid
    */
   bool IsValidTcpSegment (const SequenceNumber32 seq, const uint32_t tcpHeaderSize,
                           const uint32_t tcpPayloadSize);
@@ -977,7 +1003,6 @@ protected:
    * \param oldHeadSequence value of HeadSequence before ack
    * updated with SACK information
    * \param currentDelivered The number of bytes (S)ACKed
-   * \return the number of bytes (newly) acked, or 0 if it was a dupack
    */
   virtual void ProcessAck (const SequenceNumber32 &ackNumber, bool scoreboardUpdated,
                            uint32_t currentDelivered, const SequenceNumber32 &oldHeadSequence);
@@ -1020,6 +1045,13 @@ protected:
    */
   void DupAck (uint32_t currentDelivered);
 
+  /**
+   * \brief Enter CA_CWR state upon receipt of an ECN Echo
+   *
+   * \param currentDelivered Currently (S)ACKed bytes
+   */
+  void EnterCwr (uint32_t currentDelivered);
+
   /**
    * \brief Enter the CA_RECOVERY, and retransmit the head
    *
@@ -1178,6 +1210,17 @@ protected:
    */
   void NotifyPacingPerformed (void);
 
+  /**
+   * \brief Return true if packets in the current window should be paced
+   * \return true if pacing is currently enabled
+   */
+  bool IsPacingEnabled (void) const;
+
+  /**
+   * \brief Dynamically update the pacing rate
+   */
+  void UpdatePacingRate (void);
+
   /**
    * \brief Add Tags for the Socket
    * \param p Packet
