@@ -79,15 +79,18 @@ public:
     CA_DISORDER,  /**< In all the respects it is "Open",
                     *  but requires a bit more attention. It is entered when
                     *  we see some SACKs or dupacks. It is split of "Open" */
-    CA_CWR,       /**< cWnd was reduced due to some Congestion Notification event.
-                    *  It can be ECN, ICMP source quench, local device congestion.
-                    *  Not used in NS-3 right now. */
+    CA_CWR,       /**< cWnd was reduced due to some congestion notification
+                    *  event, such as ECN, ICMP source quench, local device
+                    *  congestion. */
     CA_RECOVERY,  /**< CWND was reduced, we are fast-retransmitting. */
     CA_LOSS,      /**< CWND was reduced due to RTO timeout or SACK reneging. */
     CA_LAST_STATE /**< Used only in debug messages */
   } TcpCongState_t;
 
   // Note: "not triggered" events are currently not triggered by the code.
+  /**
+   * \brief Congestion avoidance events
+   */
   typedef enum
   {
     CA_EVENT_TX_START,     /**< first transmit when no packets in flight */
@@ -165,6 +168,11 @@ public:
   uint32_t               m_initialCWnd      {0}; //!< Initial cWnd value
   uint32_t               m_initialSsThresh  {0}; //!< Initial Slow Start Threshold value
 
+  // Recovery
+  // This variable is used for implementing following flag of Linux: FLAG_RETRANS_DATA_ACKED
+  // and is used only during a recovery phase to keep track of acknowledgement of retransmitted packet.
+  bool                   m_isRetransDataAcked  {false}; //!< Retransmitted data is ACKed if true
+
   // Segment
   uint32_t               m_segmentSize   {0}; //!< Segment size
   SequenceNumber32       m_lastAckedSeq  {0}; //!< Last sequence ACKed
@@ -182,7 +190,10 @@ public:
   // Pacing related variables
   bool                   m_pacing            {false}; //!< Pacing status
   DataRate               m_maxPacingRate     {0};    //!< Max Pacing rate
-  DataRate               m_currentPacingRate {0};    //!< Current Pacing rate
+  TracedValue<DataRate>  m_pacingRate {0};           //!< Current Pacing rate
+  uint16_t               m_pacingSsRatio {0};        //!< SS pacing ratio
+  uint16_t               m_pacingCaRatio {0};        //!< CA pacing ratio
+  bool                   m_paceInitialWindow {false}; //!< Enable/Disable pacing for the initial window
 
   Time                   m_minRtt  {Time::Max ()};   //!< Minimum RTT observed throughout the connection
 
@@ -196,6 +207,8 @@ public:
 
   EcnCodePoint_t         m_ectCodePoint {Ect0};  //!< ECT code point to use
 
+  uint32_t               m_lastAckedSackedBytes {0}; //!< The number of bytes acked and sacked as indicated by the current ACK received. This is similar to acked_sacked variable in Linux
+
   /**
    * \brief Get cwnd in segments rather than bytes
    *
@@ -216,6 +229,9 @@ public:
     return m_ssThresh / m_segmentSize;
   }
 
+  /**
+   * Callback to send an empty packet
+   */
   Callback <void, uint8_t> m_sendEmptyPacketCallback;
 };
 
