@@ -25,44 +25,12 @@
 #include "ns3/object.h"
 #include "ns3/traced-value.h"
 #include "ns3/sequence-number.h"
-#include "ns3/nstime.h"
 #include "ns3/tcp-option-sack.h"
-#include "ns3/packet.h"
+#include "ns3/tcp-tx-item.h"
 
 namespace ns3 {
 class Packet;
 
-/**
- * \ingroup tcp
- *
- * \brief Item that encloses the application packet and some flags for it
- */
-class TcpTxItem
-{
-public:
-  // Default constructor, copy-constructor, destructor
-
-  /**
-   * \brief Print the time
-   * \param os ostream
-   */
-  void Print (std::ostream &os) const;
-
-  /**
-   * \brief Get the size in the sequence number space
-   *
-   * \return 1 if the packet size is 0 or there's no packet, otherwise the size of the packet
-   */
-  uint32_t GetSeqSize (void) const { return m_packet && m_packet->GetSize () > 0 ? m_packet->GetSize () : 1; }
-
-  SequenceNumber32 m_startSeq {0};     //!< Sequence number of the item (if transmitted)
-  Ptr<Packet> m_packet {nullptr};    //!< Application packet (can be null)
-  bool m_lost          {false};      //!< Indicates if the segment has been lost (RTO)
-  bool m_retrans       {false};      //!< Indicates if the segment is retransmitted
-  Time m_lastSent      {Time::Min()};//!< Timestamp of the time at which the segment has been sent last time
-  bool m_sacked        {false};      //!< Indicates if the segment has been SACKed
-};
-
 /**
  * \ingroup tcp
  *
@@ -198,6 +166,19 @@ public:
    */
   void SetMaxBufferSize (uint32_t n);
 
+  /**
+   * \brief check whether SACK is used on the corresponding TCP socket
+   * \return true if SACK is used
+   */
+  bool IsSackEnabled (void) const;
+
+  /**
+   * \brief tell tx-buffer whether SACK is used on this TCP socket
+   *
+   * \param enabled whether sack is used
+   */
+  void SetSackEnabled (bool enabled);
+
   /**
    * \brief Returns the available capacity of this buffer
    * \returns available capacity in this Tx window
@@ -208,13 +189,13 @@ public:
    * \brief Set the DupAckThresh
    * \param dupAckThresh the threshold
    */
-  void SetDupAckThresh (uint32_t dupAckThresh) { m_dupAckThresh = dupAckThresh; }
+  void SetDupAckThresh (uint32_t dupAckThresh);
 
   /**
    * \brief Set the segment size
    * \param segmentSize the segment size
    */
-  void SetSegmentSize (uint32_t segmentSize) { m_segmentSize = segmentSize; }
+  void SetSegmentSize (uint32_t segmentSize);
 
   /**
    * \brief Return the number of segments in the sent list that
@@ -225,7 +206,7 @@ public:
    *
    * \returns number of segments that have been transmitted more than once, without acknowledgment
    */
-  uint32_t GetRetransmitsCount (void) const { return m_retrans; }
+  uint32_t GetRetransmitsCount (void) const;
 
   /**
    * \brief Get the number of segments that we believe are lost in the network
@@ -233,13 +214,13 @@ public:
    * It is calculated in UpdateLostCount.
    * \return the number of lost segment
    */
-  uint32_t GetLost (void) const { return m_lostOut; }
+  uint32_t GetLost (void) const;
 
   /**
    * \brief Get the number of segments that have been explicitly sacked by the receiver.
    * \return the number of sacked segment.
    */
-  uint32_t GetSacked (void) const { return m_sackedOut; }
+  uint32_t GetSacked (void) const;
 
   /**
    * \brief Append a data packet to the end of the buffer
@@ -274,9 +255,10 @@ public:
    *
    * \param numBytes number of bytes to copy
    * \param seq start sequence number to extract
-   * \returns a packet
+   * \returns a pointer to the TcpTxItem that corresponds to what requested.
+   * Please do not delete the pointer, nor modify Packet data or sequence numbers.
    */
-  Ptr<Packet> CopyFromSequence (uint32_t numBytes, const SequenceNumber32& seq);
+  TcpTxItem* CopyFromSequence (uint32_t numBytes, const SequenceNumber32& seq);
 
   /**
    * \brief Set the head sequence of the buffer
@@ -287,20 +269,34 @@ public:
    */
   void SetHeadSequence (const SequenceNumber32& seq);
 
+  /**
+   * \brief Checks whether the ack corresponds to retransmitted data
+   *
+   * \param ack ACK number received
+   * \return true if retransmitted data was acked
+   */
+  bool IsRetransmittedDataAcked (const SequenceNumber32& ack) const;
+
   /**
    * \brief Discard data up to but not including this sequence number.
    *
    * \param seq The first sequence number to maintain after discarding all the
    * previous sequences.
+   * \param beforeDelCb Callback invoked, if it is not null, before the deletion
+   * of an Item (because it was, probably, ACKed)
    */
-  void DiscardUpTo (const SequenceNumber32& seq);
+  void DiscardUpTo (const SequenceNumber32& seq,
+                    const Callback<void, TcpTxItem *> &beforeDelCb = m_nullCb);
 
   /**
    * \brief Update the scoreboard
    * \param list list of SACKed blocks
-   * \returns true in case of an update
+   * \param sackedCb Callback invoked, if it is not null, when a segment has been
+   * SACKed by the receiver.
+   * \returns the number of bytes newly sacked by the list of blocks
    */
-  bool Update (const TcpOptionSack::SackList &list);
+  uint32_t Update (const TcpOptionSack::SackList &list,
+                   const Callback<void, TcpTxItem *> &sackedCb = m_nullCb);
 
   /**
    * \brief Check if a segment is lost
@@ -309,8 +305,6 @@ public:
    * as lost for an external class
    *
    * \param seq sequence to check
-   * \param dupThresh dupAck threshold
-   * \param segmentSize segment size
    * \return true if the sequence is supposed to be lost, false otherwise
    */
   bool IsLost (const SequenceNumber32 &seq) const;
@@ -319,10 +313,11 @@ public:
    * \brief Get the next sequence number to transmit, according to RFC 6675
    *
    * \param seq Next sequence number to transmit, based on the scoreboard information
+   * \param seqHigh Maximum sequence number to transmit, based on SMSS and/or receiver window
    * \param isRecovery true if the socket congestion state is in recovery mode
    * \return true is seq is updated, false otherwise
    */
-  bool NextSeg (SequenceNumber32 *seq, bool isRecovery) const;
+  bool NextSeg (SequenceNumber32 *seq, SequenceNumber32 *seqHigh, bool isRecovery) const;
 
   /**
    * \brief Return total bytes in flight
@@ -406,6 +401,12 @@ public:
    */
   void ResetRenoSack ();
 
+  /**
+   * \brief Set callback to obtain receiver window value
+   * \param rWndCallback receiver window callback
+   */
+  void SetRWndCallback (Callback<uint32_t> rWndCallback);
+
 private:
   friend std::ostream & operator<< (std::ostream & os, TcpTxBuffer const & tcpTxBuf);
 
@@ -604,6 +605,7 @@ private:
   uint32_t m_maxBuffer;  //!< Max number of data bytes in buffer (SND.WND)
   uint32_t m_size;       //!< Size of all data in this buffer
   uint32_t m_sentSize;   //!< Size of sent (and not discarded) segments
+  Callback<uint32_t> m_rWndCallback; //!< Callback to obtain RCV.WND value
 
   TracedValue<SequenceNumber32> m_firstByteSeq; //!< Sequence number of the first byte in data (SND.UNA)
   std::pair <PacketList::const_iterator, SequenceNumber32> m_highestSack; //!< Highest SACK byte
@@ -615,7 +617,9 @@ private:
   uint32_t m_dupAckThresh {0}; //!< Duplicate Ack threshold from TcpSocketBase
   uint32_t m_segmentSize {0}; //!< Segment size from TcpSocketBase
   bool     m_renoSack {false}; //!< Indicates if AddRenoSack was called
+  bool     m_sackEnabled {true}; //!< Indicates if SACK is enabled on this connection
 
+  static Callback<void, TcpTxItem *> m_nullCb; //!< Null callback for an item
 };
 
 /**
