@@ -100,13 +100,21 @@ public:
   IcmpEchoReplyTestCase ();
   virtual ~IcmpEchoReplyTestCase ();
 
+  /**
+   * Send data
+   * \param socket output socket
+   * \param dst destination address
+   */
   void SendData (Ptr<Socket> socket, Ipv4Address dst);
-  void DoSendData (Ptr<Socket> socket, Ipv4Address dst);
+  /**
+   * Receive data
+   * \param socket input socket
+   */
   void ReceivePkt (Ptr<Socket> socket);
 
 private:
   virtual void DoRun (void);
-  Ptr<Packet> m_receivedPacket;
+  Ptr<Packet> m_receivedPacket; //!< received packet
 
 };
 
@@ -125,7 +133,7 @@ IcmpEchoReplyTestCase::~IcmpEchoReplyTestCase ()
 
 
 void
-IcmpEchoReplyTestCase::DoSendData (Ptr<Socket> socket, Ipv4Address dst)
+IcmpEchoReplyTestCase::SendData (Ptr<Socket> socket, Ipv4Address dst)
 {
   Ptr<Packet> p = Create<Packet> ();
   Icmpv4Echo echo;
@@ -146,15 +154,6 @@ IcmpEchoReplyTestCase::DoSendData (Ptr<Socket> socket, Ipv4Address dst)
 }
 
 
-void
-IcmpEchoReplyTestCase::SendData (Ptr<Socket> socket, Ipv4Address dst)
-{
-  m_receivedPacket = Create<Packet> ();
-  Simulator::ScheduleWithContext (socket->GetNode ()->GetId (), Seconds (0),
-                                  &IcmpEchoReplyTestCase::DoSendData, this, socket, dst);
-  Simulator::Run ();
-}
-
 void
 IcmpEchoReplyTestCase::ReceivePkt (Ptr <Socket> socket)
 {
@@ -210,7 +209,9 @@ IcmpEchoReplyTestCase::DoRun ()
 
   // Set a TTL big enough
   socket->SetIpTtl (1);
-  SendData (socket, i.GetAddress (1,0));
+  Simulator::ScheduleWithContext (socket->GetNode ()->GetId (), Seconds (0),
+                                  &IcmpEchoReplyTestCase::SendData, this, socket, i.GetAddress (1,0));
+  Simulator::Run ();
 
   NS_TEST_EXPECT_MSG_EQ (m_receivedPacket->GetSize (), 28, " Unexpected ICMPV4_ECHO_REPLY packet size");
 
@@ -231,13 +232,21 @@ public:
   IcmpTimeExceedTestCase ();
   virtual ~IcmpTimeExceedTestCase ();
 
+  /**
+   * Send data
+   * \param socket output socket
+   * \param dst destination address
+   */
   void SendData (Ptr<Socket> socket, Ipv4Address dst);
-  void DoSendData (Ptr<Socket> socket, Ipv4Address dst);
+  /**
+   * Receive data
+   * \param socket input socket
+   */
   void ReceivePkt (Ptr<Socket> socket);
 
 private:
   virtual void DoRun (void);
-  Ptr<Packet> m_receivedPacket;
+  Ptr<Packet> m_receivedPacket; //!< received packet
 
 };
 
@@ -256,7 +265,7 @@ IcmpTimeExceedTestCase::~IcmpTimeExceedTestCase ()
 
 
 void
-IcmpTimeExceedTestCase::DoSendData (Ptr<Socket> socket, Ipv4Address dst)
+IcmpTimeExceedTestCase::SendData (Ptr<Socket> socket, Ipv4Address dst)
 {
   Ptr<Packet> p = Create<Packet> ();
   Icmpv4Echo echo;
@@ -276,16 +285,6 @@ IcmpTimeExceedTestCase::DoSendData (Ptr<Socket> socket, Ipv4Address dst)
 }
 
 
-void
-IcmpTimeExceedTestCase::SendData (Ptr<Socket> socket, Ipv4Address dst)
-{
-  m_receivedPacket = Create<Packet> ();
-  Simulator::ScheduleWithContext (socket->GetNode ()->GetId (), Seconds (0),
-                                  &IcmpTimeExceedTestCase::DoSendData, this, socket, dst);
-  Simulator::Run ();
-}
-
-
 void
 IcmpTimeExceedTestCase::ReceivePkt (Ptr<Socket> socket)
 {
@@ -355,7 +354,9 @@ IcmpTimeExceedTestCase::DoRun ()
 
   // The ttl is not big enough , causing an ICMP Time Exceeded response
   socket->SetIpTtl (1);
-  SendData (socket, i2.GetAddress (1,0));
+  Simulator::ScheduleWithContext (socket->GetNode ()->GetId (), Seconds (0),
+                                  &IcmpTimeExceedTestCase::SendData, this, socket, i2.GetAddress (1,0));
+  Simulator::Run ();
 
   NS_TEST_EXPECT_MSG_EQ (m_receivedPacket->GetSize (), 56, " Unexpected ICMP Time Exceed Response packet size");
 
@@ -375,13 +376,21 @@ public:
   IcmpV6EchoReplyTestCase ();
   virtual ~IcmpV6EchoReplyTestCase ();
 
+  /**
+   * Send data
+   * \param socket output socket
+   * \param dst destination address
+   */
   void SendData (Ptr<Socket> socket, Ipv6Address dst);
-  void DoSendData (Ptr<Socket> socket, Ipv6Address dst);
+  /**
+   * Receive data
+   * \param socket input socket
+   */
   void ReceivePkt (Ptr<Socket> socket);
 
 private:
   virtual void DoRun (void);
-  Ptr<Packet> m_receivedPacket;
+  Ptr<Packet> m_receivedPacket; //!< received packet
 
 };
 
@@ -400,7 +409,7 @@ IcmpV6EchoReplyTestCase::~IcmpV6EchoReplyTestCase ()
 
 
 void
-IcmpV6EchoReplyTestCase::DoSendData (Ptr<Socket> socket, Ipv6Address dst)
+IcmpV6EchoReplyTestCase::SendData (Ptr<Socket> socket, Ipv6Address dst)
 {
   Ptr<Packet> p = Create<Packet> ();
   Icmpv6Echo echo (1);
@@ -421,15 +430,6 @@ IcmpV6EchoReplyTestCase::DoSendData (Ptr<Socket> socket, Ipv6Address dst)
 }
 
 
-void
-IcmpV6EchoReplyTestCase::SendData (Ptr<Socket> socket, Ipv6Address dst)
-{
-  m_receivedPacket = Create<Packet> ();
-  Simulator::ScheduleWithContext (socket->GetNode ()->GetId (), Seconds (0),
-                                  &IcmpV6EchoReplyTestCase::DoSendData, this, socket, dst);
-  Simulator::Run ();
-}
-
 void
 IcmpV6EchoReplyTestCase::ReceivePkt (Ptr <Socket> socket)
 {
@@ -498,7 +498,9 @@ IcmpV6EchoReplyTestCase::DoRun ()
   // Set a TTL big enough
   socket->SetIpTtl (1);
 
-  SendData (socket, i.GetAddress (1,1));
+  Simulator::ScheduleWithContext (socket->GetNode ()->GetId (), Seconds (0),
+                                  &IcmpV6EchoReplyTestCase::SendData, this, socket, i.GetAddress (1,1));
+  Simulator::Run ();
 
   NS_TEST_EXPECT_MSG_EQ (m_receivedPacket->GetSize (), 72, " Unexpected ICMPV6_ECHO_REPLY packet size");
 
@@ -518,13 +520,21 @@ public:
   IcmpV6TimeExceedTestCase ();
   virtual ~IcmpV6TimeExceedTestCase ();
 
+  /**
+   * Send data
+   * \param socket output socket
+   * \param dst destination address
+   */
   void SendData (Ptr<Socket> socket, Ipv6Address dst);
-  void DoSendData (Ptr<Socket> socket, Ipv6Address dst);
+  /**
+   * Receive data
+   * \param socket input socket
+   */
   void ReceivePkt (Ptr<Socket> socket);
 
 private:
   virtual void DoRun (void);
-  Ptr<Packet> m_receivedPacket;
+  Ptr<Packet> m_receivedPacket; //!< received packet
 
 };
 
@@ -543,7 +553,7 @@ IcmpV6TimeExceedTestCase::~IcmpV6TimeExceedTestCase ()
 
 
 void
-IcmpV6TimeExceedTestCase::DoSendData (Ptr<Socket> socket, Ipv6Address dst)
+IcmpV6TimeExceedTestCase::SendData (Ptr<Socket> socket, Ipv6Address dst)
 {
   Ptr<Packet> p = Create<Packet> ();
   Icmpv6Echo echo (1);
@@ -564,15 +574,6 @@ IcmpV6TimeExceedTestCase::DoSendData (Ptr<Socket> socket, Ipv6Address dst)
 }
 
 
-void
-IcmpV6TimeExceedTestCase::SendData (Ptr<Socket> socket, Ipv6Address dst)
-{
-  m_receivedPacket = Create<Packet> ();
-  Simulator::ScheduleWithContext (socket->GetNode ()->GetId (), Seconds (0),
-                                  &IcmpV6TimeExceedTestCase::DoSendData, this, socket, dst);
-  Simulator::Run ();
-}
-
 void
 IcmpV6TimeExceedTestCase::ReceivePkt (Ptr <Socket> socket)
 {
@@ -658,7 +659,9 @@ IcmpV6TimeExceedTestCase::DoRun ()
   // The hop limit is not big enough , causing an ICMPV6 Time Exceeded error
   socket->SetIpv6HopLimit (1);
 
-  SendData (socket, interfaces2.GetAddress (1,1));
+  Simulator::ScheduleWithContext (socket->GetNode ()->GetId (), Seconds (0),
+                                  &IcmpV6TimeExceedTestCase::SendData, this, socket, interfaces2.GetAddress (1,1));
+  Simulator::Run ();
 
   NS_TEST_EXPECT_MSG_EQ (m_receivedPacket->GetSize (), 72, " Unexpected ICMPV6_ECHO_REPLY packet size");
 
