@@ -25,8 +25,8 @@
 #include "ns3/ipv6-route.h"
 #include "ns3/ipv4-routing-protocol.h"
 #include "ns3/ipv6-routing-protocol.h"
-#include "../model/ipv4-end-point.h"
-#include "../model/ipv6-end-point.h"
+#include "ns3/ipv4-end-point.h"
+#include "ns3/ipv6-end-point.h"
 #include "tcp-general-test.h"
 #include "ns3/node.h"
 #include "ns3/log.h"
@@ -69,11 +69,11 @@ protected:
   void ConfigureProperties ();
 
 private:
-  uint32_t m_cwndChangeCount;
-  uint32_t m_senderSent;
-  uint32_t m_senderReceived;
-  uint32_t m_receiverReceived;
-  uint32_t m_testcase;
+  uint32_t m_cwndChangeCount;     //!< Number of times the congestion window did change
+  uint32_t m_senderSent;          //!< Number of segments sent by the sender
+  uint32_t m_senderReceived;      //!< Number of segments received by the sender
+  uint32_t m_receiverReceived;    //!< Number of segments received by the receiver
+  uint32_t m_testcase;            //!< Test case type
 };
 
 
@@ -83,10 +83,10 @@ private:
  *
  * \brief A TCP socket which sends certain data packets with CE flags set for tests 5 and 6.
  *
- * The SendDataPacket function of this class sends data packets numbered 1 and 2 with CE flags set
+ * The SendDataPacket function of this class sends data packets numbered 1 and 3 with CE flags set
  * for test 5 to verify if ECE and CWR bits are correctly set by receiver and sender respectively. It
- * also sets CE flags on data packets 10 and 11 in test case 6 to check if sender reduces congestion window
- * by half and also only once per every window.
+ * also sets CE flags on data packets 4 and 5 in test case 6 to check if sender reduces congestion window
+ * appropriately and also only once per every window.
  *
  */
 class TcpSocketCongestedRouter : public TcpSocketMsgBase
@@ -98,8 +98,8 @@ public:
    */
   static TypeId GetTypeId (void);
 
-  uint32_t m_dataPacketSent;
-  uint8_t m_testcase;
+  uint32_t m_dataPacketSent;  //!< Number of packets sent
+  uint8_t m_testcase;         //!< Test case type
 
   TcpSocketCongestedRouter ()
     : TcpSocketMsgBase ()
@@ -116,6 +116,10 @@ public:
   {
   }
 
+  /**
+   * Set the test case type
+   * \param testCase Test case type
+   */
   void SetTestCase (uint8_t testCase);
 
 protected:
@@ -175,21 +179,11 @@ TcpSocketCongestedRouter::SendDataPacket (SequenceNumber32 seq, uint32_t maxSize
   // Sender should reduce the Congestion Window as a response to receiver's ECN Echo notification only once per window
   if (m_tcb->m_ecnState == TcpSocketState::ECN_ECE_RCVD && m_ecnEchoSeq.Get () > m_ecnCWRSeq.Get () && !isRetransmission)
     {
-      NS_LOG_INFO ("Backoff mechanism by reducing CWND  by half because we've received ECN Echo");
-      m_tcb->m_cWnd = std::max (m_tcb->m_cWnd.Get () / 2, m_tcb->m_segmentSize);
-      m_tcb->m_ssThresh = m_tcb->m_cWnd;
-      m_tcb->m_cWndInfl = m_tcb->m_cWnd;
-      flags |= TcpHeader::CWR;
-      m_ecnCWRSeq = seq;
       NS_LOG_DEBUG (TcpSocketState::EcnStateName[m_tcb->m_ecnState] << " -> ECN_CWR_SENT");
       m_tcb->m_ecnState = TcpSocketState::ECN_CWR_SENT;
+      m_ecnCWRSeq = seq;
+      flags |= TcpHeader::CWR;
       NS_LOG_INFO ("CWR flags set");
-      NS_LOG_DEBUG (TcpSocketState::TcpCongStateName[m_tcb->m_congState] << " -> CA_CWR");
-      if (m_tcb->m_congState == TcpSocketState::CA_OPEN)
-        {
-          m_congestionControl->CongestionStateSet (m_tcb, TcpSocketState::CA_CWR);
-          m_tcb->m_congState = TcpSocketState::CA_CWR;
-        }
     }
   /*
    * Add tags for each socket option.
@@ -200,11 +194,11 @@ TcpSocketCongestedRouter::SendDataPacket (SequenceNumber32 seq, uint32_t maxSize
   if (GetIpTos ())
     {
       SocketIpTosTag ipTosTag;
-      if ( m_testcase == 5 && (m_dataPacketSent == 1  || m_dataPacketSent == 2 || m_dataPacketSent == 3 || m_dataPacketSent == 4))
+      if ( m_testcase == 5 && (m_dataPacketSent == 1 || m_dataPacketSent == 3))
         {
           ipTosTag.SetTos (MarkEcnCe (GetIpTos ()));
         }
-      else if ( m_testcase == 6 &&  ( m_dataPacketSent == 10 || m_dataPacketSent == 11))
+      else if ( m_testcase == 6 &&  ( m_dataPacketSent == 4 || m_dataPacketSent == 5))
         {
           ipTosTag.SetTos (MarkEcnCe (GetIpTos ()));
         }
@@ -224,11 +218,11 @@ TcpSocketCongestedRouter::SendDataPacket (SequenceNumber32 seq, uint32_t maxSize
   else
     {
       SocketIpTosTag ipTosTag;
-      if ( m_testcase == 5 && (m_dataPacketSent == 1  || m_dataPacketSent == 2 || m_dataPacketSent == 3 || m_dataPacketSent == 4))
+      if ( m_testcase == 5 && (m_dataPacketSent == 1 || m_dataPacketSent == 3))
         {
           ipTosTag.SetTos (MarkEcnCe (GetIpTos ()));
         }
-      else if ( m_testcase == 6 && ( m_dataPacketSent == 10 || m_dataPacketSent == 11))
+      else if ( m_testcase == 6 && ( m_dataPacketSent == 4 || m_dataPacketSent == 5))
         {
           ipTosTag.SetTos (MarkEcnCe (GetIpTos ()));
         }
@@ -245,11 +239,11 @@ TcpSocketCongestedRouter::SendDataPacket (SequenceNumber32 seq, uint32_t maxSize
   if (IsManualIpv6Tclass ())
     {
       SocketIpv6TclassTag ipTclassTag;
-      if ( m_testcase == 5 && (m_dataPacketSent == 1  || m_dataPacketSent == 2 || m_dataPacketSent == 3 || m_dataPacketSent == 4))
+      if ( m_testcase == 5 && (m_dataPacketSent == 1  || m_dataPacketSent == 3))
         {
           ipTclassTag.SetTclass (MarkEcnCe (GetIpv6Tclass ()));
         }
-      else if ( m_testcase == 6 && ( m_dataPacketSent == 10 || m_dataPacketSent == 11))
+      else if ( m_testcase == 6 && ( m_dataPacketSent == 4 || m_dataPacketSent == 5))
         {
           ipTclassTag.SetTclass (MarkEcnCe (GetIpv6Tclass ()));
         }
@@ -269,11 +263,11 @@ TcpSocketCongestedRouter::SendDataPacket (SequenceNumber32 seq, uint32_t maxSize
   else
     {
       SocketIpv6TclassTag ipTclassTag;
-      if ( m_testcase == 5 && (m_dataPacketSent == 1  || m_dataPacketSent == 2 || m_dataPacketSent == 3 || m_dataPacketSent == 4))
+      if ( m_testcase == 5 && (m_dataPacketSent == 1  || m_dataPacketSent == 3))
         {
           ipTclassTag.SetTclass (MarkEcnCe (GetIpv6Tclass ()));
         }
-      else if ( m_testcase == 6 &&( m_dataPacketSent == 10 || m_dataPacketSent == 11  ))
+      else if ( m_testcase == 6 &&( m_dataPacketSent == 4 || m_dataPacketSent == 5 ))
         {
           ipTclassTag.SetTclass (MarkEcnCe (GetIpv6Tclass ()));
         }
@@ -422,7 +416,7 @@ TcpEcnTest::CWndTrace (uint32_t oldValue, uint32_t newValue)
         {
           m_cwndChangeCount++;
           NS_TEST_ASSERT_MSG_EQ (m_cwndChangeCount, 1, "Congestion window should be reduced once per every window");
-          NS_TEST_ASSERT_MSG_EQ (newValue, oldValue / 2, "Congestion window should be reduced by half");
+          NS_TEST_ASSERT_MSG_EQ (newValue, 1000, "Congestion window should not drop below 2 segments");
         }
     }
 }
@@ -468,14 +462,6 @@ TcpEcnTest::Rx (const Ptr<const Packet> p, const TcpHeader &h, SocketWho who)
               NS_TEST_ASSERT_MSG_EQ (((h.GetFlags ()) & TcpHeader::ECE), 0, "The flag ECE should not be set in the TCP header of first message received at sender when  either receiver or sender are not ECN Capable");
             }
         }
-      if (m_senderReceived == 3 && m_testcase == 5)
-        {
-          NS_TEST_ASSERT_MSG_NE (((h.GetFlags ()) & TcpHeader::ECE), 0, "The flag ECE should be set in TCP header of the packet sent by the receiver when it receives a packet with CE bit set in IP header");
-        }
-      if (m_senderReceived == 4 && m_testcase == 5)
-        {
-          NS_TEST_ASSERT_MSG_NE (((h.GetFlags ()) & TcpHeader::ECE), 0, "The flag ECE should be set in TCP header of the packet sent by the receiver even after sender sends CWR flags to receiver if it receives a packet with CE bit set in IP header");
-        }
       if ( m_testcase == 5 && m_receiverReceived > 12)
         {
           NS_TEST_ASSERT_MSG_EQ (((h.GetFlags ()) & TcpHeader::ECE), 0, "The flag ECE should not be set in TCP header of the packet sent by the receiver after sender sends CWR flags to receiver and receiver receives a packet without CE bit set in IP header");
@@ -505,9 +491,9 @@ TcpEcnTest::Tx (const Ptr<const Packet> p, const TcpHeader &h, SocketWho who)
             }
           else if (m_testcase == 5)
             {
-              if (m_senderSent == 3 || m_senderSent == 4)
+              if (m_senderSent == 3 || m_senderSent == 5)
                 {
-                  NS_TEST_ASSERT_MSG_EQ (ipTos, 0x3, "IP TOS should have CE bit set for 3rd and 4th packet sent in test case 5");
+                  NS_TEST_ASSERT_MSG_EQ (ipTos, 0x3, "IP TOS should have CE bit set for 3rd and 5th packet sent in test case 5");
                 }
               else
                 {
@@ -546,7 +532,7 @@ TcpEcnTest::CreateSenderSocket (Ptr<Node> node)
  *
  * \brief TCP ECN TestSuite
  */
-static class TcpEcnTestSuite : public TestSuite
+class TcpEcnTestSuite : public TestSuite
 {
 public:
   TcpEcnTestSuite () : TestSuite ("tcp-ecn-test", UNIT)
@@ -564,6 +550,8 @@ public:
     AddTestCase (new TcpEcnTest (6, "Congestion Window Reduction Test :ECN capable sender and ECN capable receiver"),
                  TestCase::QUICK);
   }
-} g_tcpECNTestSuite;
+};
+
+static TcpEcnTestSuite g_tcpECNTestSuite; //!< static var for test initialization
 
 } // namespace ns3
