@@ -587,23 +587,47 @@ protected:
    * \brief Forcefully set the initial cwnd
    *
    * \param who socket to force
-   * \param initialCwnd size of the initial cwnd
+   * \param initialCwnd size of the initial cwnd (segments)
    */
   void SetInitialCwnd (SocketWho who, uint32_t initialCwnd);
 
   /**
-   * \brief Forcefully set the ecn use on
+   * \brief Forcefully set the delayed acknowledgement count
    *
    * \param who socket to force
-   * \param useEcn Mode of ECN. Currently Off and On are supported.
+   * \param count value of delayed ACKs
+   */
+  void SetDelAckMaxCount (SocketWho who, uint32_t count);
+
+  /**
+   * \brief Forcefully set the ECN mode of use
+   *
+   * \param who socket to force
+   * \param useEcn Value representing the mode of ECN usage requested
    */
   void SetUseEcn (SocketWho who, TcpSocketState::UseEcn_t useEcn);
 
   /**
-   * \brief Forcefully set the initial ssth
+   * \brief Enable or disable pacing in the TCP socket
+   * 
+   * \param who socket
+   * \param pacing Boolean to enable or disable pacing
+   */
+  void SetPacingStatus (SocketWho who, bool pacing);
+
+  /**
+   * \brief Enable or disable pacing of the initial window
+   * 
+   * \param who socket
+   * \param paceWindow Boolean to enable or disable pacing of initial window
+   */
+  void SetPaceInitialWindow (SocketWho who, bool paceWindow);
+
+  /**
+   * \brief Forcefully set the initial ssthresh
    *
    * \param who socket to force
-   * \param initialSsThresh size of the initial ssth
+   * \param initialSsThresh Initial slow start threshold (bytes)
    */
   void SetInitialSsThresh (SocketWho who, uint32_t initialSsThresh);
 
@@ -658,7 +682,7 @@ protected:
    *
    * \param recovery typeid of the recovery algorithm
    */
-  void SetRecoveryAlgorithm (TypeId reccovery) { m_recoveryTypeId = reccovery; }
+  void SetRecoveryAlgorithm (TypeId recovery) { m_recoveryTypeId = recovery; }
 
   /**
    * \brief MTU of the bottleneck link
