@@ -35,9 +35,7 @@ namespace ns3 {
 class Node;
 class NetDevice;
 class VirtualNetDevice;
-class EpcSgwPgwApplication;
 class EpcX2;
-class EpcMme;
 
 /**
  * \ingroup lte
