@@ -137,12 +137,23 @@ private:
  
   double m_z;  ///< The `Z` attribute.
 
-  std::string m_channelPath;  ///< The `ChannelPath` attribute.
+  /**
+   * The `ChannelPath` attribute. If `Channel` attribute is not set, then
+   * `ChannelPath` will be used to determine the DL channel object for which
+   * the REM will be created.
+   */
+  std::string m_channelPath;
+
   std::string m_outputFile;   ///< The `OutputFile` attribute.
 
   bool m_stopWhenDone;   ///< The `StopWhenDone` attribute.
   
-  /// The channel object taken from the `ChannelPath` attribute.
+  /**
+   * The `Channel` attribute, which is a direct pointer to the DL channel
+   * object for which will be created the REM. Alternatively, `ChannelPath`
+   * attribute can be used. If `ChannelPath` attribute is being used then the
+   * m_channel object is configured by using the `ChannelPath` attribute value.
+   */
   Ptr<SpectrumChannel> m_channel;
 
   double m_noisePower;  ///< The `NoisePower` attribute.
