@@ -31,13 +31,9 @@
 
 namespace ns3 {
 
-
-
-
 class LteChunkProcessor;
 
 
-
 /**
  * This class implements a gaussian interference model, i.e., all
  * incoming signals are added to the total interference.
@@ -57,22 +53,22 @@ public:
   virtual void DoDispose ();
 
   /**
-   * Add a LteChunkProcessor that will use the time-vs-frequency SINR
+   * \brief Add a LteChunkProcessor that will use the time-vs-frequency SINR
    * calculated by this LteInterference instance. Note that all the
    * added LteChunkProcessors will work in parallel.
    *
    * @param p
    */
-  void AddSinrChunkProcessor (Ptr<LteChunkProcessor> p);
+  virtual void AddSinrChunkProcessor (Ptr<LteChunkProcessor> p);
 
   /**
-   * Add a LteChunkProcessor that will use the time-vs-frequency
-   *  interference calculated by this LteInterference instance. Note 
-   *  that all the added LteChunkProcessors will work in parallel.
+   * \brief Add a LteChunkProcessor that will use the time-vs-frequency
+   * interference calculated by this LteInterference instance. Note
+   * that all the added LteChunkProcessors will work in parallel.
    *
    * @param p
    */
-  void AddInterferenceChunkProcessor (Ptr<LteChunkProcessor> p);
+  virtual void AddInterferenceChunkProcessor (Ptr<LteChunkProcessor> p);
 
   /**
    * Add a LteChunkProcessor that will use the time-vs-frequency
@@ -81,23 +77,21 @@ public:
    *
    * @param p
    */
-  void AddRsPowerChunkProcessor (Ptr<LteChunkProcessor> p);
+  virtual void AddRsPowerChunkProcessor (Ptr<LteChunkProcessor> p);
 
   /**
-   * notify that the PHY is starting a RX attempt
+   * \brief Notify that the PHY is starting a RX attempt
    *
    * @param rxPsd the power spectral density of the signal being RX
    */
-  void StartRx (Ptr<const SpectrumValue> rxPsd);
-
+  virtual void StartRx (Ptr<const SpectrumValue> rxPsd);
 
   /**
    * notify that the RX attempt has ended. The receiving PHY must call
    * this method when RX ends or RX is aborted.
    *
    */
-  void EndRx ();
-
+  virtual void EndRx ();
 
   /**
    * notify that a new signal is being perceived in the medium. This
@@ -107,56 +101,54 @@ public:
    * @param spd the power spectral density of the new signal
    * @param duration the duration of the new signal
    */
-  void AddSignal (Ptr<const SpectrumValue> spd, const Time duration);
-
+  virtual void AddSignal (Ptr<const SpectrumValue> spd, const Time duration);
 
   /**
    *
    * @param noisePsd the Noise Power Spectral Density in power units
    * (Watt, Pascal...) per Hz.
    */
-  void SetNoisePowerSpectralDensity (Ptr<const SpectrumValue> noisePsd);
+  virtual void SetNoisePowerSpectralDensity (Ptr<const SpectrumValue> noisePsd);
 
-private:
+protected:
   /**
-   * Considitionally evaluate chunk
+   * Conditionally evaluate chunk
    */
-  void ConditionallyEvaluateChunk ();
+  virtual void ConditionallyEvaluateChunk ();
   /**
    * Add signal function
    *
    * @param spd the power spectral density of the new signal
    */
-  void DoAddSignal  (Ptr<const SpectrumValue> spd);
+  virtual void DoAddSignal (Ptr<const SpectrumValue> spd);
   /**
    * Subtract signal
    *
    * @param spd the power spectral density of the new signal
    * @param signalId the signal ID
    */
-  void DoSubtractSignal  (Ptr<const SpectrumValue> spd, uint32_t signalId);
+  virtual void DoSubtractSignal (Ptr<const SpectrumValue> spd, uint32_t signalId);
 
+  bool m_receiving {false}; ///< are we receiving?
 
+  Ptr<SpectrumValue> m_rxSignal {nullptr}; /**< stores the power spectral density of
+                                            * the signal whose RX is being
+                                            * attempted
+                                            */
 
-  bool m_receiving; ///< are we receiving?
+  Ptr<SpectrumValue> m_allSignals {nullptr}; /**< stores the spectral
+                                              * power density of the sum of incoming signals;
+                                              * does not include noise, includes the SPD of the signal being RX
+                                              */
 
-  Ptr<SpectrumValue> m_rxSignal; /**< stores the power spectral density of
-                                  * the signal whose RX is being
-                                  * attempted
-                                  */
+  Ptr<const SpectrumValue> m_noise {nullptr}; ///< the noise value
 
-  Ptr<SpectrumValue> m_allSignals; /**< stores the spectral
-                                    * power density of the sum of incoming signals;
-                                    * does not include noise, includes the SPD of the signal being RX
-                                    */
+  Time m_lastChangeTime {Seconds(0)}; /**< the time of the last change in
+                                       * m_TotalPower
+                                       */
 
-  Ptr<const SpectrumValue> m_noise; ///< the noise value
-
-  Time m_lastChangeTime;     /**< the time of the last change in
-                                m_TotalPower */
-
-  uint32_t m_lastSignalId; ///< the last signal ID
-  uint32_t m_lastSignalIdBeforeReset; ///< the last signal ID before reset
+  uint32_t m_lastSignalId {0}; ///< the last signal ID
+  uint32_t m_lastSignalIdBeforeReset {0}; ///< the last signal ID before reset
 
   /** all the processor instances that need to be notified whenever
   a new interference chunk is calculated */
