@@ -448,9 +448,12 @@ LteEnbRrcProtocolReal::SetUeRrcSapProvider (uint16_t rnti, LteUeRrcSapProvider*
 {
   std::map<uint16_t, LteUeRrcSapProvider*>::iterator it;
   it = m_enbRrcSapProviderMap.find (rnti);
-  NS_ASSERT_MSG (it != m_enbRrcSapProviderMap.end (), "Cell id " << m_cellId
-                                         << " could not find RNTI = " << rnti);
-  it->second = p;
+  // TODO: remove after merge of ho_failure branch
+  // assign UE RRC only if the RNTI is found at eNB
+  if (it != m_enbRrcSapProviderMap.end ())
+    {
+      it->second = p;
+    }
 }
 
 void 
