@@ -58,13 +58,13 @@ NS_LOG_COMPONENT_DEFINE ("LteUePhy");
  * events. The duration of one symbol is TTI/14 (rounded). In other words,
  * duration of data portion of UL subframe = 1 ms * (13/14) - 1 ns.
  */
-static const Time UL_DATA_DURATION = NanoSeconds (1e6 - 71429 - 1); 
+static const Time UL_DATA_DURATION = NanoSeconds (1e6 - 71429 - 1);
 
 /**
  * Delay from subframe start to transmission of SRS.
  * Equals to "TTI length - 1 symbol for SRS".
  */
-static const Time UL_SRS_DELAY_FROM_SUBFRAME_START = NanoSeconds (1e6 - 71429); 
+static const Time UL_SRS_DELAY_FROM_SUBFRAME_START = NanoSeconds (1e6 - 71429);
 
 
 
@@ -95,9 +95,7 @@ private:
 };
 
 UeMemberLteUePhySapProvider::UeMemberLteUePhySapProvider (LteUePhy* phy) : m_phy (phy)
-{
-
-}
+{}
 
 void
 UeMemberLteUePhySapProvider::SendMacPdu (Ptr<Packet> p)
@@ -204,12 +202,12 @@ LteUePhy::GetTypeId (void)
 {
   static TypeId tid = TypeId ("ns3::LteUePhy")
     .SetParent<LtePhy> ()
-    .SetGroupName("Lte")
+    .SetGroupName ("Lte")
     .AddConstructor<LteUePhy> ()
     .AddAttribute ("TxPower",
                    "Transmission power in dBm",
                    DoubleValue (10.0),
-                   MakeDoubleAccessor (&LteUePhy::SetTxPower, 
+                   MakeDoubleAccessor (&LteUePhy::SetTxPower,
                                        &LteUePhy::GetTxPower),
                    MakeDoubleChecker<double> ())
     .AddAttribute ("NoiseFigure",
@@ -221,7 +219,7 @@ LteUePhy::GetTypeId (void)
                    " are connected to sources at the standard noise temperature T0.\" "
                    "In this model, we consider T0 = 290K.",
                    DoubleValue (9.0),
-                   MakeDoubleAccessor (&LteUePhy::SetNoiseFigure, 
+                   MakeDoubleAccessor (&LteUePhy::SetNoiseFigure,
                                        &LteUePhy::GetNoiseFigure),
                    MakeDoubleChecker<double> ())
     .AddAttribute ("TxMode1Gain",
@@ -465,7 +463,7 @@ LteUePhy::SetNumQoutEvalSf (uint16_t numSubframes)
 {
   NS_LOG_FUNCTION (this << numSubframes);
   NS_ABORT_MSG_IF (numSubframes % 10 != 0, "Number of subframes used for Qout "
-                                           "evaluation must be multiple of 10");
+                   "evaluation must be multiple of 10");
   m_numOfQoutEvalSf = numSubframes;
 }
 
@@ -474,7 +472,7 @@ LteUePhy::SetNumQinEvalSf (uint16_t numSubframes)
 {
   NS_LOG_FUNCTION (this << numSubframes);
   NS_ABORT_MSG_IF (numSubframes % 10 != 0, "Number of subframes used for Qin "
-                                           "evaluation must be multiple of 10");
+                   "evaluation must be multiple of 10");
   m_numOfQinEvalSf = numSubframes;
 }
 
@@ -588,8 +586,8 @@ LteUePhy::GenerateCqiRsrpRsrq (const SpectrumValue& sinr)
       // check periodic wideband CQI
       if (Simulator::Now () > m_p10CqiLast + m_p10CqiPeriodicity)
         {
-          NS_LOG_DEBUG("Reporting P10 CQI at : " << Simulator::Now().GetMilliSeconds()
-                       << " ms. Last reported at : " << m_p10CqiLast.GetMilliSeconds() << " ms");
+          NS_LOG_DEBUG ("Reporting P10 CQI at : " << Simulator::Now ().As (Time::MS)
+                                                  << ". Last reported at : " << m_p10CqiLast.As (Time::MS));
           Ptr<LteUeNetDevice> thisDevice = GetDevice ()->GetObject<LteUeNetDevice> ();
           Ptr<DlCqiLteControlMessage> msg = CreateDlCqiFeedbackMessage (sinr);
           if (msg)
@@ -601,8 +599,8 @@ LteUePhy::GenerateCqiRsrpRsrq (const SpectrumValue& sinr)
       // check aperiodic high-layer configured subband CQI
       if  (Simulator::Now () > m_a30CqiLast + m_a30CqiPeriodicity)
         {
-          NS_LOG_DEBUG("Reporting A30 CQI at : " << Simulator::Now().GetMilliSeconds()
-                       << " ms. Last reported at : " << m_a30CqiLast.GetMilliSeconds() << " ms");
+          NS_LOG_DEBUG ("Reporting A30 CQI at : " << Simulator::Now ().As (Time::MS)
+                                                  << ". Last reported at : " << m_a30CqiLast.As (Time::MS));
           Ptr<LteUeNetDevice> thisDevice = GetDevice ()->GetObject<LteUeNetDevice> ();
           Ptr<DlCqiLteControlMessage> msg = CreateDlCqiFeedbackMessage (sinr);
           if (msg)
@@ -615,7 +613,7 @@ LteUePhy::GenerateCqiRsrpRsrq (const SpectrumValue& sinr)
 
   // Generate PHY trace
   m_rsrpSinrSampleCounter++;
-  if (m_rsrpSinrSampleCounter==m_rsrpSinrSamplePeriod)
+  if (m_rsrpSinrSampleCounter == m_rsrpSinrSamplePeriod)
     {
       NS_ASSERT_MSG (m_rsReceivedPowerUpdated, " RS received power info obsolete");
       // RSRP evaluated as averaged received power among RBs
@@ -625,8 +623,8 @@ LteUePhy::GenerateCqiRsrpRsrq (const SpectrumValue& sinr)
       for (it = m_rsReceivedPower.ConstValuesBegin (); it != m_rsReceivedPower.ConstValuesEnd (); it++)
         {
           // convert PSD [W/Hz] to linear power [W] for the single RE
-          // we consider only one RE for the RS since the channel is 
-          // flat within the same RB 
+          // we consider only one RE for the RS since the channel is
+          // flat within the same RB
           double powerTxW = ((*it) * 180000.0) / 12.0;
           sum += powerTxW;
           rbNum++;
@@ -782,15 +780,15 @@ LteUePhy::GenerateMixedCqiReport (const SpectrumValue& sinr)
   uint32_t modulo = m_dlBandwidth % rbgSize;
   double avgMixedSinr = 0;
   uint32_t usedRbgNum = 0;
-  for(uint32_t i = 0; i < (m_dlBandwidth-1-modulo); i++) 
+  for (uint32_t i = 0; i < (m_dlBandwidth - 1 - modulo); i++)
     {
       usedRbgNum++;
-      avgMixedSinr+=mixedSinr[i];
+      avgMixedSinr += mixedSinr[i];
     }
-  avgMixedSinr = avgMixedSinr/usedRbgNum;
-  for(uint32_t i = 0; i < modulo; i++) 
+  avgMixedSinr = avgMixedSinr / usedRbgNum;
+  for (uint32_t i = 0; i < modulo; i++)
     {
-      mixedSinr[m_dlBandwidth-1-i] = avgMixedSinr;
+      mixedSinr[m_dlBandwidth - 1 - i] = avgMixedSinr;
     }
 
   GenerateCqiRsrpRsrq (mixedSinr);
@@ -997,7 +995,7 @@ LteUePhy::DoSendLteControlMessage (Ptr<LteControlMessage> msg)
   SetControlMessages (msg);
 }
 
-void 
+void
 LteUePhy::DoSendRachPreamble (uint32_t raPreambleId, uint32_t raRnti)
 {
   NS_LOG_FUNCTION (this << raPreambleId);
@@ -1265,18 +1263,18 @@ LteUePhy::SubframeIndication (uint32_t frameNo, uint32_t subframeNo)
       // shift the queue
       for (uint8_t i = 1; i < m_macChTtiDelay; i++)
         {
-          m_subChannelsForTransmissionQueue.at (i-1) = m_subChannelsForTransmissionQueue.at (i);
+          m_subChannelsForTransmissionQueue.at (i - 1) = m_subChannelsForTransmissionQueue.at (i);
         }
-      m_subChannelsForTransmissionQueue.at (m_macChTtiDelay-1).clear ();
+      m_subChannelsForTransmissionQueue.at (m_macChTtiDelay - 1).clear ();
 
       if (m_srsConfigured && (m_srsStartTime <= Simulator::Now ()))
         {
 
           NS_ASSERT_MSG (subframeNo > 0 && subframeNo <= 10, "the SRS index check code assumes that subframeNo starts at 1");
-          if ((((frameNo-1)*10 + (subframeNo-1)) % m_srsPeriodicity) == m_srsSubframeOffset)
+          if ((((frameNo - 1) * 10 + (subframeNo - 1)) % m_srsPeriodicity) == m_srsSubframeOffset)
             {
               NS_LOG_INFO ("frame " << frameNo << " subframe " << subframeNo << " sending SRS (offset=" << m_srsSubframeOffset << ", period=" << m_srsPeriodicity << ")");
-              m_sendSrsEvent = Simulator::Schedule (UL_SRS_DELAY_FROM_SUBFRAME_START, 
+              m_sendSrsEvent = Simulator::Schedule (UL_SRS_DELAY_FROM_SUBFRAME_START,
                                                     &LteUePhy::SendSrs,
                                                     this);
             }
@@ -1299,7 +1297,7 @@ LteUePhy::SubframeIndication (uint32_t frameNo, uint32_t subframeNo)
       else
         {
           // send only PUCCH (ideal: fake null bandwidth signal)
-          if (ctrlMsg.size ()>0)
+          if (ctrlMsg.size () > 0)
             {
               NS_LOG_LOGIC (this << " UE - start TX PUCCH (NO PUSCH)");
               std::vector <int> dlRb;
@@ -1474,7 +1472,7 @@ LteUePhy::DoSetDlBandwidth (uint16_t dlBandwidth)
 }
 
 
-void 
+void
 LteUePhy::DoConfigureUplink (uint32_t ulEarfcn, uint16_t ulBandwidth)
 {
   m_ulEarfcn = ulEarfcn;
@@ -1488,7 +1486,7 @@ LteUePhy::DoConfigureReferenceSignalPower (int8_t referenceSignalPower)
   NS_LOG_FUNCTION (this);
   m_powerControl->ConfigureReferenceSignalPower (referenceSignalPower);
 }
- 
+
 void
 LteUePhy::DoSetRnti (uint16_t rnti)
 {
@@ -1498,7 +1496,7 @@ LteUePhy::DoSetRnti (uint16_t rnti)
   m_powerControl->SetCellId (m_cellId);
   m_powerControl->SetRnti (m_rnti);
 }
- 
+
 void
 LteUePhy::DoSetTransmissionMode (uint8_t txMode)
 {
@@ -1525,10 +1523,10 @@ void
 LteUePhy::DoSetPa (double pa)
 {
   NS_LOG_FUNCTION (this << pa);
-  m_paLinear = pow (10,(pa/10));
+  m_paLinear = pow (10,(pa / 10));
 }
 
-void 
+void
 LteUePhy::DoSetRsrpFilterCoefficient (uint8_t rsrpFilterCoefficient)
 {
   NS_LOG_FUNCTION (this << (uint16_t) (rsrpFilterCoefficient));
@@ -1621,8 +1619,8 @@ LteUePhy::RlfDetection (double sinrDb)
    */
   if (m_downlinkInSync && (m_numOfFrames * 10) == m_numOfQoutEvalSf)
     {
-      NS_LOG_LOGIC ("At " << Simulator::Now ().GetMilliSeconds()
-               << " ms UE PHY sending out of snyc indication to UE RRC layer");
+      NS_LOG_LOGIC ("At " << Simulator::Now ().As (Time::MS)
+                          << " ms UE PHY sending out of snyc indication to UE RRC layer");
       m_ueCphySapUser->NotifyOutOfSync ();
       m_numOfFrames = 0;
     }
@@ -1660,8 +1658,8 @@ LteUePhy::RlfDetection (double sinrDb)
    */
   if (!m_downlinkInSync && (m_numOfFrames * 10) == m_numOfQinEvalSf)
     {
-      NS_LOG_LOGIC ("At " << Simulator::Now ().GetMilliSeconds()
-                   << " ms UE PHY sending in snyc indication to UE RRC layer");
+      NS_LOG_LOGIC ("At " << Simulator::Now ().As (Time::MS)
+                          << " ms UE PHY sending in snyc indication to UE RRC layer");
       m_ueCphySapUser->NotifyInSync ();
       m_numOfFrames = 0;
     }
@@ -1674,37 +1672,37 @@ LteUePhy::SetTxMode1Gain (double gain)
   SetTxModeGain (1, gain);
 }
 
-void 
+void
 LteUePhy::SetTxMode2Gain (double gain)
 {
   SetTxModeGain (2, gain);
 }
 
-void 
+void
 LteUePhy::SetTxMode3Gain (double gain)
 {
   SetTxModeGain (3, gain);
 }
 
-void 
+void
 LteUePhy::SetTxMode4Gain (double gain)
 {
   SetTxModeGain (4, gain);
 }
 
-void 
+void
 LteUePhy::SetTxMode5Gain (double gain)
 {
   SetTxModeGain (5, gain);
 }
 
-void 
+void
 LteUePhy::SetTxMode6Gain (double gain)
 {
   SetTxModeGain (6, gain);
 }
 
-void 
+void
 LteUePhy::SetTxMode7Gain (double gain)
 {
   SetTxModeGain (7, gain);
@@ -1726,7 +1724,7 @@ LteUePhy::SetTxModeGain (uint8_t txMode, double gain)
   m_txModeGain.clear ();
   for (uint8_t i = 0; i < temp.size (); i++)
     {
-      if (i==txMode-1)
+      if (i == txMode - 1)
         {
           m_txModeGain.push_back (gainLin);
         }
