@@ -48,6 +48,7 @@ LteUePowerControl::LteUePowerControl ()
 
   m_M_Pusch = 0;
   m_rsrpSet = false;
+  m_pcRsrpFilterCoefficient = 4; //Default value similar to the eNB (see lte-enb-rrc.cc)
 }
 
 LteUePowerControl::~LteUePowerControl ()
@@ -260,11 +261,19 @@ LteUePowerControl::SetRsrp (double value)
       return;
     }
 
-  double coeff = 0.7;
-  m_rsrp = coeff * m_rsrp + (1 - coeff) * value;
+  double alphaRsrp = std::pow (0.5, m_pcRsrpFilterCoefficient / 4.0);
+  m_rsrp = (1 - alphaRsrp) * m_rsrp + alphaRsrp * value;
+
   m_pathLoss = m_referenceSignalPower - m_rsrp;
 }
 
+void
+LteUePowerControl::SetRsrpFilterCoefficient (uint8_t rsrpFilterCoefficient)
+{
+  NS_LOG_FUNCTION (this);
+  m_pcRsrpFilterCoefficient = rsrpFilterCoefficient;
+}
+
 void
 LteUePowerControl::ReportTpc (uint8_t tpc)
 {
