@@ -822,8 +822,8 @@ private:
 
   LteRrcSap::PdschConfigDedicated m_pdschConfigDedicated; ///< the PDSCH condig dedicated
 
-  uint8_t m_dlBandwidth; /**< Downlink bandwidth in RBs. */
-  uint8_t m_ulBandwidth; /**< Uplink bandwidth in RBs. */
+  uint16_t m_dlBandwidth; /**< Downlink bandwidth in RBs. */
+  uint16_t m_ulBandwidth; /**< Uplink bandwidth in RBs. */
 
   uint32_t m_dlEarfcn;  /**< Downlink carrier frequency. */
   uint32_t m_ulEarfcn;  /**< Uplink carrier frequency. */
@@ -917,7 +917,7 @@ private:
   /**
    * The `DrbCreated` trace source. Fired when DRB is created, i.e.
    * the RLC and PDCP entities are created for one logical channel.
-   * Exporting IMSI, cell ID, RNTI, and LCID
+   * Exporting IMSI, cell ID, RNTI, LCID.
    */
   TracedCallback<uint64_t, uint16_t, uint16_t, uint8_t> m_drbCreatedTrace;
   /**
@@ -1320,6 +1320,22 @@ private:
    */
   void DoResetSyncIndicationCounter ();
 
+  /**
+   * \brief Reset radio link failure parameters
+   *
+   * RLF timers and counters should be rest upon:
+   *
+   * - If the UE received N311 in Sync indications from the UE
+   *   PHY.
+   * - If the UE receives RRCConnectionReconfiguration including
+   *   the mobilityControlInfo (TS 36.331 sec 5.3.5.4)
+   *
+   * Inside this method the UE RRC also instructs the UE PHY to reset the
+   * RLF parameters so, it can start RLF detection again.
+   *
+   */
+  void ResetRlfParams ();
+
 public:
   /** 
    * The number of component carriers.
