@@ -211,6 +211,10 @@ LenaFdBetFfMacSchedulerTestCase1::DoRun (void)
     }
 
   Config::SetDefault ("ns3::LteHelper::UseIdealRrc", BooleanValue (true));
+  Config::SetDefault ("ns3::MacStatsCalculator::DlOutputFilename", StringValue (CreateTempDirFilename ("DlMacStats.txt")));
+  Config::SetDefault ("ns3::MacStatsCalculator::UlOutputFilename", StringValue (CreateTempDirFilename ("UlMacStats.txt")));
+  Config::SetDefault ("ns3::RadioBearerStatsCalculator::DlRlcOutputFilename", StringValue (CreateTempDirFilename ("DlRlcStats.txt")));
+  Config::SetDefault ("ns3::RadioBearerStatsCalculator::UlRlcOutputFilename", StringValue (CreateTempDirFilename ("UlRlcStats.txt")));
 
   /**
    * Initialize Simulation Scenario: 1 eNB and m_nUser UEs
@@ -279,7 +283,7 @@ LenaFdBetFfMacSchedulerTestCase1::DoRun (void)
   Simulator::Run ();
 
   /**
-   * Check that the downlink assignation is done in a "FD blind equal throughput" manner
+   * Check that the downlink assignment is done in a "FD blind equal throughput" manner
    */
   NS_LOG_INFO ("DL - Test with " << m_nUser << " user(s) at distance " << m_dist);
   std::vector <uint64_t> dlDataRxed;
@@ -293,7 +297,7 @@ LenaFdBetFfMacSchedulerTestCase1::DoRun (void)
       NS_LOG_INFO ("\tUser " << i << " imsi " << imsi << " bytes rxed " << (double)dlDataRxed.at (i) << "  thr " << (double)dlDataRxed.at (i) / statsDuration << " ref " << m_thrRefDl);
     }
   /**
-  * Check that the assignation is done in a "FD blind equal throughput" manner among users
+  * Check that the assignment is done in a "FD blind equal throughput" manner among users
   * with equal SINRs: the bandwidth should be distributed according to the 
   * ratio of the estimated throughput per TTI of each user; therefore equally 
   * partitioning the whole bandwidth achievable from a single users in a TTI
@@ -304,7 +308,7 @@ LenaFdBetFfMacSchedulerTestCase1::DoRun (void)
     }
 
   /**
-  * Check that the uplink assignation is done in a "FD blind equal throughput" manner
+  * Check that the uplink assignment is done in a "FD blind equal throughput" manner
   */
   NS_LOG_INFO ("UL - Test with " << m_nUser << " user(s) at distance " << m_dist);
   std::vector <uint64_t> ulDataRxed;
@@ -318,7 +322,7 @@ LenaFdBetFfMacSchedulerTestCase1::DoRun (void)
       NS_LOG_INFO ("\tUser " << i << " imsi " << imsi << " bytes rxed " << (double)ulDataRxed.at (i) << "  thr " << (double)ulDataRxed.at (i) / statsDuration << " ref " << m_thrRefUl);
     }
   /**
-  * Check that the assignation is done in a "FD blind equal throughput" manner among users
+  * Check that the assignment is done in a "FD blind equal throughput" manner among users
   * with equal SINRs: the bandwidth should be distributed according to the 
   * ratio of the estimated throughput per TTI of each user; therefore equally 
   * partitioning the whole bandwidth achievable from a single users in a TTI
@@ -376,6 +380,10 @@ LenaFdBetFfMacSchedulerTestCase2::DoRun (void)
       Config::SetDefault ("ns3::LteSpectrumPhy::DataErrorModelEnabled", BooleanValue (false));
     }
   Config::SetDefault ("ns3::LteHelper::UseIdealRrc", BooleanValue (false));
+  Config::SetDefault ("ns3::MacStatsCalculator::DlOutputFilename", StringValue (CreateTempDirFilename ("DlMacStats.txt")));
+  Config::SetDefault ("ns3::MacStatsCalculator::UlOutputFilename", StringValue (CreateTempDirFilename ("UlMacStats.txt")));
+  Config::SetDefault ("ns3::RadioBearerStatsCalculator::DlRlcOutputFilename", StringValue (CreateTempDirFilename ("DlRlcStats.txt")));
+  Config::SetDefault ("ns3::RadioBearerStatsCalculator::UlRlcOutputFilename", StringValue (CreateTempDirFilename ("UlRlcStats.txt")));
 
   /**
   * Initialize Simulation Scenario: 1 eNB and m_nUser UEs
@@ -464,7 +472,7 @@ LenaFdBetFfMacSchedulerTestCase2::DoRun (void)
   estTotalThr = m_nUser * (1 / estTotalThr);
   estUeThr = estTotalThr / m_nUser;
   /**
-  * Check that the assignation is done in a "FD blind equal throughput" manner among users
+  * Check that the assignment is done in a "FD blind equal throughput" manner among users
   * with different SINRs: the bandwidth should be distributed equally in long term
   */
   for (int i = 0; i < m_nUser; i++)
@@ -478,7 +486,7 @@ LenaFdBetFfMacSchedulerTestCase2::DoRun (void)
     }
 
   /**
-  * Check that the assignation in uplink is done in a round robin manner.
+  * Check that the assignment in uplink is done in a round robin manner.
   */
 
   NS_LOG_INFO ("UL - Test with " << m_nUser);
