@@ -53,15 +53,14 @@ struct CheckPointEvent
    * \param interval the interval time
    * \param ueIndex the UE index
    * \param enbIndex the ENB index
-   */ 
+   */
   CheckPointEvent (Time start, Time stop, Time interval, uint32_t ueIndex, uint32_t enbIndex)
     : checkStartTime (start),
       checkStopTime (stop),
       checkInterval (interval),
       ueDeviceIndex (ueIndex),
       enbDeviceIndex (enbIndex)
-  {
-  }
+  {}
 };
 
 
@@ -69,7 +68,7 @@ struct CheckPointEvent
  * \ingroup lte-test
  * \ingroup tests
  *
- * \brief Test different X2 handover measures and algorithms, e.g. A2A4RsrqHandoverAlgorithm and 
+ * \brief Test different X2 handover measures and algorithms, e.g. A2A4RsrqHandoverAlgorithm and
  * A3RsrpHandoverAlgorithm. Test defines different handover parameters and scenario configurations.
  */
 class LteX2HandoverMeasuresTestCase : public TestCase
@@ -104,12 +103,12 @@ private:
    * \param nEnbs number of eNBs in the test
    * \param nUes number of UEs in the test
    * \param nDedicatedBearers number of bearers to be activated per UE
-   * \param checkPointEventListName 
+   * \param checkPointEventListName
    * \param useUdp true if UDP is to be used, false if TCP is to be used
    * \param schedulerType the scheduler type
    * \param handoverAlgorithmType type of handover algorithm to be used (e.g. "ns3::A3RsrpHandoverAlgorithm")
    * \param admitHo
-   * \param useIdealRrc true if the ideal RRC should be used 
+   * \param useIdealRrc true if the ideal RRC should be used
    * \returns the name string
    */
   static std::string BuildNameString (uint32_t nEnbs, uint32_t nUes, uint32_t nDedicatedBearers,
@@ -144,7 +143,7 @@ private:
  * \ingroup tests
  *
  * \brief BearerData structure
- */ 
+ */
   struct BearerData
   {
     uint32_t bid; ///< BID
@@ -159,7 +158,7 @@ private:
  * \ingroup tests
  *
  * \brief UeData structure
- */ 
+ */
   struct UeData
   {
     uint32_t id; ///< ID
@@ -169,12 +168,12 @@ private:
   /**
    * \brief Save stats  function
    * \param ueIndex the index of the UE
-   */ 
+   */
   void SaveStats (uint32_t ueIndex);
   /**
    * \brief Check stats  function
    * \param ueIndex the index of the UE
-   */ 
+   */
   void CheckStats (uint32_t ueIndex);
 
   std::vector<UeData> m_ueDataVector; ///< UE data vector
@@ -237,8 +236,7 @@ LteX2HandoverMeasuresTestCase::LteX2HandoverMeasuresTestCase (uint32_t nEnbs, ui
     m_statsDuration (Seconds (0.5)),
     m_udpClientInterval (Seconds (0.01)),
     m_udpClientPktSize (100)
-{
-}
+{}
 
 void
 LteX2HandoverMeasuresTestCase::DoRun ()
@@ -673,7 +671,7 @@ LteX2HandoverMeasuresTestCase::CheckStats (uint32_t ueIndex)
         {
           ulRx = it->ulSink->GetTotalRx () - it->ulOldTotalRx;
         }
-      double expectedBytes = m_udpClientPktSize * (m_statsDuration.GetSeconds () / m_udpClientInterval.GetSeconds ());
+      double expectedBytes = m_udpClientPktSize * (m_statsDuration / m_udpClientInterval).GetDouble ();
 
       NS_LOG_LOGIC ("expBytes " << expectedBytes << " dlRx " << dlRx << " ulRx " << ulRx);
 
