@@ -36,7 +36,7 @@ NS_LOG_COMPONENT_DEFINE ("LteX2HandoverTest");
  * \ingroup tests
  *
  * \brief HandoverEvent structure
- */ 
+ */
 struct HandoverEvent
 {
   Time startTime; ///< start time
@@ -50,35 +50,34 @@ struct HandoverEvent
  * \ingroup lte-test
  * \ingroup tests
  *
- * \brief Test X2 Handover. In this test is used NoOpHandoverAlgorithm and 
+ * \brief Test X2 Handover. In this test is used NoOpHandoverAlgorithm and
  * the request for handover is generated manually, and it is not based on measurements.
- */ 
+ */
 class LteX2HandoverTestCase : public TestCase
 {
 public:
-
-  /** 
-   * 
-   * 
+  /**
+   *
+   *
    * \param nUes number of UEs in the test
    * \param nDedicatedBearers number of bearers to be activated per UE
-   * \param handoverEventList 
-   * \param handoverEventListName 
+   * \param handoverEventList
+   * \param handoverEventListName
    * \param schedulerType the scheduler type
    * \param admitHo
-   * \param useIdealRrc true if the ideal RRC should be used 
+   * \param useIdealRrc true if the ideal RRC should be used
    */
   LteX2HandoverTestCase (uint32_t nUes, uint32_t nDedicatedBearers, std::list<HandoverEvent> handoverEventList, std::string handoverEventListName, std::string schedulerType, bool admitHo, bool useIdealRrc);
-  
+
 private:
   /**
    * Build name string
    * \param nUes number of UEs in the test
    * \param nDedicatedBearers number of bearers to be activated per UE
-   * \param handoverEventListName 
+   * \param handoverEventListName
    * \param schedulerType the scheduler type
    * \param admitHo
-   * \param useIdealRrc true if the ideal RRC should be used 
+   * \param useIdealRrc true if the ideal RRC should be used
    * \returns the name string
    */
   static std::string BuildNameString (uint32_t nUes, uint32_t nDedicatedBearers, std::string handoverEventListName, std::string schedulerType, bool admitHo, bool useIdealRrc);
@@ -113,13 +112,13 @@ private:
   bool     m_useIdealRrc; ///< whether to use the ideal RRC
   Ptr<LteHelper> m_lteHelper; ///< LTE helper
   Ptr<PointToPointEpcHelper> m_epcHelper; ///< EPC helper
-  
+
 /**
  * \ingroup lte-test
  * \ingroup tests
  *
  * \brief BearerData structure
- */ 
+ */
   struct BearerData
   {
     uint32_t bid; ///< BID
@@ -134,7 +133,7 @@ private:
  * \ingroup tests
  *
  * \brief UeData structure
- */ 
+ */
   struct UeData
   {
     uint32_t id; ///< ID
@@ -144,12 +143,12 @@ private:
 /**
  * \brief Save stats after handover function
  * \param ueIndex the index of the UE
- */ 
+ */
   void SaveStatsAfterHandover (uint32_t ueIndex);
 /**
  * \brief Check stats a while after handover function
  * \param ueIndex the index of the UE
- */ 
+ */
   void CheckStatsAWhileAfterHandover (uint32_t ueIndex);
 
   std::vector<UeData> m_ueDataVector; ///< UE data vector
@@ -165,8 +164,8 @@ private:
 std::string LteX2HandoverTestCase::BuildNameString (uint32_t nUes, uint32_t nDedicatedBearers, std::string handoverEventListName, std::string schedulerType, bool admitHo, bool useIdealRrc)
 {
   std::ostringstream oss;
-  oss << " nUes=" << nUes 
-      << " nDedicatedBearers=" << nDedicatedBearers 
+  oss << " nUes=" << nUes
+      << " nDedicatedBearers=" << nDedicatedBearers
       << " " << schedulerType
       << " admitHo=" << admitHo
       << " hoList: " << handoverEventListName;
@@ -177,7 +176,7 @@ std::string LteX2HandoverTestCase::BuildNameString (uint32_t nUes, uint32_t nDed
   else
     {
       oss << ", real RRC";
-    }  
+    }
   return oss.str ();
 }
 
@@ -195,9 +194,8 @@ LteX2HandoverTestCase::LteX2HandoverTestCase (uint32_t nUes, uint32_t nDedicated
     m_statsDuration (Seconds (0.1)),
     m_udpClientInterval (Seconds (0.01)),
     m_udpClientPktSize (100)
-    
-{
-}
+
+{}
 
 void
 LteX2HandoverTestCase::DoRun ()
@@ -206,20 +204,20 @@ LteX2HandoverTestCase::DoRun ()
 
   Config::Reset ();
   Config::SetDefault ("ns3::UdpClient::Interval",  TimeValue (m_udpClientInterval));
-  Config::SetDefault ("ns3::UdpClient::MaxPackets", UintegerValue (1000000));  
-  Config::SetDefault ("ns3::UdpClient::PacketSize", UintegerValue (m_udpClientPktSize));  
+  Config::SetDefault ("ns3::UdpClient::MaxPackets", UintegerValue (1000000));
+  Config::SetDefault ("ns3::UdpClient::PacketSize", UintegerValue (m_udpClientPktSize));
 
   //Disable Uplink Power Control
   Config::SetDefault ("ns3::LteUePhy::EnableUplinkPowerControl", BooleanValue (false));
 
   int64_t stream = 1;
-  
+
   m_lteHelper = CreateObject<LteHelper> ();
   m_lteHelper->SetAttribute ("PathlossModel", StringValue ("ns3::FriisSpectrumPropagationLossModel"));
   m_lteHelper->SetSchedulerType (m_schedulerType);
   m_lteHelper->SetHandoverAlgorithmType ("ns3::NoOpHandoverAlgorithm"); // disable automatic handover
   m_lteHelper->SetAttribute ("UseIdealRrc", BooleanValue (m_useIdealRrc));
-  
+
 
   NodeContainer enbNodes;
   enbNodes.Create (2);
@@ -229,7 +227,7 @@ LteX2HandoverTestCase::DoRun ()
   if (m_epc)
     {
       m_epcHelper = CreateObject<PointToPointEpcHelper> ();
-      m_lteHelper->SetEpcHelper (m_epcHelper);      
+      m_lteHelper->SetEpcHelper (m_epcHelper);
     }
 
   Ptr<ListPositionAllocator> positionAlloc = CreateObject<ListPositionAllocator> ();
@@ -242,7 +240,7 @@ LteX2HandoverTestCase::DoRun ()
   MobilityHelper mobility;
   mobility.SetPositionAllocator (positionAlloc);
   mobility.SetMobilityModel ("ns3::ConstantPositionMobilityModel");
-  mobility.Install (enbNodes);  
+  mobility.Install (enbNodes);
   mobility.Install (ueNodes);
 
   NetDeviceContainer enbDevices;
@@ -290,7 +288,7 @@ LteX2HandoverTestCase::DoRun ()
       Ptr<Ipv4StaticRouting> remoteHostStaticRouting = ipv4RoutingHelper.GetStaticRouting (remoteHost->GetObject<Ipv4> ());
       remoteHostStaticRouting->AddNetworkRouteTo (Ipv4Address ("7.0.0.0"), Ipv4Mask ("255.0.0.0"), 1);
 
-      // Install the IP stack on the UEs      
+      // Install the IP stack on the UEs
       internet.Install (ueNodes);
       ueIpIfaces = m_epcHelper->AssignUeIpv4Address (NetDeviceContainer (ueDevices));
     }
@@ -298,25 +296,25 @@ LteX2HandoverTestCase::DoRun ()
   // attachment (needs to be done after IP stack configuration)
   // all UEs attached to eNB 0 at the beginning
   m_lteHelper->Attach (ueDevices, enbDevices.Get (0));
-   
+
   if (m_epc)
     {
       // always true: bool epcDl = true;
       // always true: bool epcUl = true;
       // the rest of this block is copied from lena-dual-stripe
 
-    
+
       // Install and start applications on UEs and remote host
       uint16_t dlPort = 10000;
       uint16_t ulPort = 20000;
 
       // randomize a bit start times to avoid simulation artifacts
       // (e.g., buffer overflows due to packet transmissions happening
-      // exactly at the same time) 
+      // exactly at the same time)
       Ptr<UniformRandomVariable> startTimeSeconds = CreateObject<UniformRandomVariable> ();
       startTimeSeconds->SetAttribute ("Min", DoubleValue (0));
       startTimeSeconds->SetAttribute ("Max", DoubleValue (0.010));
-      startTimeSeconds->SetStream (stream++);      
+      startTimeSeconds->SetStream (stream++);
 
       for (uint32_t u = 0; u < ueNodes.GetN (); ++u)
         {
@@ -326,7 +324,7 @@ LteX2HandoverTestCase::DoRun ()
           ueStaticRouting->SetDefaultRoute (m_epcHelper->GetUeDefaultGatewayAddress (), 1);
 
           UeData ueData;
-     
+
           for (uint32_t b = 0; b < m_nDedicatedBearers; ++b)
             {
               ++dlPort;
@@ -337,48 +335,48 @@ LteX2HandoverTestCase::DoRun ()
               BearerData bearerData;
 
               // always true: if (epcDl)
-                {
-                  UdpClientHelper dlClientHelper (ueIpIfaces.GetAddress (u), dlPort);
-                  clientApps.Add (dlClientHelper.Install (remoteHost));
-                  PacketSinkHelper dlPacketSinkHelper ("ns3::UdpSocketFactory", 
-                                                        InetSocketAddress (Ipv4Address::GetAny (), dlPort));
-                  ApplicationContainer sinkContainer = dlPacketSinkHelper.Install (ue);
-                  bearerData.dlSink = sinkContainer.Get (0)->GetObject<PacketSink> ();
-                  serverApps.Add (sinkContainer);
-                  
-                }
+              {
+                UdpClientHelper dlClientHelper (ueIpIfaces.GetAddress (u), dlPort);
+                clientApps.Add (dlClientHelper.Install (remoteHost));
+                PacketSinkHelper dlPacketSinkHelper ("ns3::UdpSocketFactory",
+                                                     InetSocketAddress (Ipv4Address::GetAny (), dlPort));
+                ApplicationContainer sinkContainer = dlPacketSinkHelper.Install (ue);
+                bearerData.dlSink = sinkContainer.Get (0)->GetObject<PacketSink> ();
+                serverApps.Add (sinkContainer);
+
+              }
               // always true: if (epcUl)
-                {      
-                  UdpClientHelper ulClientHelper (remoteHostAddr, ulPort);
-                  clientApps.Add (ulClientHelper.Install (ue));
-                  PacketSinkHelper ulPacketSinkHelper ("ns3::UdpSocketFactory", 
-                                                        InetSocketAddress (Ipv4Address::GetAny (), ulPort));
-                  ApplicationContainer sinkContainer = ulPacketSinkHelper.Install (remoteHost);
-                  bearerData.ulSink = sinkContainer.Get (0)->GetObject<PacketSink> ();
-                  serverApps.Add (sinkContainer);  
-                }            
+              {
+                UdpClientHelper ulClientHelper (remoteHostAddr, ulPort);
+                clientApps.Add (ulClientHelper.Install (ue));
+                PacketSinkHelper ulPacketSinkHelper ("ns3::UdpSocketFactory",
+                                                     InetSocketAddress (Ipv4Address::GetAny (), ulPort));
+                ApplicationContainer sinkContainer = ulPacketSinkHelper.Install (remoteHost);
+                bearerData.ulSink = sinkContainer.Get (0)->GetObject<PacketSink> ();
+                serverApps.Add (sinkContainer);
+              }
 
               Ptr<EpcTft> tft = Create<EpcTft> ();
               // always true: if (epcDl)
-                {
-                  EpcTft::PacketFilter dlpf;
-                  dlpf.localPortStart = dlPort;
-                  dlpf.localPortEnd = dlPort;
-                  tft->Add (dlpf); 
-                }
+              {
+                EpcTft::PacketFilter dlpf;
+                dlpf.localPortStart = dlPort;
+                dlpf.localPortEnd = dlPort;
+                tft->Add (dlpf);
+              }
               // always true: if (epcUl)
-                {
-                  EpcTft::PacketFilter ulpf;
-                  ulpf.remotePortStart = ulPort;
-                  ulpf.remotePortEnd = ulPort;
-                  tft->Add (ulpf);
-                }
+              {
+                EpcTft::PacketFilter ulpf;
+                ulpf.remotePortStart = ulPort;
+                ulpf.remotePortEnd = ulPort;
+                tft->Add (ulpf);
+              }
 
               // always true: if (epcDl || epcUl)
-                {
-                  EpsBearer bearer (EpsBearer::NGBR_VIDEO_TCP_DEFAULT);
-                  m_lteHelper->ActivateDedicatedEpsBearer (ueDevices.Get (u), bearer, tft);
-                }
+              {
+                EpsBearer bearer (EpsBearer::NGBR_VIDEO_TCP_DEFAULT);
+                m_lteHelper->ActivateDedicatedEpsBearer (ueDevices.Get (u), bearer, tft);
+              }
               Time startTime = Seconds (startTimeSeconds->GetValue ());
               serverApps.Start (startTime);
               clientApps.Start (startTime);
@@ -390,7 +388,7 @@ LteX2HandoverTestCase::DoRun ()
           m_ueDataVector.push_back (ueData);
         }
 
-    } 
+    }
   else // (epc == false)
     {
       // for radio bearer activation purposes, consider together home UEs and macro UEs
@@ -413,14 +411,14 @@ LteX2HandoverTestCase::DoRun ()
   const Time maxRrcConnectionEstablishmentDuration = Seconds (0.080);
   for (NetDeviceContainer::Iterator it = ueDevices.Begin (); it != ueDevices.End (); ++it)
     {
-      Simulator::Schedule (maxRrcConnectionEstablishmentDuration, 
-                           &LteX2HandoverTestCase::CheckConnected, 
+      Simulator::Schedule (maxRrcConnectionEstablishmentDuration,
+                           &LteX2HandoverTestCase::CheckConnected,
                            this, *it, enbDevices.Get (0));
     }
-  
+
   // schedule handover events and corresponding checks
 
-  Time stopTime = Seconds (0);  
+  Time stopTime = Seconds (0);
   for (std::list<HandoverEvent>::iterator hoEventIt = m_handoverEventList.begin ();
        hoEventIt != m_handoverEventList.end ();
        ++hoEventIt)
@@ -431,13 +429,13 @@ LteX2HandoverTestCase::DoRun ()
                            this,
                            ueNodes.Get (hoEventIt->ueDeviceIndex));
 
-      Simulator::Schedule (hoEventIt->startTime, 
-                           &LteX2HandoverTestCase::CheckConnected, 
-                           this, 
-                           ueDevices.Get (hoEventIt->ueDeviceIndex), 
+      Simulator::Schedule (hoEventIt->startTime,
+                           &LteX2HandoverTestCase::CheckConnected,
+                           this,
+                           ueDevices.Get (hoEventIt->ueDeviceIndex),
                            enbDevices.Get (hoEventIt->sourceEnbDeviceIndex));
 
-      m_lteHelper->HandoverRequest (hoEventIt->startTime, 
+      m_lteHelper->HandoverRequest (hoEventIt->startTime,
                                     ueDevices.Get (hoEventIt->ueDeviceIndex),
                                     enbDevices.Get (hoEventIt->sourceEnbDeviceIndex),
                                     enbDevices.Get (hoEventIt->targetEnbDeviceIndex));
@@ -448,30 +446,30 @@ LteX2HandoverTestCase::DoRun ()
                            this,
                            ueNodes.Get (hoEventIt->ueDeviceIndex),
                            enbNodes.Get (m_admitHo ? hoEventIt->targetEnbDeviceIndex
-                                                   : hoEventIt->sourceEnbDeviceIndex));
+                                         : hoEventIt->sourceEnbDeviceIndex));
 
       Time hoEndTime = hoEventIt->startTime + m_maxHoDuration;
-      Simulator::Schedule (hoEndTime, 
-                           &LteX2HandoverTestCase::CheckConnected, 
-                           this, 
-                           ueDevices.Get (hoEventIt->ueDeviceIndex), 
+      Simulator::Schedule (hoEndTime,
+                           &LteX2HandoverTestCase::CheckConnected,
+                           this,
+                           ueDevices.Get (hoEventIt->ueDeviceIndex),
                            enbDevices.Get (m_admitHo ? hoEventIt->targetEnbDeviceIndex : hoEventIt->sourceEnbDeviceIndex));
       Simulator::Schedule (hoEndTime, &LteX2HandoverTestCase::SaveStatsAfterHandover,
                            this, hoEventIt->ueDeviceIndex);
 
       Time checkStatsAfterHoTime = hoEndTime + m_statsDuration;
-      Simulator::Schedule (checkStatsAfterHoTime, &LteX2HandoverTestCase::CheckStatsAWhileAfterHandover, 
-                           this, hoEventIt->ueDeviceIndex);      
+      Simulator::Schedule (checkStatsAfterHoTime, &LteX2HandoverTestCase::CheckStatsAWhileAfterHandover,
+                           this, hoEventIt->ueDeviceIndex);
       if (stopTime <= checkStatsAfterHoTime)
         {
           stopTime = checkStatsAfterHoTime + MilliSeconds (1);
         }
     }
-  
+
   // m_lteHelper->EnableRlcTraces ();
   // m_lteHelper->EnablePdcpTraces();
 
- 
+
   Simulator::Stop (stopTime);
 
   Simulator::Run ();
@@ -480,7 +478,7 @@ LteX2HandoverTestCase::DoRun ()
 
 }
 
-void 
+void
 LteX2HandoverTestCase::CheckConnected (Ptr<NetDevice> ueDevice, Ptr<NetDevice> enbDevice)
 {
   Ptr<LteUeNetDevice> ueLteDevice = ueDevice->GetObject<LteUeNetDevice> ();
@@ -491,7 +489,7 @@ LteX2HandoverTestCase::CheckConnected (Ptr<NetDevice> ueDevice, Ptr<NetDevice> e
   Ptr<LteEnbNetDevice> enbLteDevice = enbDevice->GetObject<LteEnbNetDevice> ();
   Ptr<LteEnbRrc> enbRrc = enbLteDevice->GetRrc ();
   uint16_t rnti = ueRrc->GetRnti ();
-  Ptr<UeManager> ueManager = enbRrc->GetUeManager (rnti);  
+  Ptr<UeManager> ueManager = enbRrc->GetUeManager (rnti);
   NS_TEST_ASSERT_MSG_NE (ueManager, 0, "RNTI " << rnti << " not found in eNB");
 
   UeManager::State ueManagerState = ueManager->GetState ();
@@ -520,16 +518,16 @@ LteX2HandoverTestCase::CheckConnected (Ptr<NetDevice> ueDevice, Ptr<NetDevice> e
 
   ObjectMapValue enbDataRadioBearerMapValue;
   ueManager->GetAttribute ("DataRadioBearerMap", enbDataRadioBearerMapValue);
-  NS_TEST_ASSERT_MSG_EQ (enbDataRadioBearerMapValue.GetN (), m_nDedicatedBearers + 1, "wrong num bearers at eNB");  
+  NS_TEST_ASSERT_MSG_EQ (enbDataRadioBearerMapValue.GetN (), m_nDedicatedBearers + 1, "wrong num bearers at eNB");
 
   ObjectMapValue ueDataRadioBearerMapValue;
   ueRrc->GetAttribute ("DataRadioBearerMap", ueDataRadioBearerMapValue);
-  NS_TEST_ASSERT_MSG_EQ (ueDataRadioBearerMapValue.GetN (), m_nDedicatedBearers + 1, "wrong num bearers at UE"); 
+  NS_TEST_ASSERT_MSG_EQ (ueDataRadioBearerMapValue.GetN (), m_nDedicatedBearers + 1, "wrong num bearers at UE");
 
   ObjectMapValue::Iterator enbBearerIt = enbDataRadioBearerMapValue.Begin ();
   ObjectMapValue::Iterator ueBearerIt = ueDataRadioBearerMapValue.Begin ();
-  while (enbBearerIt != enbDataRadioBearerMapValue.End () &&
-         ueBearerIt != ueDataRadioBearerMapValue.End ())
+  while (enbBearerIt != enbDataRadioBearerMapValue.End ()
+         && ueBearerIt != ueDataRadioBearerMapValue.End ())
     {
       Ptr<LteDataRadioBearerInfo> enbDrbInfo = enbBearerIt->second->GetObject<LteDataRadioBearerInfo> ();
       Ptr<LteDataRadioBearerInfo> ueDrbInfo = ueBearerIt->second->GetObject<LteDataRadioBearerInfo> ();
@@ -539,12 +537,12 @@ LteX2HandoverTestCase::CheckConnected (Ptr<NetDevice> ueDevice, Ptr<NetDevice> e
       //NS_TEST_ASSERT_MSG_EQ (enbDrbInfo->m_rlcConfig, ueDrbInfo->m_rlcConfig, "rlcConfig differs");
       NS_TEST_ASSERT_MSG_EQ ((uint32_t) enbDrbInfo->m_logicalChannelIdentity, (uint32_t) ueDrbInfo->m_logicalChannelIdentity, "logicalChannelIdentity differs");
       //NS_TEST_ASSERT_MSG_EQ (enbDrbInfo->m_logicalChannelConfig, ueDrbInfo->m_logicalChannelConfig, "logicalChannelConfig differs");
- 
+
       ++enbBearerIt;
       ++ueBearerIt;
     }
   NS_ASSERT_MSG (enbBearerIt == enbDataRadioBearerMapValue.End (), "too many bearers at eNB");
-  NS_ASSERT_MSG (ueBearerIt == ueDataRadioBearerMapValue.End (), "too many bearers at UE");  
+  NS_ASSERT_MSG (ueBearerIt == ueDataRadioBearerMapValue.End (), "too many bearers at UE");
 }
 
 void
@@ -564,7 +562,7 @@ LteX2HandoverTestCase::TeleportUeNearTargetEnb (Ptr<Node> ueNode, Ptr<Node> enbN
   ueMobility->SetPosition (pos + Vector (0.0, 100.0, 0.0));
 }
 
-void 
+void
 LteX2HandoverTestCase::SaveStatsAfterHandover (uint32_t ueIndex)
 {
   for (std::list<BearerData>::iterator it = m_ueDataVector.at (ueIndex).bearerDataList.begin ();
@@ -576,18 +574,18 @@ LteX2HandoverTestCase::SaveStatsAfterHandover (uint32_t ueIndex)
     }
 }
 
-void 
+void
 LteX2HandoverTestCase::CheckStatsAWhileAfterHandover (uint32_t ueIndex)
-{      
+{
   uint32_t b = 1;
   for (std::list<BearerData>::iterator it = m_ueDataVector.at (ueIndex).bearerDataList.begin ();
        it != m_ueDataVector.at (ueIndex).bearerDataList.end ();
        ++it)
     {
       uint32_t dlRx = it->dlSink->GetTotalRx () - it->dlOldTotalRx;
-      uint32_t ulRx = it->ulSink->GetTotalRx () - it->ulOldTotalRx;                       
-      uint32_t expectedBytes = m_udpClientPktSize * (m_statsDuration.GetSeconds () / m_udpClientInterval.GetSeconds ());
-
+      uint32_t ulRx = it->ulSink->GetTotalRx () - it->ulOldTotalRx;
+      uint32_t expectedBytes = m_udpClientPktSize * (m_statsDuration / m_udpClientInterval).GetDouble ();
+      
       NS_TEST_ASSERT_MSG_EQ (dlRx, expectedBytes, "too few RX bytes in DL, ue=" << ueIndex << ", b=" << b);
       NS_TEST_ASSERT_MSG_EQ (ulRx, expectedBytes, "too few RX bytes in UL, ue=" << ueIndex << ", b=" << b);
       ++b;
@@ -631,25 +629,25 @@ LteX2HandoverTestSuite::LteX2HandoverTestSuite ()
   ue1fwd.targetEnbDeviceIndex = 1;
 
   HandoverEvent ue1bwd;
-  ue1bwd.startTime = MilliSeconds (400); 
+  ue1bwd.startTime = MilliSeconds (400);
   ue1bwd.ueDeviceIndex = 0;
   ue1bwd.sourceEnbDeviceIndex = 1;
   ue1bwd.targetEnbDeviceIndex = 0;
 
   HandoverEvent ue1fwdagain;
-  ue1fwdagain.startTime = MilliSeconds (700); 
+  ue1fwdagain.startTime = MilliSeconds (700);
   ue1fwdagain.ueDeviceIndex = 0;
   ue1fwdagain.sourceEnbDeviceIndex = 0;
   ue1fwdagain.targetEnbDeviceIndex = 1;
 
   HandoverEvent ue2fwd;
-  ue2fwd.startTime = MilliSeconds (110); 
+  ue2fwd.startTime = MilliSeconds (110);
   ue2fwd.ueDeviceIndex = 1;
   ue2fwd.sourceEnbDeviceIndex = 0;
   ue2fwd.targetEnbDeviceIndex = 1;
 
   HandoverEvent ue2bwd;
-  ue2bwd.startTime = MilliSeconds (350); 
+  ue2bwd.startTime = MilliSeconds (350);
   ue2bwd.ueDeviceIndex = 1;
   ue2bwd.sourceEnbDeviceIndex = 1;
   ue2bwd.targetEnbDeviceIndex = 0;
