@@ -21,7 +21,6 @@
 #ifndef MESH_WIFI_INTERFACE_MAC_PLUGIN_H
 #define MESH_WIFI_INTERFACE_MAC_PLUGIN_H
 
-#include "ns3/wifi-mac-header.h"
 #include "ns3/packet.h"
 #include "ns3/mac48-address.h"
 #include "ns3/mesh-wifi-beacon.h"
@@ -43,10 +42,16 @@ class MeshWifiInterfaceMacPlugin : public SimpleRefCount<MeshWifiInterfaceMacPlu
 public:
   /// This is for subclasses
   virtual ~MeshWifiInterfaceMacPlugin (){};
-  /// Each plugin must be installed on interface to work 
+  /**
+   * Each plugin must be installed on an interface to work
+   *
+   * \param parent the parent object
+   */
   virtual void SetParent (Ptr<MeshWifiInterfaceMac> parent) = 0; 
   /** 
    * \brief Process received frame
+   * \param packet
+   * \param header
    * 
    * \return false if (and only if) frame should be dropped
    * \todo define when MAC call this
@@ -54,13 +59,17 @@ public:
   virtual bool Receive (Ptr<Packet> packet, const WifiMacHeader & header) = 0;
   /**
    * \brief Update frame before it will be forwarded down
-   * 
+   * \param packet
+   * \param header
+   * \param from
+   * \param to
    * \return false if (and only if) frame should be dropped
    * \todo define when MAC call this, preconditions & postconditions
    */
   virtual bool UpdateOutcomingFrame (Ptr<Packet> packet, WifiMacHeader & header, Mac48Address from, Mac48Address to) = 0;
   /**
    * \brief Update beacon before it will be formed and sent
+   * \param beacon
    *
    * \todo define when MAC call this
    */
