@@ -65,6 +65,19 @@ MobilityModel::GetPosition (void) const
 {
   return DoGetPosition ();
 }
+Vector
+MobilityModel::GetPositionWithReference (const Vector& referencePosition) const
+{
+  return DoGetPositionWithReference (referencePosition);
+}
+
+// Default implementation ignores referencePosition
+Vector
+MobilityModel::DoGetPositionWithReference (const Vector& referencePosition) const
+{
+  return DoGetPosition ();
+}
+
 Vector
 MobilityModel::GetVelocity (void) const
 {
