@@ -1,5 +1,7 @@
 /* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /*
+ *  Copyright 2013. Lawrence Livermore National Security, LLC.
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
  * published by the Free Software Foundation;
@@ -13,6 +15,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
+ * Author: Steven Smith <smith84@llnl.gov>
+ */
+
+/**
+ * \file
+ * \ingroup mpi
  *
  * This test is equivalent to simple-distributed but tests boundary cases
  * when one of the ranks has no Nodes on it.   When run on two tasks
@@ -56,21 +64,23 @@
  * right leaf nodes output logging information when they receive the packet.
  */
 
+#include "mpi-test-fixtures.h"
+
 #include "ns3/core-module.h"
 #include "ns3/network-module.h"
 #include "ns3/mpi-interface.h"
 #include "ns3/ipv4-global-routing-helper.h"
 #include "ns3/point-to-point-helper.h"
 #include "ns3/internet-stack-helper.h"
-#include "ns3/ipv4-nix-vector-helper.h"
+#include "ns3/nix-vector-helper.h"
 #include "ns3/ipv4-address-helper.h"
 #include "ns3/on-off-helper.h"
 #include "ns3/packet-sink-helper.h"
-#include <mpi.h>
+#include "mpi.h"
 
 using namespace ns3;
 
-NS_LOG_COMPONENT_DEFINE ("SimpleDistributed");
+NS_LOG_COMPONENT_DEFINE ("SimpleDistributedEmptyNode");
 
 int
 main (int argc, char *argv[])
@@ -78,12 +88,16 @@ main (int argc, char *argv[])
   bool nix = true;
   bool nullmsg = false;
   bool tracing = false;
+  bool testing = false;
+  bool verbose = false;
 
   // Parse command line
   CommandLine cmd (__FILE__);
   cmd.AddValue ("nix", "Enable the use of nix-vector or global routing", nix);
   cmd.AddValue ("nullmsg", "Enable the use of null-message synchronization", nullmsg);
   cmd.AddValue ("tracing", "Enable pcap tracing", tracing);
+  cmd.AddValue ("verbose", "verbose output", verbose);
+  cmd.AddValue ("test", "Enable regression test output", testing);
   cmd.Parse (argc, argv);
 
   // Distributed simulation setup; by default use granted time window algorithm.
@@ -100,8 +114,13 @@ main (int argc, char *argv[])
 
   MpiInterface::Enable (&argc, &argv);
 
-  LogComponentEnable ("PacketSink", LOG_LEVEL_INFO);
-
+  SinkTracer::Init ();
+  
+  if (verbose)
+    {
+      LogComponentEnable ("PacketSink", (LogLevel)(LOG_LEVEL_INFO | LOG_PREFIX_NODE | LOG_PREFIX_TIME));
+    }
+    
   uint32_t systemId = MpiInterface::GetSystemId ();
   uint32_t systemCount = MpiInterface::GetSize ();
 
@@ -258,6 +277,10 @@ main (int argc, char *argv[])
       for (uint32_t i = 0; i < 4; ++i)
         {
           sinkApp.Add (sinkHelper.Install (rightLeafNodes.Get (i)));
+          if (testing)
+            {
+              sinkApp.Get (i)->TraceConnectWithoutContext ("RxWithAddresses", MakeCallback (&SinkTracer::SinkTrace));
+            }
         }
       sinkApp.Start (Seconds (1.0));
       sinkApp.Stop (Seconds (5));
@@ -287,6 +310,12 @@ main (int argc, char *argv[])
   Simulator::Stop (Seconds (5));
   Simulator::Run ();
   Simulator::Destroy ();
+
+  if (testing)
+    {
+      SinkTracer::Verify (4);
+    }
+  
   // Exit the MPI execution environment
   MpiInterface::Disable ();
   return 0;
