@@ -16,9 +16,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  * Author: Steven Smith <smith84@llnl.gov>
- *
  */
 
+/**
+ * \file
+ * \ingroup mpi
+ * Implementation of class ns3::NullMessageSimulatorImpl.
+ */
+
+
 #include "null-message-simulator-impl.h"
 
 #include "null-message-mpi-interface.h"
@@ -369,14 +375,6 @@ NullMessageSimulatorImpl::GetSystemId () const
   return m_myId;
 }
 
-void
-NullMessageSimulatorImpl::RunOneEvent (void)
-{
-  NS_LOG_FUNCTION (this);
-
-  ProcessOneEvent ();
-}
-
 void
 NullMessageSimulatorImpl::Stop (void)
 {
