@@ -400,8 +400,9 @@ void
 Buffer::AddAtEnd (const Buffer &o)
 {
   NS_LOG_FUNCTION (this << &o);
+
   if (m_data->m_count == 1 &&
-      m_end == m_zeroAreaEnd &&
+      (m_end == m_zeroAreaEnd || m_zeroAreaStart == m_zeroAreaEnd) &&
       m_end == m_data->m_dirtyEnd &&
       o.m_start == o.m_zeroAreaStart &&
       o.m_zeroAreaEnd - o.m_zeroAreaStart > 0)
@@ -411,8 +412,12 @@ Buffer::AddAtEnd (const Buffer &o)
        * we attempt to aggregate two buffers which contain
        * adjacent zero areas.
        */
+      if (m_zeroAreaStart == m_zeroAreaEnd)
+        {
+          m_zeroAreaStart = m_end;
+        }
       uint32_t zeroSize = o.m_zeroAreaEnd - o.m_zeroAreaStart;
-      m_zeroAreaEnd += zeroSize;
+      m_zeroAreaEnd = m_end + zeroSize;
       m_end = m_zeroAreaEnd;
       m_data->m_dirtyEnd = m_zeroAreaEnd;
       uint32_t endData = o.m_end - o.m_zeroAreaEnd;
@@ -812,14 +817,10 @@ bool
 Buffer::Iterator::CheckNoZero (uint32_t start, uint32_t end) const
 {
   NS_LOG_FUNCTION (this << &start << &end);
-  for (uint32_t i = start; i < end; i++)
-    {
-      if (!Check (i))
-        {
-          return false;
-        }
-    }
-  return true;
+  return !(start < m_dataStart ||
+           end > m_dataEnd ||
+           (end > m_zeroStart && start < m_zeroEnd && m_zeroEnd != m_zeroStart && start != end)
+           );
 }
 bool 
 Buffer::Iterator::Check (uint32_t i) const
