@@ -118,6 +118,75 @@ public:
    */
   DataRate (std::string rate);
 
+  /**
+   * \return the DataRate representing the sum of this object with rhs
+   * 
+   * \param rhs the DataRate to add to this DataRate
+   */
+  DataRate operator + (DataRate rhs);
+
+  /**
+   * \return the DataRate representing the sum of this object with rhs
+   * 
+   * \param rhs the DataRate to add to this DataRate
+   */
+  DataRate& operator += (DataRate rhs);
+
+  /**
+   * \return the DataRate representing the difference of this object with rhs
+   * 
+   * \param rhs the DataRate to subtract from this DataRate
+   */
+  DataRate operator - (DataRate rhs);
+
+  /**
+   * \return the DataRate representing the difference of this object with rhs
+   * 
+   * \param rhs the DataRate to subtract from this DataRate
+   */
+  DataRate& operator -= (DataRate rhs);
+
+  /**
+   * \brief Scales the DataRate
+   * 
+   * Multiplies with double and is re-casted to an int
+   * 
+   * \return DataRate object representing the product of this object with rhs 
+   * 
+   * \param rhs the double to multiply to this datarate
+   */
+  DataRate operator * (double rhs);
+
+  /**
+   * \brief Scales the DataRate
+   * 
+   * Multiplies with double and is re-casted to an int 
+   * 
+   * \return DataRate object representing the product of this object with rhs
+   * 
+   * \param rhs the double to multipy to this datarate
+   */
+  DataRate& operator *= (double rhs);
+
+  /**
+   * \brief Scales the DataRate
+   * 
+   * \return DataRate object representing the product of this object with rhs
+   * 
+   * \param rhs the uint64_t to multipy to this datarate
+   */
+  DataRate operator * (uint64_t rhs);
+
+  /**
+   * \brief Scales the DataRate
+   * 
+   * \return DataRate object representing the product of this object with rhs
+   * 
+   * \param rhs the uint64_t to multipy to this datarate
+   */
+  DataRate& operator *= (uint64_t rhs);
+
+
   /**
    * \return true if this rate is less than rhs
    *
@@ -248,6 +317,19 @@ double operator* (const DataRate& lhs, const Time& rhs);
  */
 double operator* (const Time& lhs, const DataRate& rhs);
 
+namespace TracedValueCallback {
+
+/**
+ * \ingroup network
+ * TracedValue callback signature for DataRate
+ *
+ * \param [in] oldValue original value of the traced variable
+ * \param [in] newValue new value of the traced variable
+ */
+typedef void (* DataRate)(DataRate oldValue,
+                          DataRate newValue);
+
+}  // namespace TracedValueCallback
 
 } // namespace ns3
 
