@@ -76,19 +76,6 @@ public:
     * \param address C-string containing the address as described above
     */
   void Set (char const *address);
-  /**
-   * \brief Comparison operation between two Ipv4Addresses
-   *
-   * \deprecated Use the == operator (same functionality)
-   *
-   * \param other address to which to compare this address
-   * \return True if the addresses are equal. False otherwise.
-   */
-  NS_DEPRECATED_3_31
-  bool IsEqual (const Ipv4Address &other) const
-  {
-    return m_address == other.m_address;
-  }
   /**
    * Serialize this address to a 4-byte buffer
    *
@@ -289,15 +276,6 @@ public:
    * corresponding to this mask
    */
   bool IsMatch (Ipv4Address a, Ipv4Address b) const;
-  /**
-   *
-   * \deprecated Use the == operator (same functionality)
-   *
-   * \param other a mask to compare 
-   * \return true if the mask equals the mask passed as input parameter
-   */
-  NS_DEPRECATED_3_31
-  bool IsEqual (Ipv4Mask other) const;
   /** 
    * Get the host-order 32-bit IP mask
    * \return the host-order 32-bit IP mask
@@ -396,35 +374,16 @@ std::istream & operator >> (std::istream &is, Ipv4Address &address);
  */
 std::istream & operator >> (std::istream &is, Ipv4Mask &mask);
 
-/**
- * \brief Equal to operator.
- *
- * \param a the first operand
- * \param b the first operand
- * \returns true if the operands are equal
- */
 inline bool operator == (const Ipv4Address &a, const Ipv4Address &b)
 {
   return (a.m_address == b.m_address);
 }
-/**
- * \brief Not equal to operator.
- *
- * \param a the first operand
- * \param b the first operand
- * \returns true if the operands are not equal
- */
+
 inline bool operator != (const Ipv4Address &a, const Ipv4Address &b)
 {
   return (a.m_address != b.m_address);
 }
-/**
- * \brief Less than operator.
- *
- * \param a the first operand
- * \param b the first operand
- * \returns true if the operand a is less than operand b
- */
+
 inline bool operator < (const Ipv4Address &a, const Ipv4Address &b)
 {
   return (a.m_address < b.m_address);
@@ -435,35 +394,24 @@ inline bool operator < (const Ipv4Address &a, const Ipv4Address &b)
  *
  * \brief Class providing an hash for IPv4 addresses
  */
-class Ipv4AddressHash : public std::unary_function<Ipv4Address, size_t> {
+class Ipv4AddressHash {
 public:
   /**
-   * Returns the hash of the address
+   * \brief Returns the hash of an IPv4 address.
    * \param x the address
    * \return the hash
+   *
+   * This method uses std::hash rather than class Hash
+   * as speed is more important than cryptographic robustness.
    */
   size_t operator() (Ipv4Address const &x) const;
 };
 
-/**
- * \brief Equal to operator.
- *
- * \param a the first operand
- * \param b the first operand
- * \returns true if the operands are equal
- */
 inline bool operator == (Ipv4Mask const &a, Ipv4Mask const &b)
 {
   return (a.m_mask == b.m_mask);
 }
 
-/**
- * \brief Not equal to operator.
- *
- * \param a the first operand
- * \param b the first operand
- * \returns true if the operands are not equal
- */
 inline bool operator != (Ipv4Mask const &a, Ipv4Mask const &b)
 {
   return (a.m_mask != b.m_mask);
