@@ -48,7 +48,20 @@ public:
   enum LosConditionValue
   {
     LOS, //!< Line of Sight
-    NLOS //!< Non Line of Sight
+    NLOS, //!< Non Line of Sight
+    NLOSv, //!< Non Line of Sight due to a vehicle
+    LC_ND //!< Los condition not defined
+  };
+  
+  /**
+   * Possible values for Outdoor to Indoor condition.
+   */
+  enum O2iConditionValue
+  {
+    O2O, //!< Outdoor to Outdoor
+    O2I, //!< Outdoor to Indoor
+    I2I, //!< Indoor to Indoor
+    O2I_ND //!< Outdoor to Indoor condition not defined
   };
 
   /**
@@ -62,6 +75,13 @@ public:
    * Constructor for the ChannelCondition class
    */
   ChannelCondition ();
+  
+  /**
+   * Constructor for the ChannelCondition class
+   * \param losCondition the LOS condition value
+   * \param o2iCondition the O2I condition value (by default is set to O2O)
+   */
+  ChannelCondition (LosConditionValue losCondition, O2iConditionValue o2iCondition = O2O);
 
   /**
    * Destructor for the ChannelCondition class
@@ -83,9 +103,89 @@ public:
    * \param the LosConditionValue
    */
   void SetLosCondition (LosConditionValue losCondition);
+  
+  /**
+   * Get the O2iConditionValue contaning the information about the O2I
+   * state of the channel
+   *
+   * \return the O2iConditionValue
+   */
+  O2iConditionValue GetO2iCondition () const;
+
+  /**
+   * Set the O2iConditionValue contaning the information about the O2I
+   * state of the channel
+   *
+   * \param o2iCondition the O2iConditionValue
+   */
+  void SetO2iCondition (O2iConditionValue o2iCondition);
+  
+  /**
+   * Return true if the channel condition is LOS
+   *
+   * \return true if the channel condition is LOS
+   */
+  bool IsLos () const;
+  
+  /**
+   * Return true if the channel condition is NLOS
+   *
+   * It does not consider the case in which the LOS path is obstructed by a 
+   * vehicle. This case is represented as a separate channel condition (NLOSv), 
+   * use the method IsNlosv instead.
+   *
+   * \return true if the channel condition is NLOS
+   */
+  bool IsNlos () const;
+  
+  /**
+   * Return true if the channel condition is NLOSv
+   *
+   * \return true if the channel condition is NLOSv
+   */
+  bool IsNlosv () const;
+  
+  /**
+   * Return true if the channel is outdoor-to-indoor
+   *
+   * \return true if the channel is outdoor-to-indoor
+   */
+  bool IsO2i () const;
+  
+  /**
+   * Return true if the channel is outdoor-to-outdoor
+   *
+   * \return true if the channel is outdoor-to-outdoor
+   */
+  bool IsO2o () const;
+  
+  /**
+   * Return true if the channel is indoor-to-indoor
+   *
+   * \return true if the channel is indoor-to-indoor
+   */
+  bool IsI2i () const;
+  
+  /**
+   * Return true if this instance is equivalent to the one passed as argument
+   *
+   * \param otherCondition the other instance to compare with this instance
+   * \return true if this instance is equivalent to the one passed as argument
+   */
+  bool IsEqual (Ptr<const ChannelCondition> otherCondition) const;
 
 private:
-  LosConditionValue m_losCondition; //!< contains the information about the LOS/NLOS state of the channel
+  LosConditionValue m_losCondition; //!< contains the information about the LOS state of the channel
+  O2iConditionValue m_o2iCondition; //!< contains the information about the O2I state of the channel
+  
+  /** 
+   * Prints a LosConditionValue to output
+   * \param os the output stream
+   * \param cond the LosConditionValue
+   * 
+   * \return a reference to the output stream
+   */
+  friend std::ostream& operator<< (std::ostream& os, LosConditionValue cond);
 
 };
 
@@ -133,7 +233,7 @@ public:
    * 'stream'. Return the number of streams (possibly zero) that
    * have been assigned.
    *
-   * \param stream
+   * \param stream the offset used to set the stream numbers
    * \return the number of stream indices assigned by this model
    */
   virtual int64_t AssignStreams (int64_t stream) = 0;
@@ -170,12 +270,12 @@ public:
   static TypeId GetTypeId (void);
 
   /**
-   * Constructor for the ChannelConditionModel class
+   * Constructor
    */
   AlwaysLosChannelConditionModel ();
 
   /**
-   * Destructor for the ChannelConditionModel class
+   * Destructor
    */
   virtual ~AlwaysLosChannelConditionModel ();
 
@@ -199,7 +299,7 @@ public:
   * \brief Copy constructor
   *
   * Defined and unimplemented to avoid misuse
-  * \returns
+  * \returns a copy of the object
   */
   AlwaysLosChannelConditionModel &operator = (const AlwaysLosChannelConditionModel &) = delete;
 
@@ -209,7 +309,7 @@ public:
    * 'stream'. Return the number of streams (possibly zero) that
    * have been assigned.
    *
-   * \param stream
+   * \param stream the offset used to set the stream numbers
    * \return the number of stream indices assigned by this model
    */
   virtual int64_t AssignStreams (int64_t stream) override;
@@ -231,12 +331,12 @@ public:
   static TypeId GetTypeId (void);
 
   /**
-   * Constructor for the ChannelConditionModel class
+   * Constructor
    */
   NeverLosChannelConditionModel ();
 
   /**
-   * Destructor for the ChannelConditionModel class
+   * Destructor
    */
   virtual ~NeverLosChannelConditionModel ();
 
@@ -260,7 +360,7 @@ public:
   * \brief Copy constructor
   *
   * Defined and unimplemented to avoid misuse
-  * \returns
+  * \returns a copy of the object
   */
   NeverLosChannelConditionModel &operator = (const NeverLosChannelConditionModel &) = delete;
 
@@ -270,7 +370,68 @@ public:
    * 'stream'. Return the number of streams (possibly zero) that
    * have been assigned.
    *
-   * \param stream
+   * \param stream the offset used to set the stream numbers
+   * \return the number of stream indices assigned by this model
+   */
+  virtual int64_t AssignStreams (int64_t stream) override;
+};
+
+/**
+ * \ingroup propagation
+ *
+ * \brief Models a never in-LoS condition model caused by a blocking vehicle
+ */
+class NeverLosVehicleChannelConditionModel : public ChannelConditionModel
+{
+public:
+  /**
+   * Get the type ID.
+   * \brief Get the type ID.
+   * \return the object TypeId
+   */
+  static TypeId GetTypeId (void);
+
+  /**
+   * Constructor 
+   */
+  NeverLosVehicleChannelConditionModel ();
+
+  /**
+   * Destructor 
+   */
+  virtual ~NeverLosVehicleChannelConditionModel ();
+
+  /**
+   * Computes the condition of the channel between a and b, that will be always NLOSv
+   *
+   * \param a mobility model
+   * \param b mobility model
+   * \return the condition of the channel between a and b, that will be always NLOSv
+   */
+  virtual Ptr<ChannelCondition> GetChannelCondition (Ptr<const MobilityModel> a, Ptr<const MobilityModel> b) const override;
+
+  /**
+  * \brief Copy constructor
+  *
+  * Defined and unimplemented to avoid misuse
+  */
+  NeverLosVehicleChannelConditionModel (const NeverLosVehicleChannelConditionModel&) = delete;
+
+  /**
+  * \brief Copy constructor
+  *
+  * Defined and unimplemented to avoid misuse
+  * \returns a copy of the object
+  */
+  NeverLosVehicleChannelConditionModel &operator = (const NeverLosVehicleChannelConditionModel &) = delete;
+
+  /**
+   * If this  model uses objects of type RandomVariableStream,
+   * set the stream numbers to the integers starting with the offset
+   * 'stream'. Return the number of streams (possibly zero) that
+   * have been assigned.
+   *
+   * \param stream the offset used to set the stream numbers
    * \return the number of stream indices assigned by this model
    */
   virtual int64_t AssignStreams (int64_t stream) override;
@@ -305,9 +466,9 @@ public:
   /**
    * \brief Retrieve the condition of the channel between a and b.
    *
-   * If the channel condition does not exists, the method creates it and
-   * store it in a local cache, that will be updated following the "UpdatePeriod"
-   * parameter.
+   * If the channel condition does not exists, the method computes it by calling 
+   * ComputeChannelCondition and stores it in a local cache, that will be updated 
+   * following the "UpdatePeriod" parameter.
    *
    * \param a mobility model
    * \param b mobility model
@@ -321,7 +482,7 @@ public:
    * 'stream'. Return the number of streams (possibly zero) that
    * have been assigned.
    *
-   * \param stream
+   * \param stream the offset used to set the stream numbers
    * \return the number of stream indices assigned by this model
    */
   virtual int64_t AssignStreams (int64_t stream) override;
@@ -329,6 +490,17 @@ public:
 protected:
   virtual void DoDispose () override;
   
+  /**
+   * Determine the density of vehicles in a V2V scenario.
+   */
+  enum VehicleDensity
+  {
+    LOW,
+    MEDIUM,
+    HIGH,
+    INVALID
+  };
+
   /**
   * \brief Computes the 2D distance between two 3D vectors
   * \param a the first 3D vector
@@ -336,16 +508,37 @@ protected:
   * \return the 2D distance between a and b
   */
   static double Calculate2dDistance (const Vector &a, const Vector &b);
+  
+  Ptr<UniformRandomVariable> m_uniformVar; //!< uniform random variable
 
 private:
   /**
-   * Compute the LOS probability as specified in Table 7.4.2-1 of 3GPP TR 38.901.
+  * This method computes the channel condition based on a probabilistic model 
+  * that is specific for the scenario of interest
+  *
+  * \param a tx mobility model
+  * \param b rx mobility model
+  * \return the channel condition
+  */
+  Ptr<ChannelCondition> ComputeChannelCondition (Ptr<const MobilityModel> a, Ptr<const MobilityModel> b) const;
+  
+  /**
+   * Compute the LOS probability.
    *
    * \param a tx mobility model
    * \param b rx mobility model
    * \return the LOS probability
    */
   virtual double ComputePlos (Ptr<const MobilityModel> a, Ptr<const MobilityModel> b) const = 0;
+  
+  /**
+   * Compute the NLOS probability. By default returns 1 - PLOS
+   *
+   * \param a tx mobility model
+   * \param b rx mobility model
+   * \return the LOS probability
+   */
+  virtual double ComputePnlos (Ptr<const MobilityModel> a, Ptr<const MobilityModel> b) const;
 
   /**
    * \brief Returns a unique and reciprocal key for the channel between a and b.
@@ -366,7 +559,6 @@ private:
 
   std::unordered_map<uint32_t, Item> m_channelConditionMap; //!< map to store the channel conditions
   Time m_updatePeriod; //!< the update period for the channel condition
-  Ptr<UniformRandomVariable> m_uniformVar; //!< uniform random variable
 };
 
 /**
