@@ -793,6 +793,7 @@ SixLowPanIphc::SixLowPanIphc ()
 {
   // 011x xxxx xxxx xxxx
   m_baseFormat = 0x6000;
+  m_srcdstContextId = 0;
 }
 
 SixLowPanIphc::SixLowPanIphc (uint8_t dispatch)
@@ -800,6 +801,7 @@ SixLowPanIphc::SixLowPanIphc (uint8_t dispatch)
   // 011x xxxx xxxx xxxx
   m_baseFormat = dispatch;
   m_baseFormat <<= 8;
+  m_srcdstContextId = 0;
 }
 
 TypeId SixLowPanIphc::GetTypeId (void)
@@ -818,7 +820,48 @@ TypeId SixLowPanIphc::GetInstanceTypeId (void) const
 
 void SixLowPanIphc::Print (std::ostream & os) const
 {
-  os << "Compression kind: " << +m_baseFormat;
+  switch ( GetTf () )
+    {
+    case TF_FULL:
+      os << "TF_FULL(" << +m_ecn << ", " << +m_dscp << ", " << m_flowLabel << ")";
+      break;
+    case TF_DSCP_ELIDED:
+      os << "TF_DSCP_ELIDED(" << +m_ecn << ", " << m_flowLabel << ")";
+      break;
+    case TF_FL_ELIDED:
+      os << "TF_FL_ELIDED(" << +m_ecn << ", " << +m_dscp << ")";
+      break;
+    default:
+      os << "TF_ELIDED";
+      break;
+    }
+
+  GetNh () ? os << " NH(1)" : os << " NH(0)";
+
+  switch ( GetHlim () )
+    {
+    case HLIM_INLINE:
+      os << " HLIM_INLINE(" << +m_hopLimit << ")";
+      break;
+    case HLIM_COMPR_1:
+      os << " HLIM_COMPR_1(1)";
+      break;
+    case HLIM_COMPR_64:
+      os << " HLIM_COMPR_64(64)";
+      break;
+    default:
+      os << " HLIM_COMPR_255(255)";
+      break;
+    }
+
+  GetCid () ? os << " CID(" << +m_srcdstContextId << ")" : os << " CID(0)";
+
+  GetSac () ? os << " SAC(1)" : os << " SAC(0)";
+  os << " SAM (" << GetSam () << ")";
+
+  GetM () ? os << " M(1)" : os << " M(0)";
+  GetDac () ? os << " DAC(1)" : os << " DAC(0)";
+  os << " DAM (" << GetDam () << ")";
 }
 
 uint32_t SixLowPanIphc::GetSerializedSize () const
@@ -983,22 +1026,17 @@ void SixLowPanIphc::Serialize (Buffer::Iterator start) const
   // Source Address
   switch (GetSam () )
     {
-      uint8_t temp[16];
     case HC_INLINE:
       if ( GetSac () == false )
         {
-          uint8_t temp[16];
-          m_srcAddress.Serialize (temp);
-          i.Write (temp, 16);
+          i.Write (m_srcInlinePart, 16);
         }
       break;
     case HC_COMPR_64:
-      m_srcAddress.Serialize (temp);
-      i.Write (temp + 8, 8);
+      i.Write (m_srcInlinePart, 8);
       break;
     case HC_COMPR_16:
-      m_srcAddress.Serialize (temp);
-      i.Write (temp + 14, 2);
+      i.Write (m_srcInlinePart, 2);
       break;
     case HC_COMPR_0:
     default:
@@ -1007,23 +1045,17 @@ void SixLowPanIphc::Serialize (Buffer::Iterator start) const
   // Destination Address
   if ( GetM () == false)
     {
-      uint8_t temp[16];
+      // unicast
       switch (GetDam () )
         {
         case HC_INLINE:
-          if ( GetDac () == false )
-            {
-              m_dstAddress.Serialize (temp);
-              i.Write (temp, 16);
-            }
+          i.Write (m_dstInlinePart, 16);
           break;
         case HC_COMPR_64:
-          m_dstAddress.Serialize (temp);
-          i.Write (temp + 8, 8);
+          i.Write (m_dstInlinePart, 8);
           break;
         case HC_COMPR_16:
-          m_dstAddress.Serialize (temp);
-          i.Write (temp + 14, 2);
+          i.Write (m_dstInlinePart, 2);
           break;
         case HC_COMPR_0:
         default:
@@ -1032,45 +1064,22 @@ void SixLowPanIphc::Serialize (Buffer::Iterator start) const
     }
   else
     {
+      // multicast
       switch (GetDam () )
         {
-          uint8_t temp[16];
         case HC_INLINE:
-          if ( GetDac () == false )
-            {
-              m_dstAddress.Serialize (temp);
-              i.Write (temp, 16);
-            }
-          else
-            {
-              m_dstAddress.Serialize (temp);
-              i.Write (temp + 1, 2);
-              i.Write (temp + 12, 4);
-            }
+          i.Write (m_dstInlinePart, 16);
           break;
         case HC_COMPR_64:
-          if ( GetDac () == false )
-            {
-              m_dstAddress.Serialize (temp);
-              i.Write (temp + 1, 1);
-              i.Write (temp + 11, 5);
-            }
+          i.Write (m_dstInlinePart, 6);
           break;
         case HC_COMPR_16:
-          if ( GetDac () == false )
-            {
-              m_dstAddress.Serialize (temp);
-              i.Write (temp + 1, 1);
-              i.Write (temp + 13, 3);
-            }
+          i.Write (m_dstInlinePart, 4);
           break;
         case HC_COMPR_0:
-        default:
-          if ( GetDac () == false )
-            {
-              m_dstAddress.Serialize (temp);
-              i.WriteU8 (temp[15]);
-            }
+          i.Write (m_dstInlinePart, 1);
+          break;
+       default:
           break;
         }
     }
@@ -1086,6 +1095,10 @@ uint32_t SixLowPanIphc::Deserialize (Buffer::Iterator start)
     {
       m_srcdstContextId = i.ReadU8 ();
     }
+  else
+    {
+      m_srcdstContextId = 0;
+    }
   // Traffic Class and Flow Label
   switch ( GetTf () )
     {
@@ -1142,68 +1155,41 @@ uint32_t SixLowPanIphc::Deserialize (Buffer::Iterator start)
 
     }
   // Source Address
+  memset (m_srcInlinePart, 0x00, sizeof (m_srcInlinePart));
   switch (GetSam () )
     {
-      uint8_t temp[16];
     case HC_INLINE:
       if ( GetSac () == false )
         {
-          i.Read (temp, 16);
-          m_srcAddress = Ipv6Address::Deserialize (temp);
+          i.Read (m_srcInlinePart, 16);
         }
       break;
     case HC_COMPR_64:
-      memset (temp, 0x00, sizeof (temp));
-      i.Read (temp + 8, 8);
-      temp[0] = 0xfe;
-      temp[1] = 0x80;
-      m_srcAddress = Ipv6Address::Deserialize (temp);
+      i.Read (m_srcInlinePart, 8);
       break;
     case HC_COMPR_16:
-      memset (temp, 0x00, sizeof (temp));
-      i.Read (temp + 14, 2);
-      temp[0] = 0xfe;
-      temp[1] = 0x80;
-      temp[11] = 0xff;
-      temp[12] = 0xfe;
-      m_srcAddress = Ipv6Address::Deserialize (temp);
+      i.Read (m_srcInlinePart, 2);
       break;
     case HC_COMPR_0:
     default:
       break;
     }
-  if ( GetSac () == true )
-    {
-      PostProcessSac ();
-    }
+
   // Destination Address
+  memset (m_dstInlinePart, 0x00, sizeof (m_dstInlinePart));
   if ( GetM () == false)
     {
-      uint8_t temp[16];
+      // unicast
       switch (GetDam () )
         {
         case HC_INLINE:
-          if ( GetDac () == false )
-            {
-              i.Read (temp, 16);
-              m_dstAddress = Ipv6Address::Deserialize (temp);
-            }
+          i.Read (m_dstInlinePart, 16);
           break;
         case HC_COMPR_64:
-          memset (temp, 0x00, sizeof (temp));
-          i.Read (temp + 8, 8);
-          temp[0] = 0xfe;
-          temp[1] = 0x80;
-          m_dstAddress = Ipv6Address::Deserialize (temp);
+          i.Read (m_dstInlinePart, 8);
           break;
         case HC_COMPR_16:
-          memset (temp, 0x00, sizeof (temp));
-          i.Read (temp + 14, 2);
-          temp[0] = 0xfe;
-          temp[1] = 0x80;
-          temp[11] = 0xff;
-          temp[12] = 0xfe;
-          m_dstAddress = Ipv6Address::Deserialize (temp);
+          i.Read (m_dstInlinePart, 2);
           break;
         case HC_COMPR_0:
         default:
@@ -1212,61 +1198,26 @@ uint32_t SixLowPanIphc::Deserialize (Buffer::Iterator start)
     }
   else
     {
+      // multicast
       switch (GetDam () )
         {
-          uint8_t temp[16];
         case HC_INLINE:
-          if ( GetDac () == false )
-            {
-              i.Read (temp, 16);
-              m_dstAddress = Ipv6Address::Deserialize (temp);
-            }
-          else
-            {
-              memset (temp, 0x00, sizeof (temp));
-              i.Read (temp + 1, 2);
-              i.Read (temp + 12, 4);
-              temp[0] = 0xff;
-              m_dstAddress = Ipv6Address::Deserialize (temp);
-            }
+          i.Read (m_dstInlinePart, 16);
           break;
         case HC_COMPR_64:
-          if ( GetDac () == false )
-            {
-              memset (temp, 0x00, sizeof (temp));
-              i.Read (temp + 1, 1);
-              i.Read (temp + 11, 5);
-              temp[0] = 0xff;
-              m_dstAddress = Ipv6Address::Deserialize (temp);
-            }
+          i.Read (m_dstInlinePart, 6);
           break;
         case HC_COMPR_16:
-          if ( GetDac () == false )
-            {
-              memset (temp, 0x00, sizeof (temp));
-              i.Read (temp + 1, 1);
-              i.Read (temp + 13, 3);
-              temp[0] = 0xff;
-              m_dstAddress = Ipv6Address::Deserialize (temp);
-            }
+          i.Read (m_dstInlinePart, 4);
           break;
         case HC_COMPR_0:
+          i.Read (m_dstInlinePart, 1);
+          break;
         default:
-          if ( GetDac () == false )
-            {
-              memset (temp, 0x00, sizeof (temp));
-              temp[15] = i.ReadU8 ();
-              temp[0] = 0xff;
-              temp[1] = 0x02;
-              m_dstAddress = Ipv6Address::Deserialize (temp);
-            }
           break;
         }
     }
-  if ( GetDac () == true )
-    {
-      PostProcessDac ();
-    }
+
   return GetSerializedSize ();
 }
 
@@ -1336,6 +1287,19 @@ SixLowPanIphc::HeaderCompression_e SixLowPanIphc::GetSam (void) const
   return HeaderCompression_e ((m_baseFormat >> 4) & 0x3);
 }
 
+const uint8_t* SixLowPanIphc::GetSrcInlinePart (void) const
+{
+  return m_srcInlinePart;
+}
+
+void SixLowPanIphc::SetSrcInlinePart (uint8_t srcInlinePart[16], uint8_t size)
+{
+  NS_ASSERT_MSG (size <= 16,  "Src inline part too large");
+
+  memcpy (m_srcInlinePart, srcInlinePart, size);
+  return;
+}
+
 void SixLowPanIphc::SetM (bool mField)
 {
   uint16_t field = mField;
@@ -1369,6 +1333,19 @@ SixLowPanIphc::HeaderCompression_e SixLowPanIphc::GetDam (void) const
   return HeaderCompression_e (m_baseFormat & 0x3);
 }
 
+const uint8_t* SixLowPanIphc::GetDstInlinePart (void) const
+{
+  return m_dstInlinePart;
+}
+
+void SixLowPanIphc::SetDstInlinePart (uint8_t dstInlinePart[16], uint8_t size)
+{
+  NS_ASSERT_MSG (size <= 16,  "Dst inline part too large");
+
+  memcpy (m_dstInlinePart, dstInlinePart, size);
+  return;
+}
+
 void SixLowPanIphc::SetSrcContextId (uint8_t srcContextId)
 {
   NS_ASSERT_MSG (srcContextId < 16,  "Src Context ID too large");
@@ -1444,38 +1421,6 @@ uint8_t SixLowPanIphc::GetHopLimit (void) const
   return m_hopLimit;
 }
 
-void SixLowPanIphc::SetSrcAddress (Ipv6Address srcAddress)
-{
-  m_srcAddress = srcAddress;
-}
-
-Ipv6Address SixLowPanIphc::GetSrcAddress () const
-{
-  return m_srcAddress;
-}
-
-void SixLowPanIphc::SetDstAddress (Ipv6Address dstAddress)
-{
-  m_dstAddress = dstAddress;
-}
-
-Ipv6Address SixLowPanIphc::GetDstAddress () const
-{
-  return m_dstAddress;
-}
-
-void SixLowPanIphc::PostProcessSac ()
-{
-  NS_ABORT_MSG ("Unsupported; Context destination is not implemented");
-  return;
-}
-
-void SixLowPanIphc::PostProcessDac ()
-{
-  NS_ABORT_MSG ("Unsupported; Context destination is not implemented");
-  return;
-}
-
 std::ostream & operator << (std::ostream & os, const SixLowPanIphc & h)
 {
   h.Print (os);
