@@ -70,9 +70,11 @@ public:
    */
   enum DropReason
   {
-    DROP_FRAGMENT_TIMEOUT = 1, /**< Fragment timeout exceeded */
-    DROP_FRAGMENT_BUFFER_FULL, /**< Fragment buffer size exceeded */
-    DROP_UNKNOWN_EXTENSION /**< Unsupported compression kind */
+    DROP_FRAGMENT_TIMEOUT = 1,    /**< Fragment timeout exceeded */
+    DROP_FRAGMENT_BUFFER_FULL,    /**< Fragment buffer size exceeded */
+    DROP_UNKNOWN_EXTENSION,       /**< Unsupported compression kind */
+    DROP_DISALLOWED_COMPRESSION,  /**< HC1 while in IPHC mode or viceversa */
+    DROP_SATETFUL_DECOMPRESSION_PROBLEM, /**< Decompression failed due to missing or expired context */
   };
 
   /**
@@ -161,7 +163,7 @@ public:
                                       uint32_t ifindex);
 
   /**
-   * TracedCallback signature for
+   * TracedCallback signature fo packet drop events
    *
    * \param [in] reason The reason for the drop.
    * \param [in] packet The packet.
@@ -176,6 +178,58 @@ public:
                                       Ptr<SixLowPanNetDevice> sixNetDevice,
                                       uint32_t ifindex);
 
+  /**
+   * Add, remove, or update a context used in IPHC stateful compression.
+   *
+   * A context with a zero validLifetime will be immediately removed.
+   *
+   * \param [in] contextId context id (most be between 0 and 15 included).
+   * \param [in] contextPrefix context prefix to be used in compression/decompression.
+   * \param [in] compressionAllowed compression and decompression allowed (true), decompression only (false).
+   * \param [in] validLifetime validity time (relative to the actual time).
+   *
+   */
+  void AddContext (uint8_t contextId, Ipv6Prefix contextPrefix, bool compressionAllowed, Time validLifetime);
+
+  /**
+   * Get a context used in IPHC stateful compression.
+   *
+   * \param [in] contextId context id (most be between 0 and 15 included).
+   * \param [out] contextPrefix context prefix to be used in compression/decompression.
+   * \param [out] compressionAllowed compression and decompression allowed (true), decompression only (false).
+   * \param [out] validLifetime validity time (relative to the actual time).
+   *
+   * \return false if the context has not been found.
+   *
+   */
+  bool GetContext (uint8_t contextId, Ipv6Prefix& contextPrefix, bool& compressionAllowed, Time& validLifetime);
+
+  /**
+   * Renew a context used in IPHC stateful compression.
+   *
+   * The context will have its lifetime extended and its validity for compression re-enabled.
+   *
+   * \param [in] contextId context id (most be between 0 and 15 included).
+   * \param [in] validLifetime validity time (relative to the actual time).
+   */
+  void RenewContext (uint8_t contextId, Time validLifetime);
+
+  /**
+   * Invalidate a context used in IPHC stateful compression.
+   *
+   * An invalid context will not be used for compression but it will be used for decompression.
+   *
+   * \param [in] contextId context id (most be between 0 and 15 included).
+   */
+  void InvalidateContext (uint8_t contextId);
+
+  /**
+   * Remove a context used in IPHC stateful compression.
+   *
+   * \param [in] contextId context id (most be between 0 and 15 included).
+   */
+  void RemoveContext (uint8_t contextId);
+
 protected:
   virtual void DoDispose (void);
 
@@ -201,7 +255,6 @@ private:
    * \param [in] source The source address.
    * \param [in] destination The destination address.
    * \param [in] packetType The packet kind (e.g., HOST, BROADCAST, etc.).
-   * \return The IPv6 link-local address.
    */
   void ReceiveFromDevice (Ptr<NetDevice> device, Ptr<const Packet> packet, uint16_t protocol,
                           Address const &source, Address const &destination, PacketType packetType);
@@ -311,8 +364,9 @@ private:
    * \param [in] packet The packet to be compressed.
    * \param [in] src The MAC source address.
    * \param [in] dst The MAC destination address.
+   * \return true if the packet can not be decompressed due to wrong context informations.
    */
-  void DecompressLowPanIphc (Ptr<Packet> packet, Address const &src, Address const &dst);
+  bool DecompressLowPanIphc (Ptr<Packet> packet, Address const &src, Address const &dst);
 
   /**
    * \brief Compress the headers according to NHC compression.
@@ -331,9 +385,9 @@ private:
    * \param [in] dst The MAC destination address.
    * \param [in] srcAddress The IPv6 source address.
    * \param [in] dstAddress The IPv6 destination address.
-   * \return The decompressed header type.
+   * \return A std::pair containing the decompressed header type and a flag - true if the packet can not be decompressed due to wrong context informations.
    */
-  uint8_t DecompressLowPanNhc (Ptr<Packet> packet, Address const &src, Address const &dst, Ipv6Address srcAddress, Ipv6Address dstAddress);
+  std::pair<uint8_t, bool> DecompressLowPanNhc (Ptr<Packet> packet, Address const &src, Address const &dst, Ipv6Address srcAddress, Ipv6Address dstAddress);
 
   /**
    * \brief Compress the headers according to NHC compression.
@@ -471,9 +525,10 @@ private:
    * \param [in] packet the packet to be fragmented (with headers already compressed with 6LoWPAN).
    * \param [in] origPacketSize the size of the IP packet before the 6LoWPAN header compression, including the IP/L4 headers.
    * \param [in] origHdrSize the size of the IP header before the 6LoWPAN header compression.
+   * \param [in] extraHdrSize the sum of the sizes of BC0 header and MESH header if mesh routing is used or 0.
    * \param [out] listFragments A reference to the list of the resulting packets, all with the proper headers in place.
    */
-  void DoFragmentation (Ptr<Packet> packet, uint32_t origPacketSize, uint32_t origHdrSize,
+  void DoFragmentation (Ptr<Packet> packet, uint32_t origPacketSize, uint32_t origHdrSize, uint32_t extraHdrSize,
                         std::list<Ptr<Packet> >& listFragments);
 
   /**
@@ -548,6 +603,48 @@ private:
   uint32_t m_compressionThreshold; //!< Minimum L2 payload size.
 
   Ptr<UniformRandomVariable> m_rng; //!< Rng for the fragments tag.
+
+  /**
+   * Structure holding the informations for a context (used in compression and decompression)
+   */
+  struct ContextEntry
+  {
+    Ipv6Prefix contextPrefix;    //!< context prefix to be used in compression/decompression
+    bool compressionAllowed;     //!< compression and decompression allowed (true), decompression only (false)
+    Time validLifetime;          //!< validity period
+  };
+
+  std::map<uint8_t, ContextEntry> m_contextTable; //!< Table of the contexts used in compression/decompression
+
+  /**
+   * \brief Finds if the given unicast address matches a context for compression
+   *
+   * \param[in] address the address to check
+   * \param[out] contextId the context found
+   * \return true if a valid context has been found
+   */
+  bool FindUnicastCompressionContext (Ipv6Address address, uint8_t& contextId);
+
+  /**
+   * \brief Finds if the given multicast address matches a context for compression
+   *
+   * \param[in] address the address to check
+   * \param[out] contextId the context found
+   * \return true if a valid context has been found
+   */
+  bool FindMulticastCompressionContext (Ipv6Address address, uint8_t& contextId);
+
+  /**
+   * \brief Clean an address from its prefix.
+   *
+   * This function is used to find the relevant bits to be sent in stateful IPHC compression.
+   * Only the pefix length is used - the address prefix is assumed to be matching the prefix.
+   *
+   * \param address the address to be cleaned
+   * \param prefix the prefix to remove
+   * \return An address with the prefix zeroed.
+   */
+  Ipv6Address CleanPrefix (Ipv6Address address, Ipv6Prefix prefix);
 };
 
 } // namespace ns3
