@@ -41,7 +41,7 @@ using namespace ns3;
  */
 int main (int argc, char** argv)
 {
-  CommandLine cmd;
+  CommandLine cmd (__FILE__);
   cmd.Parse (argc, argv);
   
   /* nodes and positions */
