@@ -102,10 +102,10 @@ public:
   void SetChannel (Ptr<SpectrumChannel> c);
   void SetMobility (Ptr<MobilityModel> m);
   void SetDevice (Ptr<NetDevice> d);
-  Ptr<MobilityModel> GetMobility ();
+  Ptr<MobilityModel> GetMobility () const;
   Ptr<NetDevice> GetDevice () const;
   Ptr<const SpectrumModel> GetRxSpectrumModel () const;
-  Ptr<AntennaModel> GetRxAntenna ();
+  Ptr<AntennaModel> GetRxAntenna () const;
   void StartRx (Ptr<SpectrumSignalParameters> params);
 
 
