@@ -33,7 +33,7 @@ namespace ns3 {
 /**
  * \ingroup spectrum
  *
- * @brief SpectrumChannel implementation which handles a single spectrum model
+ * \brief SpectrumChannel implementation which handles a single spectrum model
  *
  * All SpectrumPhy layers attached to this SpectrumChannel
  */
@@ -50,34 +50,25 @@ public:
   static TypeId GetTypeId (void);
 
   // inherited from SpectrumChannel
-  virtual void AddPropagationLossModel (Ptr<PropagationLossModel> loss);
-  virtual void AddSpectrumPropagationLossModel (Ptr<SpectrumPropagationLossModel> loss);
-  virtual void SetPropagationDelayModel (Ptr<PropagationDelayModel> delay);
   virtual void AddRx (Ptr<SpectrumPhy> phy);
   virtual void StartTx (Ptr<SpectrumSignalParameters> params);
 
 
   // inherited from Channel
-  virtual uint32_t GetNDevices (void) const;
-  virtual Ptr<NetDevice> GetDevice (uint32_t i) const;
+  virtual std::size_t GetNDevices (void) const;
+  virtual Ptr<NetDevice> GetDevice (std::size_t i) const;
 
   /// Container: SpectrumPhy objects
   typedef std::vector<Ptr<SpectrumPhy> > PhyList;
 
-  /**
-   * Get the frequency-dependent propagation loss model.
-   * \returns a pointer to the propagation loss model.
-   */
-  virtual Ptr<SpectrumPropagationLossModel> GetSpectrumPropagationLossModel (void);
-
 private:
   virtual void DoDispose ();
 
   /**
    * Used internally to reschedule transmission after the propagation delay.
    *
-   * @param params
-   * @param receiver
+   * \param params
+   * \param receiver
    */
   void StartRx (Ptr<SpectrumSignalParameters> params, Ptr<SpectrumPhy> receiver);
 
@@ -91,43 +82,8 @@ private:
    */
   Ptr<const SpectrumModel> m_spectrumModel;
 
-
-  /**
-   * Propagation delay model to be used with this channel.
-   */
-  Ptr<PropagationDelayModel> m_propagationDelay;
-
-
-  /**
-   * Single-frequency propagation loss model to be used with this channel.
-   */
-  Ptr<PropagationLossModel> m_propagationLoss;
-
-  /**
-   * Frequency-dependent propagation loss model to be used with this channel.
-   */
-  Ptr<SpectrumPropagationLossModel> m_spectrumPropagationLoss;
-
-
-  /**
-   * Maximum loss [dB].
-   *
-   * Any device above this loss is considered out of range.
-   */
-  double m_maxLossDb;
-
-  /**
-   * \deprecated The non-const \c Ptr<SpectrumPhy> argument
-   * is deprecated and will be changed to \c Ptr<const SpectrumPhy>
-   * in a future release.
-   */
-  TracedCallback<Ptr<SpectrumPhy>, Ptr<SpectrumPhy>, double > m_pathLossTrace;
 };
 
-
-
 }
 
-
-
 #endif /* SINGLE_MODEL_SPECTRUM_CHANNEL_H */
