@@ -92,7 +92,7 @@ void
 Emitter::Count (void)
 {
   NS_LOG_FUNCTION (this);
-  NS_LOG_DEBUG ("Counting at " << Simulator::Now ().GetSeconds ());
+  NS_LOG_DEBUG ("Counting at " << Simulator::Now ().As (Time::S));
   m_counter += 1.0;
   Simulator::Schedule (Seconds (m_var->GetValue ()), &Emitter::Count, this);
 }
