@@ -34,6 +34,12 @@
 
 using namespace ns3;
 
+/**
+ * \ingroup wifi-test
+ * \ingroup tests
+ *
+ * \brief Throughput test for MsduAggregator
+ */
 class WifiMsduAggregatorThroughputTest : public TestCase
 {
 public:
@@ -41,7 +47,7 @@ public:
   virtual void DoRun (void);
 
 private:
-  bool m_writeResults;
+  bool m_writeResults; //!< flag whether to generate pcap
 };
 
 WifiMsduAggregatorThroughputTest::WifiMsduAggregatorThroughputTest ()
@@ -55,7 +61,7 @@ WifiMsduAggregatorThroughputTest::DoRun (void)
 {
   WifiHelper wifi;
   WifiMacHelper wifiMac;
-  YansWifiPhyHelper wifiPhy = YansWifiPhyHelper::Default ();
+  YansWifiPhyHelper wifiPhy;
   YansWifiChannelHelper wifiChannel = YansWifiChannelHelper::Default ();
   wifiPhy.SetChannel (wifiChannel.Create ());
 
@@ -65,7 +71,7 @@ WifiMsduAggregatorThroughputTest::DoRun (void)
   // less), but this approach tests the bit we need to without unduly
   // increasing the complexity of the simulation.
   std::string phyMode ("DsssRate1Mbps");
-  wifi.SetStandard (WIFI_PHY_STANDARD_80211b);
+  wifi.SetStandard (WIFI_STANDARD_80211b);
   wifi.SetRemoteStationManager ("ns3::ConstantRateWifiManager",
                                 "DataMode", StringValue (phyMode),
                                 "ControlMode", StringValue (phyMode));
@@ -150,6 +156,7 @@ WifiMsduAggregatorThroughputTest::DoRun (void)
   // Enable tracing at the AP
   if (m_writeResults)
     {
+      wifiPhy.SetPcapDataLinkType (WifiPhyHelper::DLT_IEEE802_11_RADIO);
       wifiPhy.EnablePcap ("wifi-amsdu-throughput", sta.Get (0)->GetId (), 0);
     }
 
@@ -181,9 +188,16 @@ WifiMsduAggregatorThroughputTest::DoRun (void)
 }
 
 
-// For now the MSDU Aggregator Test Suite contains only the one test
-// that is defined in this file, so it's class definition and
-// instantiation can live here.
+/**
+ * \ingroup wifi-test
+ * \ingroup tests
+ *
+ * \brief MsduAggregator Test Suite
+ *
+ * For now the MSDU Aggregator Test Suite contains only the one test
+ * that is defined in this file, so it's class definition and
+ * instantiation can live here.
+ */
 class WifiMsduAggregatorTestSuite : public TestSuite
 {
 public:
