@@ -66,24 +66,6 @@ public:
   static constexpr const char* LIMIT_EXCEEDED_DROP = "Queue disc limit exceeded";  //!< Packet dropped due to queue disc limit exceeded
 
 private:
-  /**
-   * \brief Set the limit of this queue disc.
-   *
-   * \param limit The limit of this queue disc.
-   * \deprecated This method will go away in future versions of ns-3.
-   * See instead SetMaxSize()
-   */
-  void SetLimit (uint32_t limit);
-
-  /**
-   * \brief Get the limit of this queue disc.
-   *
-   * \returns The limit of this queue disc.
-   * \deprecated This method will go away in future versions of ns-3.
-   * See instead GetMaxSize()
-   */
-  uint32_t GetLimit (void) const;
-
   /**
    * Priority to band map. Values are taken from the prio2band array used by
    * the Linux pfifo_fast queue disc.
