@@ -50,7 +50,7 @@ TypeId PieQueueDisc::GetTypeId (void)
                    "Average of packet size",
                    UintegerValue (1000),
                    MakeUintegerAccessor (&PieQueueDisc::m_meanPktSize),
-                   MakeUintegerChecker<uint32_t> ())
+                   MakeUintegerChecker<uint32_t> ()) 
     .AddAttribute ("A",
                    "Value of alpha",
                    DoubleValue (0.125),
@@ -63,7 +63,7 @@ TypeId PieQueueDisc::GetTypeId (void)
                    MakeDoubleChecker<double> ())
     .AddAttribute ("Tupdate",
                    "Time period to calculate drop probability",
-                   TimeValue (Seconds (0.03)),
+                   TimeValue (MilliSeconds (15)),
                    MakeTimeAccessor (&PieQueueDisc::m_tUpdate),
                    MakeTimeChecker ())
     .AddAttribute ("Supdate",
@@ -79,19 +79,59 @@ TypeId PieQueueDisc::GetTypeId (void)
                    MakeQueueSizeChecker ())
     .AddAttribute ("DequeueThreshold",
                    "Minimum queue size in bytes before dequeue rate is measured",
-                   UintegerValue (10000),
+                   UintegerValue (16384),
                    MakeUintegerAccessor (&PieQueueDisc::m_dqThreshold),
                    MakeUintegerChecker<uint32_t> ())
     .AddAttribute ("QueueDelayReference",
                    "Desired queue delay",
-                   TimeValue (Seconds (0.02)),
+                   TimeValue (MilliSeconds (15)),
                    MakeTimeAccessor (&PieQueueDisc::m_qDelayRef),
                    MakeTimeChecker ())
     .AddAttribute ("MaxBurstAllowance",
-                   "Current max burst allowance in seconds before random drop",
-                   TimeValue (Seconds (0.1)),
+                   "Current max burst allowance before random drop",
+                   TimeValue (MilliSeconds (15)),
                    MakeTimeAccessor (&PieQueueDisc::m_maxBurst),
                    MakeTimeChecker ())
+    .AddAttribute ("UseDequeueRateEstimator",
+                   "Enable/Disable usage of Dequeue Rate Estimator",
+                   BooleanValue (false),
+                   MakeBooleanAccessor (&PieQueueDisc::m_useDqRateEstimator),
+                   MakeBooleanChecker ())
+    .AddAttribute ("UseCapDropAdjustment",
+                   "Enable/Disable Cap Drop Adjustment feature mentioned in RFC 8033",
+                   BooleanValue (true),
+                   MakeBooleanAccessor (&PieQueueDisc::m_isCapDropAdjustment),
+                   MakeBooleanChecker ())
+    .AddAttribute ("UseEcn",
+                   "True to use ECN (packets are marked instead of being dropped)",
+                   BooleanValue (false),
+                   MakeBooleanAccessor (&PieQueueDisc::m_useEcn),
+                   MakeBooleanChecker ())
+    .AddAttribute ("MarkEcnThreshold",
+                   "ECN marking threshold (RFC 8033 suggests 0.1 (i.e., 10%) default)",
+                   DoubleValue (0.1),
+                   MakeDoubleAccessor (&PieQueueDisc::m_markEcnTh),
+                   MakeDoubleChecker<double> (0,1))
+    .AddAttribute ("UseDerandomization",
+                   "Enable/Disable Derandomization feature mentioned in RFC 8033",
+                   BooleanValue (false),
+                   MakeBooleanAccessor (&PieQueueDisc::m_useDerandomization),
+                   MakeBooleanChecker ())
+    .AddAttribute ("ActiveThreshold",
+                   "Threshold for activating PIE (disabled by default)",
+                   TimeValue (Time::Max ()),
+                   MakeTimeAccessor (&PieQueueDisc::m_activeThreshold),
+                   MakeTimeChecker ())
+    .AddAttribute ("CeThreshold",
+                   "The FqPie CE threshold for marking packets",
+                   TimeValue (Time::Max ()),
+                   MakeTimeAccessor (&PieQueueDisc::m_ceThreshold),
+                   MakeTimeChecker ())
+    .AddAttribute ("UseL4s",
+                   "True to use L4S (only ECT1 packets are marked at CE threshold)",
+                   BooleanValue (false),
+                   MakeBooleanAccessor (&PieQueueDisc::m_useL4s),
+                   MakeBooleanChecker ())
   ;
 
   return tid;
@@ -122,7 +162,6 @@ PieQueueDisc::DoDispose (void)
 Time
 PieQueueDisc::GetQueueDelay (void)
 {
-  NS_LOG_FUNCTION (this);
   return m_qDelay;
 }
 
@@ -140,23 +179,70 @@ PieQueueDisc::DoEnqueue (Ptr<QueueDiscItem> item)
   NS_LOG_FUNCTION (this << item);
 
   QueueSize nQueued = GetCurrentSize ();
+  // If L4S is enabled, then check if the packet is ECT1, and if it is then set isEct true
+  bool isEct1 = false;
+  if (item && m_useL4s)
+    {
+      uint8_t tosByte = 0;
+      if (item->GetUint8Value (QueueItem::IP_DSFIELD, tosByte) && (((tosByte & 0x3) == 1) || (tosByte & 0x3) == 3))
+        {
+          if ((tosByte & 0x3) == 1)
+            {
+              NS_LOG_DEBUG ("Enqueueing ECT1 packet " << static_cast<uint16_t> (tosByte & 0x3));
+            }
+          else 
+            {
+              NS_LOG_DEBUG ("Enqueueing CE packet " << static_cast<uint16_t> (tosByte & 0x3));
+            }
+          isEct1 = true; 
+        }
+    }
 
   if (nQueued + item > GetMaxSize ())
     {
       // Drops due to queue limit: reactive
       DropBeforeEnqueue (item, FORCED_DROP);
+      m_accuProb = 0;
       return false;
     }
-  else if (DropEarly (item, nQueued.GetValue ()))
+  // isEct1 will be true only if L4S enabled as well as the packet is ECT1.
+  // If L4S is enabled and packet is ECT1 then directly enqueue the packet.
+  else if ((m_activeThreshold == Time::Max () || m_active) && !isEct1 && DropEarly (item, nQueued.GetValue ()))
     {
-      // Early probability drop: proactive
-      DropBeforeEnqueue (item, UNFORCED_DROP);
-      return false;
+      if (!m_useEcn || m_dropProb >= m_markEcnTh || !Mark (item, UNFORCED_MARK))
+        {
+          // Early probability drop: proactive
+          DropBeforeEnqueue (item, UNFORCED_DROP);
+          m_accuProb = 0;
+          return false;
+        }
     }
 
   // No drop
   bool retval = GetInternalQueue (0)->Enqueue (item);
 
+  // If the queue is over a certain threshold, Turn ON PIE
+  if (m_activeThreshold != Time::Max () && !m_active && m_qDelay >= m_activeThreshold)
+    {
+      m_active = true;
+      m_qDelayOld = Seconds (0);
+      m_dropProb = 0;
+      m_inMeasurement = true;
+      m_dqCount = 0;
+      m_avgDqRate = 0;
+      m_burstAllowance = m_maxBurst;
+      m_accuProb = 0;
+      m_dqStart = Now ();
+    }
+
+  // If queue has been Idle for a while, Turn OFF PIE
+  // Reset Counters when accessing the queue after some idle period if PIE was active before
+  if (m_activeThreshold != Time::Max () && m_dropProb == 0 && m_qDelayOld.GetMilliSeconds () == 0 && m_qDelay.GetMilliSeconds () == 0)
+    {
+      m_active = false;
+      m_inMeasurement = false ;
+    }
+
   // If Queue::Enqueue fails, QueueDisc::DropBeforeEnqueue is called by the
   // internal queue because QueueDisc::AddInternalQueue sets the trace callback
 
@@ -174,9 +260,11 @@ PieQueueDisc::InitializeParams (void)
   m_dqCount = DQCOUNT_INVALID;
   m_dropProb = 0;
   m_avgDqRate = 0.0;
-  m_dqStart = 0;
+  m_dqStart = Seconds (0);
   m_burstState = NO_BURST;
-  m_qDelayOld = Time (Seconds (0));
+  m_qDelayOld = Seconds (0);
+  m_accuProb = 0.0;
+  m_active = false;
 }
 
 bool PieQueueDisc::DropEarly (Ptr<QueueDiscItem> item, uint32_t qSize)
@@ -202,9 +290,8 @@ bool PieQueueDisc::DropEarly (Ptr<QueueDiscItem> item, uint32_t qSize)
     {
       p = p * packetSize / m_meanPktSize;
     }
-  bool earlyDrop = true;
-  double u =  m_uv->GetValue ();
 
+  // Safeguard PIE to be work conserving (Section 4.1 of RFC 8033)
   if ((m_qDelayOld.GetSeconds () < (0.5 * m_qDelayRef.GetSeconds ())) && (m_dropProb < 0.2))
     {
       return false;
@@ -218,11 +305,25 @@ bool PieQueueDisc::DropEarly (Ptr<QueueDiscItem> item, uint32_t qSize)
       return false;
     }
 
-  if (u > p)
+  if (m_useDerandomization)
     {
-      earlyDrop = false;
+      if (m_dropProb == 0)
+        {
+          m_accuProb = 0;
+        }
+      m_accuProb += m_dropProb;
+      if (m_accuProb < 0.85)
+        {
+          return false;
+        }
+      else if (m_accuProb >= 8.5)
+        {
+          return true;
+        }
     }
-  if (!earlyDrop)
+
+  double u =  m_uv->GetValue ();
+  if (u > p)
     {
       return false;
     }
@@ -236,17 +337,25 @@ void PieQueueDisc::CalculateP ()
   Time qDelay;
   double p = 0.0;
   bool missingInitFlag = false;
-  if (m_avgDqRate > 0)
+
+  if (m_useDqRateEstimator)
     {
-      qDelay = Time (Seconds (GetInternalQueue (0)->GetNBytes () / m_avgDqRate));
+      if (m_avgDqRate > 0)
+        {
+          qDelay = Seconds (GetInternalQueue (0)->GetNBytes () / m_avgDqRate);
+        }
+      else
+        {
+          qDelay = Seconds (0);
+          missingInitFlag = true;
+        }
+      m_qDelay = qDelay;
     }
   else
     {
-      qDelay = Time (Seconds (0));
-      missingInitFlag = true;
+      qDelay = m_qDelay;
     }
-
-  m_qDelay = qDelay;
+  NS_LOG_DEBUG ("Queue delay while calculating probability: " << qDelay.GetMilliSeconds () << "ms");
 
   if (m_burstAllowance.GetSeconds () > 0)
     {
@@ -255,7 +364,19 @@ void PieQueueDisc::CalculateP ()
   else
     {
       p = m_a * (qDelay.GetSeconds () - m_qDelayRef.GetSeconds ()) + m_b * (qDelay.GetSeconds () - m_qDelayOld.GetSeconds ());
-      if (m_dropProb < 0.001)
+      if (m_dropProb < 0.000001)
+        {
+          p /= 2048;
+        }
+      else if (m_dropProb < 0.00001)
+        {
+          p /= 512;
+        }
+      else if (m_dropProb < 0.0001)
+        {
+          p /= 128;
+        }
+      else if (m_dropProb < 0.001)
         {
           p /= 32;
         }
@@ -267,19 +388,15 @@ void PieQueueDisc::CalculateP ()
         {
           p /= 2;
         }
-      else if (m_dropProb < 1)
-        {
-          p /= 0.5;
-        }
-      else if (m_dropProb < 10)
-        {
-          p /= 0.125;
-        }
       else
         {
-          p /= 0.03125;
+          // The pseudocode in Section 4.2 of RFC 8033 suggests to use this for
+          // assignment of p, but this assignment causes build failure on Mac OS
+          // p = p;
         }
-      if ((m_dropProb >= 0.1) && (p > 0.02))
+
+      // Cap Drop Adjustment (Section 5.5 of RFC 8033)
+      if (m_isCapDropAdjustment && (m_dropProb >= 0.1) && (p > 0.02))
         {
           p = 0.02;
         }
@@ -288,20 +405,30 @@ void PieQueueDisc::CalculateP ()
   p += m_dropProb;
 
   // For non-linear drop in prob
-
+  // Decay the drop probability exponentially (Section 4.2 of RFC 8033)
   if (qDelay.GetSeconds () == 0 && m_qDelayOld.GetSeconds () == 0)
     {
       p *= 0.98;
     }
-  else if (qDelay.GetSeconds () > 0.2)
+
+  // bound the drop probability (Section 4.2 of RFC 8033)
+  if (p < 0)
     {
-      p += 0.02;
+      m_dropProb = 0;
+    }
+  else if (p > 1)
+    {
+      m_dropProb = 1;
+    }
+  else
+    {
+      m_dropProb = p;
     }
 
-  m_dropProb = (p > 0) ? p : 0;
+  // Section 4.4 #2
   if (m_burstAllowance < m_tUpdate)
     {
-      m_burstAllowance =  Time (Seconds (0));
+      m_burstAllowance =  Seconds (0);
     }
   else
     {
@@ -352,56 +479,88 @@ PieQueueDisc::DoDequeue ()
     }
 
   Ptr<QueueDiscItem> item = GetInternalQueue (0)->Dequeue ();
-  double now = Simulator::Now ().GetSeconds ();
-  uint32_t pktSize = item->GetSize ();
+  NS_ASSERT_MSG (item != nullptr, "Dequeue null, but internal queue not empty");
+
+  // If L4S is enabled and packet is ECT1, then check if delay is greater
+  // than CE threshold and if it is then mark the packet,
+  // skip PIE steps, and return the item.
+  if (m_useL4s)
+    {
+      uint8_t tosByte = 0;
+      if (item->GetUint8Value (QueueItem::IP_DSFIELD, tosByte) && (((tosByte & 0x3) == 1) || (tosByte & 0x3) == 3))
+        {
+          if ((tosByte & 0x3) == 1)
+            {
+              NS_LOG_DEBUG ("ECT1 packet " << static_cast<uint16_t> (tosByte & 0x3));
+            }
+          else 
+            {
+              NS_LOG_DEBUG ("CE packet " << static_cast<uint16_t> (tosByte & 0x3));
+            }
+          if ((Now () - item->GetTimeStamp () > m_ceThreshold) && Mark (item, CE_THRESHOLD_EXCEEDED_MARK))
+            {
+              NS_LOG_LOGIC ("Marking due to CeThreshold " << m_ceThreshold.GetSeconds ());
+            }
+          return item;
+        }
+    }  
 
   // if not in a measurement cycle and the queue has built up to dq_threshold,
   // start the measurement cycle
-
-  if ( (GetInternalQueue (0)->GetNBytes () >= m_dqThreshold) && (!m_inMeasurement) )
+  if (m_useDqRateEstimator)
     {
-      m_dqStart = now;
-      m_dqCount = 0;
-      m_inMeasurement = true;
-    }
-
-  if (m_inMeasurement)
-    {
-      m_dqCount += pktSize;
-
-      // done with a measurement cycle
-      if (m_dqCount >= m_dqThreshold)
+      if ( (GetInternalQueue (0)->GetNBytes () >= m_dqThreshold) && (!m_inMeasurement) )
         {
+          m_dqStart = Now ();
+          m_dqCount = 0;
+          m_inMeasurement = true;
+        }
 
-          double tmp = now - m_dqStart;
+      if (m_inMeasurement)
+        {
+          m_dqCount += item->GetSize ();
 
-          if (tmp > 0)
+          // done with a measurement cycle
+          if (m_dqCount >= m_dqThreshold)
             {
-              if (m_avgDqRate == 0)
+              Time dqTime = Now () - m_dqStart;
+              if (dqTime > Seconds (0))
                 {
-                  m_avgDqRate = m_dqCount / tmp;
+                  if (m_avgDqRate == 0)
+                    {
+                      m_avgDqRate = m_dqCount / dqTime.GetSeconds ();
+                    }
+                  else
+                    {
+                      m_avgDqRate = (0.5 * m_avgDqRate) + (0.5 * (m_dqCount / dqTime.GetSeconds ()));
+                    }
+                }
+              NS_LOG_DEBUG ("Average Dequeue Rate after Dequeue: " << m_avgDqRate);
+
+              // restart a measurement cycle if there is enough data
+              if (GetInternalQueue (0)->GetNBytes () > m_dqThreshold)
+                {
+                  m_dqStart = Now ();
+                  m_dqCount = 0;
+                  m_inMeasurement = true;
                 }
               else
                 {
-                  m_avgDqRate = (0.5 * m_avgDqRate) + (0.5 * (m_dqCount / tmp));
+                  m_dqCount = 0;
+                  m_inMeasurement = false;
                 }
             }
-
-          // restart a measurement cycle if there is enough data
-          if (GetInternalQueue (0)->GetNBytes () > m_dqThreshold)
-            {
-              m_dqStart = now;
-              m_dqCount = 0;
-              m_inMeasurement = true;
-            }
-          else
-            {
-              m_dqCount = 0;
-              m_inMeasurement = false;
-            }
         }
     }
+  else
+    {
+      m_qDelay = Now () - item->GetTimeStamp ();
 
+      if (GetInternalQueue (0)->GetNBytes () == 0)
+        {
+          m_qDelay = Seconds (0);
+        }
+    }
   return item;
 }
 
