@@ -133,13 +133,13 @@ public:
   typedef std::vector<Ptr<QueueDisc> > QueueDiscVector;
 
   /**
-   * \brief Perform the operations that the traffic control layer needs to do when
-   *        an IPv4/v6 interface is added to a device
-   * \param device the device which the IPv4/v6 interface has been added to
+   * \brief Collect information needed to determine how to handle packets
+   *        destined to each of the NetDevices of this node
    *
-   * This method creates a NetDeviceQueueInterface for the device
+   * Checks whether a NetDeviceQueueInterface objects is aggregated to each of
+   * the NetDevices of this node and sets the required callbacks properly.
    */
-  virtual void SetupDevice (Ptr<NetDevice> device);
+  virtual void ScanDevices (void);
 
   /**
    * \brief This method can be used to set the root queue disc installed on a device
@@ -195,9 +195,6 @@ public:
    */
   virtual void Send (Ptr<NetDevice> device, Ptr<QueueDiscItem> item);
 
-  /// Callback invoked to determine the tx queue selected for a given packet
-  typedef Callback< uint8_t, Ptr<QueueItem> > SelectQueueCallback;
-
 protected:
 
   virtual void DoDispose (void);
@@ -230,38 +227,11 @@ private:
   /**
    * \brief Information to store for each device
    */
-  class NetDeviceInfo
+  struct NetDeviceInfo
   {
-  public:
-    /**
-     * \brief Constructor
-     *
-     * \param rootQueueDisc the root queue disc installed on the device
-     * \param ndqi the NetDeviceQueueInterface aggregated to the device
-     * \param queueDiscsToWake the vector of queue discs to wake
-     * \param selectQueueCallback the select queue callback
-     */
-    NetDeviceInfo (Ptr<QueueDisc> rootQueueDisc, Ptr<NetDeviceQueueInterface> ndqi,
-                   QueueDiscVector queueDiscsToWake, SelectQueueCallback selectQueueCallback);
-    virtual ~NetDeviceInfo ();
-
     Ptr<QueueDisc> m_rootQueueDisc;       //!< the root queue disc on the device
     Ptr<NetDeviceQueueInterface> m_ndqi;  //!< the netdevice queue interface
     QueueDiscVector m_queueDiscsToWake;   //!< the vector of queue discs to wake
-    SelectQueueCallback m_selectQueueCallback;  //!< the select queue callback
-  private:
-    NetDeviceInfo ();
-    /**
-     * \brief Copy constructor
-     * Disable default implementation to avoid misuse
-     */
-    NetDeviceInfo (NetDeviceInfo const &);
-    /**
-     * \brief Assignment operator
-     * \return this object
-     * Disable default implementation to avoid misuse
-     */
-    NetDeviceInfo& operator= (NetDeviceInfo const &);
   };
 
   /// Typedef for protocol handlers container
