@@ -334,10 +334,10 @@ TbfQueueDiscTestCase::RunTbfTest (QueueSizeUnit mode)
   Simulator::Stop (Seconds (1.3));
   Simulator::Run ();
 
-  // test 4 : When DataRate < FirstBucketTokenRate; burst condition, peakRate is set so that bursts are controlled.
-  /* This test checks the burst control ability of TBF. 10 packets each of size 1000 bytes are enqueued followed by
+  // test 4 : This test checks the peakRate control of packet dequeue, when DataRate < FirstBucketTokenRate.
+  /* 10 packets each of size 1000 bytes are enqueued followed by
      their dequeue. The data rate (25 KB/s) is not sufficiently higher than the btokens rate (15 KB/s), so that in
-     the startup phase the first bucket is not empty. Hence when adequate tokens are present in the second bucket,
+     the startup phase the first bucket is not empty. Hence when adequate tokens are present in the second (peak) bucket,
      the packets get transmitted, otherwise they are blocked. So basically the transmission of packets falls under the
      regulation of the second bucket since first bucket will always have excess tokens. TBF does not let all
      the packets go smoothly without any control just because there are excess tokens in the first bucket. */
@@ -365,6 +365,7 @@ TbfQueueDiscTestCase::RunTbfTest (QueueSizeUnit mode)
 
   burst = 15000;
   mtu = 1000;
+  pktSize = 1000;
   rate = DataRate ("15KB/s");
   peakRate = DataRate ("20KB/s");
 
@@ -392,17 +393,27 @@ TbfQueueDiscTestCase::RunTbfTest (QueueSizeUnit mode)
       Simulator::Schedule (Time (Seconds ((i + 1) * delay)), &TbfQueueDiscTestCase::Enqueue, this, queue, dest, pktSize);
     }
 
+  // The pattern being checked is a pattern of dequeue followed by blocked.  The delay between enqueues is not sufficient
+  // to allow ptokens to refill befor the next dequeue.  The first enqueue is at 1.08s in the future, and the attempted
+  // dequeue is at 1.10s in the future.  The first dequeue will always succeed.  The second enqueue is 1.12s and attempted
+  // dequeue is at 1.14s in the future, but the last dequeue was 0.04s prior; only 800 tokens can be refilled in 0.04s
+  // at a peak rate of 20Kbps.  The actual dequeue occurs at 0.01s further into the future when ptokens refills to 1000.
+  // To repeat the pattern, odd-numbered dequeue events should be spaced at intervals of at least 100ms, and the
+  // even-numbered dequeue events (that block) should be 0.04s (delay) following the last odd-numbered dequeue event.
+  double nextDelay = (2 * delay) + 0.02; // 20ms after first enqueue to attempt the first dequeue;
   for (uint32_t i = 1; i <= nPkt; i++)
     {
       if (i % 2 == 1)
         {
-          Simulator::Schedule (Time (Seconds ((i + 1) * delay + 0.02)), &TbfQueueDiscTestCase::DequeueAndCheck, this,
+          Simulator::Schedule (Seconds (nextDelay), &TbfQueueDiscTestCase::DequeueAndCheck, this,
                                queue, true, "1st packet should not be blocked");
+          nextDelay += 0.04;
         }
       else
         {
-          Simulator::Schedule (Time (Seconds ((i + 1) * delay + 0.02)), &TbfQueueDiscTestCase::DequeueAndCheck, this,
+          Simulator::Schedule (Seconds (nextDelay), &TbfQueueDiscTestCase::DequeueAndCheck, this,
                                queue, false, "This packet should be blocked");
+          nextDelay += 0.06;  // Need 0.04 + 0.06 seconds to allow the next packet to be dequeued without block
         }
     }
   Simulator::Stop (Seconds (0.55));
