@@ -96,7 +96,7 @@ void
 UanHeaderRcData::Serialize (Buffer::Iterator start) const
 {
   start.WriteU8 (m_frameNo);
-  start.WriteU16 ( (uint16_t)(1000.0 * m_propDelay.GetSeconds () + 0.5));
+  start.WriteU16 ( (uint16_t) m_propDelay.RoundTo (Time::MS).GetMilliSeconds ());
 }
 uint32_t
 UanHeaderRcData::Deserialize (Buffer::Iterator start)
@@ -109,10 +109,16 @@ UanHeaderRcData::Deserialize (Buffer::Iterator start)
   return rbuf.GetDistanceFrom (start);
 }
 
+void
+UanHeaderRcData::Print (std::ostream &os, Time::Unit unit) const
+{
+  os << "Frame No=" << (uint32_t) m_frameNo << " Prop Delay=" << m_propDelay.As (unit);
+}
+
 void
 UanHeaderRcData::Print (std::ostream &os) const
 {
-  os << "Frame No=" << (uint32_t) m_frameNo << " Prop Delay=" << m_propDelay.GetSeconds ();
+  Print (os, Time::S);
 }
 
 TypeId
@@ -232,8 +238,7 @@ UanHeaderRcRts::Serialize (Buffer::Iterator start) const
   start.WriteU8 (m_retryNo);
   start.WriteU8 (m_noFrames);
   start.WriteU16 (m_length);
-  start.WriteU32 ((uint32_t)(m_timeStamp.GetSeconds () * 1000.0 + 0.5));
-  // start.WriteU16(uint16_t (m_timeStamp.GetSeconds ()*1000));
+  start.WriteU32 ((uint32_t) (m_timeStamp.RoundTo (Time::MS).GetMilliSeconds ()));
 }
 
 uint32_t
@@ -249,10 +254,16 @@ UanHeaderRcRts::Deserialize (Buffer::Iterator start)
   return rbuf.GetDistanceFrom (start);
 }
 
+void
+UanHeaderRcRts::Print (std::ostream &os, Time::Unit unit) const
+{
+  os << "Frame #=" << (uint32_t) m_frameNo << " Retry #=" << (uint32_t) m_retryNo << " Num Frames=" << (uint32_t) m_noFrames << "Length=" << m_length << " Time Stamp=" << m_timeStamp.As (unit);
+}
+
 void
 UanHeaderRcRts::Print (std::ostream &os) const
 {
-  os << "Frame #=" << (uint32_t) m_frameNo << " Retry #=" << (uint32_t) m_retryNo << " Num Frames=" << (uint32_t) m_noFrames << "Length=" << m_length << " Time Stamp=" << m_timeStamp.GetSeconds ();
+  Print(os, Time::S);
 }
 
 TypeId
@@ -358,8 +369,8 @@ UanHeaderRcCtsGlobal::Serialize (Buffer::Iterator start) const
 {
   start.WriteU16 (m_rateNum);
   start.WriteU16 (m_retryRate);
-  start.WriteU32 ( (uint32_t)(m_timeStampTx.GetSeconds () * 1000.0 + 0.5));
-  start.WriteU32 ( (uint32_t)(m_winTime.GetSeconds () * 1000.0 + 0.5));
+  start.WriteU32 ( (uint32_t) (m_timeStampTx.RoundTo (Time::MS).GetMilliSeconds ()));
+  start.WriteU32 ( (uint32_t) (m_winTime.RoundTo (Time::MS).GetMilliSeconds ()));
 }
 
 uint32_t
@@ -374,10 +385,16 @@ UanHeaderRcCtsGlobal::Deserialize (Buffer::Iterator start)
 
 }
 
+void
+UanHeaderRcCtsGlobal::Print (std::ostream &os, Time::Unit unit) const
+{
+  os << "CTS Global (Rate #=" << m_rateNum << ", Retry Rate=" << m_retryRate << ", TX Time=" << m_timeStampTx.As (Time::S) << ", Win Time=" << m_winTime.As (Time::S) << ")";
+}
+
 void
 UanHeaderRcCtsGlobal::Print (std::ostream &os) const
 {
-  os << "CTS Global (Rate #=" << m_rateNum << ", Retry Rate=" << m_retryRate << ", TX Time=" << m_timeStampTx.GetSeconds () << ", Win Time=" << m_winTime.GetSeconds () << ")";
+  Print(os, Time::S);
 }
 
 TypeId
@@ -500,8 +517,8 @@ UanHeaderRcCts::Serialize (Buffer::Iterator start) const
   start.WriteU8 (address);
   start.WriteU8 (m_frameNo);
   start.WriteU8 (m_retryNo);
-  start.WriteU32 ((uint32_t)(m_timeStampRts.GetSeconds () * 1000.0 + 0.5));
-  start.WriteU32 ((uint32_t)(m_delay.GetSeconds () * 1000.0 + 0.5));
+  start.WriteU32 ((uint32_t) (m_timeStampRts.RoundTo (Time::MS).GetMilliSeconds ()));
+  start.WriteU32 ((uint32_t) (m_delay.RoundTo (Time::MS).GetMilliSeconds ()));
 }
 
 uint32_t
@@ -517,10 +534,16 @@ UanHeaderRcCts::Deserialize (Buffer::Iterator start)
   return rbuf.GetDistanceFrom (start);
 }
 
+void
+UanHeaderRcCts::Print (std::ostream &os, Time::Unit unit) const
+{
+  os << "CTS (Addr=" << m_address << " Frame #=" << (uint32_t) m_frameNo << " Retry #=" << (uint32_t) m_retryNo << " RTS Rx Timestamp=" << m_timeStampRts.As (unit) << " Delay until TX=" << m_delay.As (unit) << ")";
+}
+
 void
 UanHeaderRcCts::Print (std::ostream &os) const
 {
-  os << "CTS (Addr=" << m_address << " Frame #=" << (uint32_t) m_frameNo << " Retry #=" << (uint32_t) m_retryNo << " RTS Rx Timestamp=" << m_timeStampRts.GetSeconds () << " Delay until TX=" << m_delay.GetSeconds () << ")";
+  Print (os, Time::S);
 }
 
 TypeId
