@@ -527,14 +527,11 @@ class Channel(PyVizObject):
         @return none
         """
         self.channel = channel
-        self.canvas_item = GooCanvas.CanvasEllipse()
-        self.canvas_item.radius_x=30
-        self.canvas_item.radius_y=30
-        self.canvas_item.fill_color="white"
-        self.canvas_item.stroke_color="grey"
-        self.canvas_item.line_width="2.0"
-        self.canvas_item.line_dash=GooCanvas.CanvasLineDash([10.0, 10.0])
-        self.canvas_item.visibility=GooCanvas.CanvasItemVisibility.VISIBLE
+        self.canvas_item = GooCanvas.CanvasEllipse(radius_x=30, radius_y=30,
+                                             fill_color="white",
+                                             stroke_color="grey", line_width=2.0,
+                                             line_dash=GooCanvas.CanvasLineDash.newv([10.0, 10.0 ]),
+                                             visibility=GooCanvas.CanvasItemVisibility.VISIBLE)
         self.canvas_item.pyviz_object = self
         self.links = []
 
