@@ -26,7 +26,6 @@
 #include "ns3/minstrel-wifi-manager.h"
 #include "ns3/radiotap-header.h"
 #include "ns3/unused.h"
-#include "ns3/wifi-ack-policy-selector.h"
 #include "wave-mac-helper.h"
 #include "wave-helper.h"
 
@@ -278,10 +277,6 @@ WaveHelper::Default (void)
                                   "DataMode", StringValue ("OfdmRate6MbpsBW10MHz"),
                                   "ControlMode",StringValue ("OfdmRate6MbpsBW10MHz"),
                                   "NonUnicastMode", StringValue ("OfdmRate6MbpsBW10MHz"));
-  helper.SetAckPolicySelectorForAc (AC_BE, "ns3::ConstantWifiAckPolicySelector");
-  helper.SetAckPolicySelectorForAc (AC_BK, "ns3::ConstantWifiAckPolicySelector");
-  helper.SetAckPolicySelectorForAc (AC_VI, "ns3::ConstantWifiAckPolicySelector");
-  helper.SetAckPolicySelectorForAc (AC_VO, "ns3::ConstantWifiAckPolicySelector");
   return helper;
 }
 
@@ -339,29 +334,6 @@ WaveHelper::SetRemoteStationManager (std::string type,
   m_stationManager.Set (n7, v7);
 }
 
-void
-WaveHelper::SetAckPolicySelectorForAc (AcIndex ac, std::string type,
-                                       std::string n0, const AttributeValue &v0,
-                                       std::string n1, const AttributeValue &v1,
-                                       std::string n2, const AttributeValue &v2,
-                                       std::string n3, const AttributeValue &v3,
-                                       std::string n4, const AttributeValue &v4,
-                                       std::string n5, const AttributeValue &v5,
-                                       std::string n6, const AttributeValue &v6,
-                                       std::string n7, const AttributeValue &v7)
-{
-  m_ackPolicySelector[ac] = ObjectFactory ();
-  m_ackPolicySelector[ac].SetTypeId (type);
-  m_ackPolicySelector[ac].Set (n0, v0);
-  m_ackPolicySelector[ac].Set (n1, v1);
-  m_ackPolicySelector[ac].Set (n2, v2);
-  m_ackPolicySelector[ac].Set (n3, v3);
-  m_ackPolicySelector[ac].Set (n4, v4);
-  m_ackPolicySelector[ac].Set (n5, v5);
-  m_ackPolicySelector[ac].Set (n6, v6);
-  m_ackPolicySelector[ac].Set (n7, v7);
-}
-
 void
 WaveHelper::SetChannelScheduler (std::string type,
                                  std::string n0, const AttributeValue &v0,
@@ -412,7 +384,7 @@ WaveHelper::Install (const WifiPhyHelper &phyHelper,  const WifiMacHelper &macHe
       for (uint32_t j = 0; j != m_physNumber; ++j)
         {
           Ptr<WifiPhy> phy = phyHelper.Create (node, device);
-          phy->ConfigureStandard (WIFI_PHY_STANDARD_80211_10MHZ);
+          phy->ConfigureStandardAndBand (WIFI_PHY_STANDARD_80211p, WIFI_PHY_BAND_5GHZ);
           phy->SetChannelNumber (ChannelManager::GetCch ());
           device->AddPhy (phy);
         }
@@ -420,40 +392,10 @@ WaveHelper::Install (const WifiPhyHelper &phyHelper,  const WifiMacHelper &macHe
       for (std::vector<uint32_t>::const_iterator k = m_macsForChannelNumber.begin ();
            k != m_macsForChannelNumber.end (); ++k)
         {
-          Ptr<WifiMac> wifiMac = macHelper.Create (device);
+          Ptr<WifiMac> wifiMac = macHelper.Create (device, WIFI_STANDARD_80211p);
           Ptr<OcbWifiMac> ocbMac = DynamicCast<OcbWifiMac> (wifiMac);
-          // we use WaveMacLow to replace original MacLow
+          ocbMac->SetWifiRemoteStationManager (m_stationManager.Create<WifiRemoteStationManager> ());
           ocbMac->EnableForWave (device);
-          ocbMac->SetWifiRemoteStationManager ( m_stationManager.Create<WifiRemoteStationManager> ());
-          ocbMac->ConfigureStandard (WIFI_PHY_STANDARD_80211_10MHZ);
-          // Install ack policy selector
-          BooleanValue qosSupported;
-          PointerValue ptr;
-          Ptr<WifiAckPolicySelector> ackSelector;
-
-          ocbMac->GetAttributeFailSafe ("QosSupported", qosSupported);
-          if (qosSupported.Get ())
-            {
-              ocbMac->GetAttributeFailSafe ("BE_Txop", ptr);
-              ackSelector = m_ackPolicySelector[AC_BE].Create<WifiAckPolicySelector> ();
-              ackSelector->SetQosTxop (ptr.Get<QosTxop> ());
-              ptr.Get<QosTxop> ()->SetAckPolicySelector (ackSelector);
-
-              ocbMac->GetAttributeFailSafe ("BK_Txop", ptr);
-              ackSelector = m_ackPolicySelector[AC_BK].Create<WifiAckPolicySelector> ();
-              ackSelector->SetQosTxop (ptr.Get<QosTxop> ());
-              ptr.Get<QosTxop> ()->SetAckPolicySelector (ackSelector);
-
-              ocbMac->GetAttributeFailSafe ("VI_Txop", ptr);
-              ackSelector = m_ackPolicySelector[AC_VI].Create<WifiAckPolicySelector> ();
-              ackSelector->SetQosTxop (ptr.Get<QosTxop> ());
-              ptr.Get<QosTxop> ()->SetAckPolicySelector (ackSelector);
-
-              ocbMac->GetAttributeFailSafe ("VO_Txop", ptr);
-              ackSelector = m_ackPolicySelector[AC_VO].Create<WifiAckPolicySelector> ();
-              ackSelector->SetQosTxop (ptr.Get<QosTxop> ());
-              ptr.Get<QosTxop> ()->SetAckPolicySelector (ackSelector);
-            }
           device->AddMac (*k, ocbMac);
         }
 
@@ -491,7 +433,7 @@ WaveHelper::EnableLogComponents (void)
   LogComponentEnable ("VsaManager", LOG_LEVEL_ALL);
   LogComponentEnable ("OcbWifiMac", LOG_LEVEL_ALL);
   LogComponentEnable ("VendorSpecificAction", LOG_LEVEL_ALL);
-  LogComponentEnable ("WaveMacLow", LOG_LEVEL_ALL);
+  LogComponentEnable ("WaveFrameExchangeManager", LOG_LEVEL_ALL);
   LogComponentEnable ("HigherLayerTxVectorTag", LOG_LEVEL_ALL);
 }
 
