@@ -51,12 +51,6 @@ ChannelManager::ChannelManager ()
 ChannelManager::~ChannelManager ()
 {
   NS_LOG_FUNCTION (this);
-  std::map<uint32_t, WaveChannel *> ::iterator i;
-  for (i = m_channels.begin (); i != m_channels.end (); ++i)
-    {
-      delete (i->second);
-    }
-  m_channels.clear ();
 }
 
 uint32_t
@@ -175,4 +169,16 @@ ChannelManager::GetManagementPowerLevel (uint32_t channelNumber)
   return m_channels[channelNumber]->txPowerLevel;
 }
 
+void
+ChannelManager::DoDispose (void)
+{
+  NS_LOG_FUNCTION (this);
+  std::map<uint32_t, WaveChannel *> ::iterator i;
+  for (i = m_channels.begin (); i != m_channels.end (); ++i)
+    {
+      delete (i->second);
+    }
+  m_channels.clear ();
+}
+
 } // namespace ns3
