@@ -117,6 +117,7 @@ WaveNetDevice::DoDispose (void)
       mac->Dispose ();
     }
   m_macEntities.clear ();
+  m_phyEntities.clear ();
   m_channelCoordinator->Dispose ();
   m_channelManager->Dispose ();
   m_channelScheduler->Dispose ();
@@ -126,7 +127,7 @@ WaveNetDevice::DoDispose (void)
   m_channelScheduler = 0;
   m_vsaManager = 0;
   // chain up.
-  NetDevice::DoDispose ();
+  WifiNetDevice::DoDispose ();
 }
 
 void
@@ -635,16 +636,6 @@ WaveNetDevice::Send (Ptr<Packet> packet, const Address& dest, uint16_t protocol)
   return true;
 }
 
-Ptr<Node>
-WaveNetDevice::GetNode (void) const
-{
-  return m_node;
-}
-void
-WaveNetDevice::SetNode (Ptr<Node> node)
-{
-  m_node = node;
-}
 bool
 WaveNetDevice::NeedsArp (void) const
 {
