@@ -61,6 +61,7 @@ int main (int argc, char *argv[])
 {
   uint32_t testCase = 0;
   bool printAttributes = false;
+  bool exceptionThrown = false;
 
   CommandLine cmd (__FILE__);
   cmd.AddValue ("testCase", "Test case", testCase);
@@ -73,7 +74,7 @@ int main (int argc, char *argv[])
   wifiApNode.Create (1);
 
   YansWifiChannelHelper channel = YansWifiChannelHelper::Default ();
-  YansWifiPhyHelper phy = YansWifiPhyHelper::Default ();
+  YansWifiPhyHelper phy;
   phy.SetChannel (channel.Create ());
   WifiHelper wifi;
   wifi.SetRemoteStationManager ("ns3::IdealWifiManager");
@@ -102,11 +103,8 @@ int main (int argc, char *argv[])
     case 0:
       // Default configuration, without WifiHelper::SetStandard or WifiHelper
       phySta = CreateObject<YansWifiPhy> ();
-      // The default results in an invalid configuration of channel 0,
-      // width 20, and frequency 0 MHz
-      NS_ASSERT (phySta->GetChannelNumber () == 0);
-      NS_ASSERT (phySta->GetChannelWidth () == 20);
-      NS_ASSERT (phySta->GetFrequency () == 0);
+      // The default results in an invalid configuration
+      NS_ASSERT (!phySta->GetOperatingChannel ().IsSet ());
       PrintAttributesIfEnabled (printAttributes);
       break;
 
@@ -114,7 +112,7 @@ int main (int argc, char *argv[])
     // i.e. without further channel number/width/frequency configuration
 
     case 1:
-      // By default, WifiHelper will use WIFI_PHY_STANDARD_80211a
+      // By default, WifiHelper will use WIFI_STANDARD_80211a
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
@@ -125,7 +123,7 @@ int main (int argc, char *argv[])
       PrintAttributesIfEnabled (printAttributes);
       break;
     case 2:
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211b);
+      wifi.SetStandard (WIFI_STANDARD_80211b);
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
@@ -136,7 +134,7 @@ int main (int argc, char *argv[])
       PrintAttributesIfEnabled (printAttributes);
       break;
     case 3:
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211g);
+      wifi.SetStandard (WIFI_STANDARD_80211g);
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
@@ -147,7 +145,7 @@ int main (int argc, char *argv[])
       PrintAttributesIfEnabled (printAttributes);
       break;
     case 4:
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+      wifi.SetStandard (WIFI_STANDARD_80211n_5GHZ);
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
@@ -158,7 +156,7 @@ int main (int argc, char *argv[])
       PrintAttributesIfEnabled (printAttributes);
       break;
     case 5:
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211n_2_4GHZ);
+      wifi.SetStandard (WIFI_STANDARD_80211n_2_4GHZ);
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
@@ -169,7 +167,7 @@ int main (int argc, char *argv[])
       PrintAttributesIfEnabled (printAttributes);
       break;
     case 6:
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211ac);
+      wifi.SetStandard (WIFI_STANDARD_80211ac);
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
@@ -180,7 +178,41 @@ int main (int argc, char *argv[])
       PrintAttributesIfEnabled (printAttributes);
       break;
     case 7:
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211_10MHZ);
+      wifi.SetStandard (WIFI_STANDARD_80211ax_2_4GHZ);
+      staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
+      apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
+      phySta = GetYansWifiPhyPtr (staDevice);
+      // We expect channel 1, width 20, frequency 2412
+      NS_ASSERT (phySta->GetChannelNumber () == 1);
+      NS_ASSERT (phySta->GetChannelWidth () == 20);
+      NS_ASSERT (phySta->GetFrequency () == 2412);
+      PrintAttributesIfEnabled (printAttributes);
+      break;
+    case 8:
+      wifi.SetStandard (WIFI_STANDARD_80211ax_5GHZ);
+      staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
+      apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
+      phySta = GetYansWifiPhyPtr (staDevice);
+      // We expect channel 42, width 80, frequency 5210
+      NS_ASSERT (phySta->GetChannelNumber () == 42);
+      NS_ASSERT (phySta->GetChannelWidth () == 80);
+      NS_ASSERT (phySta->GetFrequency () == 5210);
+      PrintAttributesIfEnabled (printAttributes);
+      break;
+    case 9:
+      wifi.SetStandard (WIFI_STANDARD_80211ax_6GHZ);
+      staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
+      apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
+      phySta = GetYansWifiPhyPtr (staDevice);
+      // We expect channel 7, width 80, frequency 5975
+      NS_ASSERT (phySta->GetChannelNumber () == 7);
+      NS_ASSERT (phySta->GetChannelWidth () == 80);
+      NS_ASSERT (phySta->GetFrequency () == 5975);
+      PrintAttributesIfEnabled (printAttributes);
+      break;
+    case 10:
+      wifi.SetStandard (WIFI_STANDARD_80211p);
+      phy.Set ("ChannelWidth", UintegerValue (10));
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
@@ -190,31 +222,20 @@ int main (int argc, char *argv[])
       NS_ASSERT (phySta->GetFrequency () == 5860);
       PrintAttributesIfEnabled (printAttributes);
       break;
-    case 8:
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211_5MHZ);
+    case 11:
+      wifi.SetStandard (WIFI_STANDARD_80211p);
+      phy.Set ("ChannelWidth", UintegerValue (5));
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
-      // We expect channel 0, width 5, frequency 5860
-      // Channel 0 because 5MHz channels are not officially defined
-      NS_ASSERT (phySta->GetChannelNumber () == 0);
+      // We expect channel 171, width 5, frequency 5860
+      NS_ASSERT (phySta->GetChannelNumber () == 171);
       NS_ASSERT (phySta->GetChannelWidth () == 5);
       NS_ASSERT (phySta->GetFrequency () == 5860);
       PrintAttributesIfEnabled (printAttributes);
       break;
-    case 9:
-      wifi.SetStandard (WIFI_PHY_STANDARD_holland);
-      staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
-      apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
-      phySta = GetYansWifiPhyPtr (staDevice);
-      // We expect channel 36, width 20, frequency 5180
-      NS_ASSERT (phySta->GetChannelNumber () == 36);
-      NS_ASSERT (phySta->GetChannelWidth () == 20);
-      NS_ASSERT (phySta->GetFrequency () == 5180);
-      PrintAttributesIfEnabled (printAttributes);
-      break;
-    case 10:
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+    case 12:
+      wifi.SetStandard (WIFI_STANDARD_80211n_5GHZ);
       phy.Set ("ChannelNumber", UintegerValue (44));
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
@@ -225,9 +246,8 @@ int main (int argc, char *argv[])
       NS_ASSERT (phySta->GetFrequency () == 5220);
       PrintAttributesIfEnabled (printAttributes);
       break;
-
-    case 11:
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+    case 13:
+      wifi.SetStandard (WIFI_STANDARD_80211n_5GHZ);
       phy.Set ("ChannelNumber", UintegerValue (44));
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
@@ -241,61 +261,65 @@ int main (int argc, char *argv[])
       NS_ASSERT (phySta->GetFrequency () == 5200);
       PrintAttributesIfEnabled (printAttributes);
       break;
-
-    case 12:
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+    case 14:
+      wifi.SetStandard (WIFI_STANDARD_80211n_5GHZ);
       phy.Set ("ChannelNumber", UintegerValue (44));
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
-      // Post-install reconfiguration to channel width 40 MHz
-      Config::Set ("/NodeList/0/DeviceList/*/$ns3::WifiNetDevice/Phy/$ns3::YansWifiPhy/ChannelWidth", UintegerValue (40));
-      Config::Set ("/NodeList/1/DeviceList/*/$ns3::WifiNetDevice/Phy/$ns3::YansWifiPhy/ChannelWidth", UintegerValue (40));
-      // Although channel 44 is configured originally for 20 MHz, we
-      // allow it to be used for 40 MHz here
-      NS_ASSERT (phySta->GetChannelNumber () == 44);
+      // Post-install reconfiguration to a 40 MHz channel
+      Config::Set ("/NodeList/0/DeviceList/*/$ns3::WifiNetDevice/Phy/$ns3::YansWifiPhy/ChannelNumber", UintegerValue (46));
+      Config::Set ("/NodeList/1/DeviceList/*/$ns3::WifiNetDevice/Phy/$ns3::YansWifiPhy/ChannelNumber", UintegerValue (46));
+      NS_ASSERT (phySta->GetChannelNumber () == 46);
       NS_ASSERT (phySta->GetChannelWidth () == 40);
-      NS_ASSERT (phySta->GetFrequency () == 5220);
+      NS_ASSERT (phySta->GetFrequency () == 5230);
       PrintAttributesIfEnabled (printAttributes);
       break;
-
-    case 13:
-      Config::SetDefault ("ns3::WifiPhy::ChannelNumber", UintegerValue (44));
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
-      staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
-      apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
-      phySta = GetYansWifiPhyPtr (staDevice);
-      // Post-install reconfiguration to channel width 40 MHz
-      Config::Set ("/NodeList/0/DeviceList/*/$ns3::WifiNetDevice/Phy/$ns3::YansWifiPhy/ChannelWidth", UintegerValue (40));
-      Config::Set ("/NodeList/1/DeviceList/*/$ns3::WifiNetDevice/Phy/$ns3::YansWifiPhy/ChannelWidth", UintegerValue (40));
-      // Although channel 44 is configured originally for 20 MHz, we
-      // allow it to be used for 40 MHz here
-      NS_ASSERT (phySta->GetChannelNumber () == 44);
-      NS_ASSERT (phySta->GetChannelWidth () == 40);
-      NS_ASSERT (phySta->GetFrequency () == 5220);
-      PrintAttributesIfEnabled (printAttributes);
-      break;
-
-    case 14:
-      // Test that setting Frequency to a non-standard value will zero the
-      // channel number
-      Config::SetDefault ("ns3::WifiPhy::Frequency", UintegerValue (5281));
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
-      staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
-      apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
-      phySta = GetYansWifiPhyPtr (staDevice);
-      // We expect channel number to be zero since frequency doesn't match
-      NS_ASSERT (phySta->GetChannelNumber () == 0);
-      NS_ASSERT (phySta->GetChannelWidth () == 20);
-      NS_ASSERT (phySta->GetFrequency () == 5281);
-      PrintAttributesIfEnabled (printAttributes);
-      break;
-
     case 15:
+      Config::SetDefault ("ns3::WifiPhy::ChannelNumber", UintegerValue (44));
+      wifi.SetStandard (WIFI_STANDARD_80211n_5GHZ);
+      staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
+      apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
+      phySta = GetYansWifiPhyPtr (staDevice);
+      // Post-install reconfiguration to a 40 MHz channel
+      Config::Set ("/NodeList/0/DeviceList/*/$ns3::WifiNetDevice/Phy/$ns3::YansWifiPhy/ChannelNumber", UintegerValue (46));
+      Config::Set ("/NodeList/1/DeviceList/*/$ns3::WifiNetDevice/Phy/$ns3::YansWifiPhy/ChannelNumber", UintegerValue (46));
+      NS_ASSERT (phySta->GetChannelNumber () == 46);
+      NS_ASSERT (phySta->GetChannelWidth () == 40);
+      NS_ASSERT (phySta->GetFrequency () == 5230);
+      PrintAttributesIfEnabled (printAttributes);
+      break;
+    case 16:
+      // Test that setting Frequency to a non-standard value will throw an exception
+      Config::SetDefault ("ns3::WifiPhy::Frequency", UintegerValue (5281));
+      wifi.SetStandard (WIFI_STANDARD_80211n_5GHZ);
+      exceptionThrown = false;
+      try
+        {
+          staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
+        }
+      catch (const std::runtime_error&)
+        {
+          exceptionThrown = true;
+        }
+      NS_ASSERT (exceptionThrown);
+      exceptionThrown = false;
+      try
+        {
+          apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
+        }
+      catch (const std::runtime_error&)
+        {
+          exceptionThrown = true;
+        }
+      NS_ASSERT (exceptionThrown);
+      PrintAttributesIfEnabled (printAttributes);
+      break;
+    case 17:
       // Test that setting Frequency to a standard value will set the
       // channel number correctly
       Config::SetDefault ("ns3::WifiPhy::Frequency", UintegerValue (5500));
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+      wifi.SetStandard (WIFI_STANDARD_80211n_5GHZ);
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
@@ -305,51 +329,76 @@ int main (int argc, char *argv[])
       NS_ASSERT (phySta->GetFrequency () == 5500);
       PrintAttributesIfEnabled (printAttributes);
       break;
-
-    case 16:
-      // Define a new channel number
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+    case 18:
+      // Set a wrong channel after initialization
+      wifi.SetStandard (WIFI_STANDARD_80211n_5GHZ);
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
-      // This case will error exit due to invalid channel number unless
-      // we provide the DefineChannelNumber() below
-      phySta->DefineChannelNumber (99, WIFI_PHY_STANDARD_80211n_5GHZ, 5185, 40);
-      phySta->SetAttribute ("ChannelNumber", UintegerValue (99));
+      exceptionThrown = false;
+      try
+        {
+          phySta->SetOperatingChannel (99, 5185, 40);
+        }
+      catch (const std::runtime_error&)
+        {
+          exceptionThrown = true;
+        }
+      NS_ASSERT (exceptionThrown);
       PrintAttributesIfEnabled (printAttributes);
       break;
-
-    case 17:
+    case 19:
       // Test how channel number behaves when frequency is non-standard
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+      wifi.SetStandard (WIFI_STANDARD_80211n_5GHZ);
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
-      phySta->SetAttribute ("Frequency", UintegerValue (5181));
-      // We expect channel number to be 0 due to unknown center frequency 5181
-      NS_ASSERT (phySta->GetChannelNumber () == 0);
-      NS_ASSERT (phySta->GetChannelWidth () == 20);
-      NS_ASSERT (phySta->GetFrequency () == 5181);
+      exceptionThrown = false;
+      try
+        {
+          phySta->SetAttribute ("Frequency", UintegerValue (5181));
+        }
+      catch (const std::runtime_error&)
+        {
+          exceptionThrown = true;
+        }
+      // We expect that an exception is thrown due to unknown center frequency 5181
+      NS_ASSERT (exceptionThrown);
       phySta->SetAttribute ("Frequency", UintegerValue (5180));
       // We expect channel number to be 36 due to known center frequency 5180
       NS_ASSERT (phySta->GetChannelNumber () == 36);
       NS_ASSERT (phySta->GetChannelWidth () == 20);
       NS_ASSERT (phySta->GetFrequency () == 5180);
-      phySta->SetAttribute ("Frequency", UintegerValue (5179));
-      // We expect channel number to be 0 due to unknown center frequency 5179
-      NS_ASSERT (phySta->GetChannelNumber () == 0);
-      NS_ASSERT (phySta->GetChannelWidth () == 20);
-      NS_ASSERT (phySta->GetFrequency () == 5179);
+      exceptionThrown = false;
+      try
+        {
+          phySta->SetAttribute ("Frequency", UintegerValue (5179));
+        }
+      catch (const std::runtime_error&)
+        {
+          exceptionThrown = true;
+        }
+      // We expect that an exception is thrown due to unknown center frequency 5179
+      NS_ASSERT (exceptionThrown);
       phySta->SetAttribute ("ChannelNumber", UintegerValue (36));
       NS_ASSERT (phySta->GetChannelNumber () == 36);
       NS_ASSERT (phySta->GetChannelWidth () == 20);
       NS_ASSERT (phySta->GetFrequency () == 5180);
       PrintAttributesIfEnabled (printAttributes);
       break;
-
-    case 18:
-      // Set both channel and frequency to consistent values
-      wifi.SetStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+    case 20:
+      // Set both channel and frequency to consistent values before initialization
+      Config::SetDefault ("ns3::WifiPhy::Frequency", UintegerValue (5200));
+      Config::SetDefault ("ns3::WifiPhy::ChannelNumber", UintegerValue (40));
+      wifi.SetStandard (WIFI_STANDARD_80211n_5GHZ);
+      staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
+      apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
+      phySta = GetYansWifiPhyPtr (staDevice);
+      NS_ASSERT (phySta->GetChannelNumber () == 40);
+      NS_ASSERT (phySta->GetChannelWidth () == 20);
+      NS_ASSERT (phySta->GetFrequency () == 5200);
+      // Set both channel and frequency to consistent values after initialization
+      wifi.SetStandard (WIFI_STANDARD_80211n_5GHZ);
       staDevice = wifi.Install (phy, macSta, wifiStaNode.Get (0));
       apDevice = wifi.Install (phy, macAp, wifiApNode.Get (0));
       phySta = GetYansWifiPhyPtr (staDevice);
@@ -371,21 +420,38 @@ int main (int argc, char *argv[])
       NS_ASSERT (phySta->GetChannelNumber () == 40);
       NS_ASSERT (phySta->GetChannelWidth () == 20);
       NS_ASSERT (phySta->GetFrequency () == 5200);
-      phySta->SetAttribute ("Frequency", UintegerValue (5179));
+      exceptionThrown = false;
+      try
+        {
+          phySta->SetAttribute ("Frequency", UintegerValue (5179));
+        }
+      catch (const std::runtime_error&)
+        {
+          exceptionThrown = true;
+        }
       phySta->SetAttribute ("ChannelNumber", UintegerValue (36));
-      // We expect channel number to be 36
+      // We expect channel number to be 36 and an exception to be thrown
       NS_ASSERT (phySta->GetChannelNumber () == 36);
       NS_ASSERT (phySta->GetChannelWidth () == 20);
       NS_ASSERT (phySta->GetFrequency () == 5180);
+      NS_ASSERT (exceptionThrown);
       phySta->SetAttribute ("ChannelNumber", UintegerValue (36));
-      phySta->SetAttribute ("Frequency", UintegerValue (5179));
-      // We expect channel number to be 0
-      NS_ASSERT (phySta->GetChannelNumber () == 0);
+      exceptionThrown = false;
+      try
+        {
+          phySta->SetAttribute ("Frequency", UintegerValue (5179));
+        }
+      catch (const std::runtime_error&)
+        {
+          exceptionThrown = true;
+        }
+      // We expect channel number to be 36 and an exception to be thrown
+      NS_ASSERT (phySta->GetChannelNumber () == 36);
       NS_ASSERT (phySta->GetChannelWidth () == 20);
-      NS_ASSERT (phySta->GetFrequency () == 5179);
+      NS_ASSERT (phySta->GetFrequency () == 5180);
+      NS_ASSERT (exceptionThrown);
       PrintAttributesIfEnabled (printAttributes);
       break;
-
     default:
       std::cerr << "Invalid testcase number " << testCase << std::endl;
       exit (1);
