@@ -41,7 +41,12 @@ public:
    * \return the object TypeId
    */
   static TypeId GetTypeId (void);
-  TypeId GetInstanceTypeId (void) const;
+
+  TypeId GetInstanceTypeId (void) const override;
+  void Serialize (TagBuffer i) const override;
+  void Deserialize (TagBuffer i) override;
+  uint32_t GetSerializedSize () const override;
+  void Print (std::ostream &os) const override;
 
   /**
    * Create a AmpduTag with the default =0 no A-MPDU
@@ -60,11 +65,6 @@ public:
    */
   void SetRemainingAmpduDuration (Time duration);
 
-  void Serialize (TagBuffer i) const;
-  void Deserialize (TagBuffer i);
-  uint32_t GetSerializedSize () const;
-  void Print (std::ostream &os) const;
-
   /**
    * \return the remaining number of MPDUs in an A-MPDU
    *
