@@ -59,6 +59,12 @@ CapabilityInformation::SetShortSlotTime (bool shortSlotTime)
     }
 }
 
+void
+CapabilityInformation::SetCfPollable (void)
+{
+  Set (2);
+}
+
 bool
 CapabilityInformation::IsEss (void) const
 {
@@ -83,6 +89,12 @@ CapabilityInformation::IsShortSlotTime (void) const
   return Is (10);
 }
 
+bool
+CapabilityInformation::IsCfPollable (void) const
+{
+  return Is (2);
+}
+
 void
 CapabilityInformation::Set (uint8_t n)
 {
