@@ -24,7 +24,7 @@
 #include "txop.h"
 #include "wifi-phy-listener.h"
 #include "wifi-phy.h"
-#include "mac-low.h"
+#include "frame-exchange-manager.h"
 
 namespace ns3 {
 
@@ -114,8 +114,6 @@ ChannelAccessManager::ChannelAccessManager ()
     m_lastSwitchingDuration (MicroSeconds (0)),
     m_sleeping (false),
     m_off (false),
-    m_slot (Seconds (0.0)),
-    m_sifs (Seconds (0.0)),
     m_phyListener (0)
 {
   NS_LOG_FUNCTION (this);
@@ -138,6 +136,7 @@ ChannelAccessManager::DoDispose (void)
       i = 0;
     }
   m_phy = 0;
+  m_feManager = 0;
 }
 
 void
@@ -164,38 +163,29 @@ ChannelAccessManager::RemovePhyListener (Ptr<WifiPhy> phy)
 }
 
 void
-ChannelAccessManager::SetupLow (Ptr<MacLow> low)
+ChannelAccessManager::SetupFrameExchangeManager (Ptr<FrameExchangeManager> feManager)
 {
-  NS_LOG_FUNCTION (this << low);
-  low->RegisterChannelAccessManager (this);
+  NS_LOG_FUNCTION (this << feManager);
+  m_feManager = feManager;
+  m_feManager->SetChannelAccessManager (this);
 }
 
-void
-ChannelAccessManager::SetSlot (Time slotTime)
+Time
+ChannelAccessManager::GetSlot (void) const
 {
-  NS_LOG_FUNCTION (this << slotTime);
-  m_slot = slotTime;
+  return m_phy->GetSlot ();
 }
 
-void
-ChannelAccessManager::SetSifs (Time sifs)
+Time
+ChannelAccessManager::GetSifs (void) const
 {
-  NS_LOG_FUNCTION (this << sifs);
-  m_sifs = sifs;
-}
-
-void
-ChannelAccessManager::SetEifsNoDifs (Time eifsNoDifs)
-{
-  NS_LOG_FUNCTION (this << eifsNoDifs);
-  m_eifsNoDifs = eifsNoDifs;
+  return m_phy->GetSifs ();
 }
 
 Time
 ChannelAccessManager::GetEifsNoDifs () const
 {
-  NS_LOG_FUNCTION (this);
-  return m_eifsNoDifs;
+  return m_phy->GetSifs () + m_phy->GetAckTxTime ();
 }
 
 void
@@ -247,6 +237,12 @@ ChannelAccessManager::NeedBackoffUponAccess (Ptr<Txop> txop)
 {
   NS_LOG_FUNCTION (this << txop);
 
+  // No backoff needed if in sleep mode or off
+  if (m_sleeping || m_off)
+    {
+      return false;
+    }
+
   // the Txop might have a stale value of remaining backoff slots
   UpdateBackoff ();
 
@@ -270,7 +266,8 @@ ChannelAccessManager::NeedBackoffUponAccess (Ptr<Txop> txop)
    *    with that AC has now become non-empty and any other transmit queues
    *    associated with that AC are empty; the medium is busy on the primary channel
    */
-  if (!txop->HasFramesToTransmit () && !txop->GetLow ()->IsCfPeriod () && txop->GetBackoffSlots () == 0)
+  if (!txop->HasFramesToTransmit () && txop->GetAccessStatus () != Txop::GRANTED
+      && txop->GetBackoffSlots () == 0)
     {
       if (!IsBusy ())
         {
@@ -280,7 +277,7 @@ ChannelAccessManager::NeedBackoffUponAccess (Ptr<Txop> txop)
           // to correctly align the backoff start time at the next slot boundary
           // (performed by the next call to ChannelAccessManager::RequestAccess())
           Time delay = (txop->IsQosTxop () ? Seconds (0)
-                                           : m_sifs + txop->GetAifsn () * m_slot);
+                                           : GetSifs () + txop->GetAifsn () * GetSlot ());
           txop->UpdateBackoffSlotsNow (0, Simulator::Now () + delay);
         }
       else
@@ -293,7 +290,7 @@ ChannelAccessManager::NeedBackoffUponAccess (Ptr<Txop> txop)
 }
 
 void
-ChannelAccessManager::RequestAccess (Ptr<Txop> txop, bool isCfPeriod)
+ChannelAccessManager::RequestAccess (Ptr<Txop> txop)
 {
   NS_LOG_FUNCTION (this << txop);
   if (m_phy)
@@ -305,17 +302,10 @@ ChannelAccessManager::RequestAccess (Ptr<Txop> txop, bool isCfPeriod)
     {
       return;
     }
-  if (isCfPeriod)
-    {
-      txop->NotifyAccessRequested ();
-      Time delay = (MostRecent ({GetAccessGrantStart (true), Simulator::Now ()}) - Simulator::Now ());
-      m_accessTimeout = Simulator::Schedule (delay, &ChannelAccessManager::DoGrantPcfAccess, this, txop);
-      return;
-    }
   /*
    * EDCAF operations shall be performed at slot boundaries (Sec. 10.22.2.4 of 802.11-2016)
    */
-  Time accessGrantStart = GetAccessGrantStart () + (txop->GetAifsn () * m_slot);
+  Time accessGrantStart = GetAccessGrantStart () + (txop->GetAifsn () * GetSlot ());
 
   if (txop->IsQosTxop () && txop->GetBackoffStart () > accessGrantStart)
     {
@@ -323,23 +313,17 @@ ChannelAccessManager::RequestAccess (Ptr<Txop> txop, bool isCfPeriod)
       // time the medium was busy plus an AIFS, hence we need to align it to the
       // next slot boundary.
       Time diff = txop->GetBackoffStart () - accessGrantStart;
-      uint32_t nIntSlots = (diff / m_slot).GetHigh () + 1;
-      txop->UpdateBackoffSlotsNow (0, accessGrantStart + (nIntSlots * m_slot));
+      uint32_t nIntSlots = (diff / GetSlot ()).GetHigh () + 1;
+      txop->UpdateBackoffSlotsNow (0, accessGrantStart + (nIntSlots * GetSlot ()));
     }
 
   UpdateBackoff ();
-  NS_ASSERT (!txop->IsAccessRequested ());
+  NS_ASSERT (txop->GetAccessStatus () != Txop::REQUESTED);
   txop->NotifyAccessRequested ();
   DoGrantDcfAccess ();
   DoRestartAccessTimeoutIfNeeded ();
 }
 
-void
-ChannelAccessManager::DoGrantPcfAccess (Ptr<Txop> txop)
-{
-  txop->NotifyAccessGranted ();
-}
-
 void
 ChannelAccessManager::DoGrantDcfAccess (void)
 {
@@ -348,7 +332,8 @@ ChannelAccessManager::DoGrantDcfAccess (void)
   for (Txops::iterator i = m_txops.begin (); i != m_txops.end (); k++)
     {
       Ptr<Txop> txop = *i;
-      if (txop->IsAccessRequested ()
+      if (txop->GetAccessStatus () == Txop::REQUESTED
+          && (!txop->IsQosTxop () || !StaticCast<QosTxop> (txop)->EdcaDisabled ())
           && GetBackoffEndFor (txop) <= Simulator::Now () )
         {
           /**
@@ -362,7 +347,7 @@ ChannelAccessManager::DoGrantDcfAccess (void)
           for (Txops::iterator j = i; j != m_txops.end (); j++, k++)
             {
               Ptr<Txop> otherTxop = *j;
-              if (otherTxop->IsAccessRequested ()
+              if (otherTxop->GetAccessStatus () == Txop::REQUESTED
                   && GetBackoffEndFor (otherTxop) <= Simulator::Now ())
                 {
                   NS_LOG_DEBUG ("dcf " << k << " needs access. backoff expired. internal collision. slots=" <<
@@ -377,18 +362,30 @@ ChannelAccessManager::DoGrantDcfAccess (void)
             }
 
           /**
-           * Now, we notify all of these changes in one go. It is necessary to
+           * Now, we notify all of these changes in one go if the EDCAF winning
+           * the contention actually transmitted a frame. It is necessary to
            * perform first the calculations of which Txops are colliding and then
            * only apply the changes because applying the changes through notification
            * could change the global state of the manager, and, thus, could change
            * the result of the calculations.
            */
-          txop->NotifyAccessGranted ();
-          for (auto collidingTxop : internalCollisionTxops)
+          NS_ASSERT (m_feManager != 0);
+
+          if (m_feManager->StartTransmission (txop))
             {
-              collidingTxop->NotifyInternalCollision ();
+              for (auto& collidingTxop : internalCollisionTxops)
+                {
+                  m_feManager->NotifyInternalCollision (collidingTxop);
+                }
+              break;
+            }
+          else
+            {
+              // reset the current state to the EDCAF that won the contention
+              // but did not transmit anything
+              i--;
+              k = std::distance (m_txops.begin (), i);
             }
-          break;
         }
       i++;
     }
@@ -408,17 +405,18 @@ ChannelAccessManager::GetAccessGrantStart (bool ignoreNav) const
 {
   NS_LOG_FUNCTION (this);
   Time lastRxEnd = m_lastRxStart + m_lastRxDuration;
-  Time rxAccessStart = lastRxEnd + m_sifs;
+  const Time& sifs = GetSifs();
+  Time rxAccessStart = lastRxEnd + sifs;
   if ((lastRxEnd <= Simulator::Now ()) && !m_lastRxReceivedOk)
     {
-      rxAccessStart += m_eifsNoDifs;
+      rxAccessStart += GetEifsNoDifs ();
     }
-  Time busyAccessStart = m_lastBusyStart + m_lastBusyDuration + m_sifs;
-  Time txAccessStart = m_lastTxStart + m_lastTxDuration + m_sifs;
-  Time navAccessStart = m_lastNavStart + m_lastNavDuration + m_sifs;
-  Time ackTimeoutAccessStart = m_lastAckTimeoutEnd + m_sifs;
-  Time ctsTimeoutAccessStart = m_lastCtsTimeoutEnd + m_sifs;
-  Time switchingAccessStart = m_lastSwitchingStart + m_lastSwitchingDuration + m_sifs;
+  Time busyAccessStart = m_lastBusyStart + m_lastBusyDuration + sifs;
+  Time txAccessStart = m_lastTxStart + m_lastTxDuration + sifs;
+  Time navAccessStart = m_lastNavStart + m_lastNavDuration + sifs;
+  Time ackTimeoutAccessStart = m_lastAckTimeoutEnd + sifs;
+  Time ctsTimeoutAccessStart = m_lastCtsTimeoutEnd + sifs;
+  Time switchingAccessStart = m_lastSwitchingStart + m_lastSwitchingDuration + sifs;
   Time accessGrantedStart;
   if (ignoreNav)
     {
@@ -454,7 +452,7 @@ ChannelAccessManager::GetBackoffStartFor (Ptr<Txop> txop)
 {
   NS_LOG_FUNCTION (this << txop);
   Time mostRecentEvent = MostRecent ({txop->GetBackoffStart (),
-                                     GetAccessGrantStart () + (txop->GetAifsn () * m_slot)});
+                                     GetAccessGrantStart () + (txop->GetAifsn () * GetSlot ())});
   NS_LOG_DEBUG ("Backoff start: " << mostRecentEvent.As (Time::US));
 
   return mostRecentEvent;
@@ -464,7 +462,7 @@ Time
 ChannelAccessManager::GetBackoffEndFor (Ptr<Txop> txop)
 {
   NS_LOG_FUNCTION (this << txop);
-  Time backoffEnd = GetBackoffStartFor (txop) + (txop->GetBackoffSlots () * m_slot);
+  Time backoffEnd = GetBackoffStartFor (txop) + (txop->GetBackoffSlots () * GetSlot ());
   NS_LOG_DEBUG ("Backoff end: " << backoffEnd.As (Time::US));
 
   return backoffEnd;
@@ -480,7 +478,7 @@ ChannelAccessManager::UpdateBackoff (void)
       Time backoffStart = GetBackoffStartFor (txop);
       if (backoffStart <= Simulator::Now ())
         {
-          uint32_t nIntSlots = ((Simulator::Now () - backoffStart) / m_slot).GetHigh ();
+          uint32_t nIntSlots = ((Simulator::Now () - backoffStart) / GetSlot ()).GetHigh ();
           /*
            * EDCA behaves slightly different to DCA. For EDCA we
            * decrement once at the slot boundary at the end of AIFS as
@@ -498,7 +496,7 @@ ChannelAccessManager::UpdateBackoff (void)
             }
           uint32_t n = std::min (nIntSlots, txop->GetBackoffSlots ());
           NS_LOG_DEBUG ("dcf " << k << " dec backoff slots=" << n);
-          Time backoffUpdateBound = backoffStart + (n * m_slot);
+          Time backoffUpdateBound = backoffStart + (n * GetSlot ());
           txop->UpdateBackoffSlotsNow (n, backoffUpdateBound);
         }
       ++k;
@@ -517,7 +515,7 @@ ChannelAccessManager::DoRestartAccessTimeoutIfNeeded (void)
   Time expectedBackoffEnd = Simulator::GetMaximumSimulationTime ();
   for (auto txop : m_txops)
     {
-      if (txop->IsAccessRequested ())
+      if (txop->GetAccessStatus () == Txop::REQUESTED)
         {
           Time tmp = GetBackoffEndFor (txop);
           if (tmp > Simulator::Now ())
@@ -545,6 +543,19 @@ ChannelAccessManager::DoRestartAccessTimeoutIfNeeded (void)
     }
 }
 
+void
+ChannelAccessManager::DisableEdcaFor (Ptr<Txop> qosTxop, Time duration)
+{
+  NS_LOG_FUNCTION (this << qosTxop << duration);
+  NS_ASSERT (qosTxop->IsQosTxop ());
+  UpdateBackoff ();
+  Time resume = Simulator::Now () + duration;
+  NS_LOG_DEBUG ("Backoff will resume at time " << resume << " with "
+                << qosTxop->GetBackoffSlots () << " remaining slot(s)");
+  qosTxop->UpdateBackoffSlotsNow (0, resume);
+  DoRestartAccessTimeoutIfNeeded ();
+}
+
 void
 ChannelAccessManager::NotifyRxStartNow (Time duration)
 {
@@ -592,7 +603,7 @@ ChannelAccessManager::NotifyTxStartNow (Time duration)
     {
       //this may be caused only if PHY has started to receive a packet
       //inside SIFS, so, we check that lastRxStart was maximum a SIFS ago
-      NS_ASSERT (now - m_lastRxStart <= m_sifs);
+      NS_ASSERT (now - m_lastRxStart <= GetSifs ());
       m_lastRxDuration = now - m_lastRxStart;
     }
   NS_LOG_DEBUG ("tx start for " << duration);
@@ -659,7 +670,7 @@ ChannelAccessManager::NotifySwitchingStartNow (Time duration)
           NS_ASSERT (txop->GetBackoffSlots () == 0);
         }
       txop->ResetCw ();
-      txop->m_accessRequested = false;
+      txop->m_access = Txop::NOT_REQUESTED;
       txop->NotifyChannelSwitching ();
     }
 
@@ -718,7 +729,7 @@ ChannelAccessManager::NotifyWakeupNow (void)
           NS_ASSERT (txop->GetBackoffSlots () == 0);
         }
       txop->ResetCw ();
-      txop->m_accessRequested = false;
+      txop->m_access = Txop::NOT_REQUESTED;
       txop->NotifyWakeUp ();
     }
 }
@@ -737,7 +748,7 @@ ChannelAccessManager::NotifyOnNow (void)
           NS_ASSERT (txop->GetBackoffSlots () == 0);
         }
       txop->ResetCw ();
-      txop->m_accessRequested = false;
+      txop->m_access = Txop::NOT_REQUESTED;
       txop->NotifyOn ();
     }
 }
