@@ -22,7 +22,7 @@
 #include "ns3/sequence-number.h"
 #include "ns3/packet.h"
 #include "mac-rx-middle.h"
-#include "wifi-mac-header.h"
+#include "wifi-mac-queue-item.h"
 
 namespace ns3 {
 
@@ -198,7 +198,7 @@ MacRxMiddle::Lookup (const WifiMacHeader *hdr)
   if (hdr->IsQosData ()
       && !hdr->GetAddr2 ().IsGroup ())
     {
-      /* only for qos data non-broadcast frames */
+      /* only for QoS data non-broadcast frames */
       originator = m_qosOriginatorStatus[std::make_pair (source, hdr->GetQosTid ())];
       if (originator == 0)
         {
@@ -209,8 +209,8 @@ MacRxMiddle::Lookup (const WifiMacHeader *hdr)
   else
     {
       /* - management frames
-       * - qos data broadcast frames
-       * - nqos data frames
+       * - QoS data broadcast frames
+       * - non-QoS data frames
        * see section 7.1.3.4.1
        */
       originator = m_originatorStatus[source];
@@ -236,8 +236,8 @@ MacRxMiddle::IsDuplicate (const WifiMacHeader* hdr,
   return false;
 }
 
-Ptr<Packet>
-MacRxMiddle::HandleFragments (Ptr<Packet> packet, const WifiMacHeader *hdr,
+Ptr<const Packet>
+MacRxMiddle::HandleFragments (Ptr<const Packet> packet, const WifiMacHeader *hdr,
                               OriginatorRxStatus *originator)
 {
   NS_LOG_FUNCTION (packet << hdr << originator);
@@ -296,14 +296,12 @@ MacRxMiddle::HandleFragments (Ptr<Packet> packet, const WifiMacHeader *hdr,
 }
 
 void
-MacRxMiddle::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
+MacRxMiddle::Receive (Ptr<WifiMacQueueItem> mpdu)
 {
-  NS_LOG_FUNCTION (packet << hdr);
+  NS_LOG_FUNCTION (*mpdu);
+  const WifiMacHeader* hdr = &mpdu->GetHeader ();
   NS_ASSERT (hdr->IsData () || hdr->IsMgt ());
-  if (!m_pcfCallback.IsNull ())
-    {
-      m_pcfCallback ();
-    }
+
   OriginatorRxStatus *originator = Lookup (hdr);
   /**
    * The check below is really unneeded because it can fail in a lot of
@@ -327,7 +325,7 @@ MacRxMiddle::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                     ", frag=" << +hdr->GetFragmentNumber ());
       return;
     }
-  Ptr<Packet> aggregate = HandleFragments (packet, hdr, originator);
+  Ptr<const Packet> aggregate = HandleFragments (mpdu->GetPacket (), hdr, originator);
   if (aggregate == 0)
     {
       return;
@@ -339,13 +337,18 @@ MacRxMiddle::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
     {
       originator->SetSequenceControl (hdr->GetSequenceControl ());
     }
-  m_callback (aggregate, hdr);
-}
-
-void
-MacRxMiddle::SetPcfCallback (Callback<void> callback)
-{
-  m_pcfCallback = callback;
+  if (aggregate == mpdu->GetPacket ())
+    {
+      m_callback (mpdu);
+    }
+  else
+    {
+      // We could do this in all cases, but passing the received mpdu in case of
+      // A-MSDUs saves us the time to deaggregate the A-MSDU in MSDUs (which are
+      // kept separate in the received mpdu) and allows us to pass the originally
+      // transmitted packets (i.e., with the same UID) to the receiver.
+      m_callback (Create<WifiMacQueueItem> (aggregate, *hdr));
+    }
 }
 
 } //namespace ns3
