@@ -28,17 +28,17 @@
 #include "capability-information.h"
 #include "supported-rates.h"
 #include "ssid.h"
-#include "dsss-parameter-set.h"
+#include "ns3/dsss-parameter-set.h"
 #include "extended-capabilities.h"
-#include "ht-capabilities.h"
-#include "ht-operation.h"
-#include "vht-capabilities.h"
-#include "vht-operation.h"
-#include "erp-information.h"
+#include "ns3/ht-capabilities.h"
+#include "ns3/ht-operation.h"
+#include "ns3/vht-capabilities.h"
+#include "ns3/vht-operation.h"
+#include "ns3/erp-information.h"
 #include "edca-parameter-set.h"
-#include "he-capabilities.h"
-#include "he-operation.h"
-#include "cf-parameter-set.h"
+#include "ns3/he-capabilities.h"
+#include "ns3/he-operation.h"
+#include "ns3/mu-edca-parameter-set.h"
 
 namespace ns3 {
 
@@ -154,11 +154,12 @@ public:
    * \return The TypeId.
    */
   static TypeId GetTypeId (void);
-  TypeId GetInstanceTypeId (void) const;
-  void Print (std::ostream &os) const;
-  uint32_t GetSerializedSize (void) const;
-  void Serialize (Buffer::Iterator start) const;
-  uint32_t Deserialize (Buffer::Iterator start);
+
+  TypeId GetInstanceTypeId (void) const override;
+  void Print (std::ostream &os) const override;
+  uint32_t GetSerializedSize (void) const override;
+  void Serialize (Buffer::Iterator start) const override;
+  uint32_t Deserialize (Buffer::Iterator start) override;
 
 
 private:
@@ -399,6 +400,12 @@ public:
    * \return the EDCA Parameter Set
    */
   EdcaParameterSet GetEdcaParameterSet (void) const;
+  /**
+   * Return the MU EDCA Parameter Set.
+   *
+   * \return the MU EDCA Parameter Set
+   */
+  MuEdcaParameterSet GetMuEdcaParameterSet (void) const;
   /**
    * Set the Capability information.
    *
@@ -465,6 +472,12 @@ public:
    * \param edcaParameterSet the EDCA Parameter Set
    */
   void SetEdcaParameterSet (EdcaParameterSet edcaParameterSet);
+  /**
+   * Set the MU EDCA Parameter Set.
+   *
+   * \param muEdcaParameterSet the MU EDCA Parameter Set
+   */
+  void SetMuEdcaParameterSet (MuEdcaParameterSet muEdcaParameterSet);
   /**
    * Set the HE capabilities.
    *
@@ -504,6 +517,7 @@ private:
   EdcaParameterSet m_edcaParameterSet; //!< EDCA Parameter Set
   HeCapabilities m_heCapability; //!< HE capabilities
   HeOperation m_heOperation; //!< HE operation
+  MuEdcaParameterSet m_muEdcaParameterSet; //!< MU EDCA Parameter Set
 };
 
 
@@ -706,11 +720,11 @@ public:
    */
   EdcaParameterSet GetEdcaParameterSet (void) const;
   /**
-   * Return the CF parameter set.
+   * Return the MU EDCA Parameter Set.
    *
-   * \return CF parameter set
+   * \return the MU EDCA Parameter Set
    */
-  CfParameterSet GetCfParameterSet (void) const;
+  MuEdcaParameterSet GetMuEdcaParameterSet (void) const;
   /**
    * Set the Capability information.
    *
@@ -796,11 +810,11 @@ public:
    */
   void SetEdcaParameterSet (EdcaParameterSet edcaParameterSet);
   /**
-   * Set the CF parameter set.
+   * Set the MU EDCA Parameter Set.
    *
-   * \param cfParameterSet CF parameter set
+   * \param muEdcaParameterSet the MU EDCA Parameter Set
    */
-  void SetCfParameterSet (CfParameterSet cfParameterSet);
+  void SetMuEdcaParameterSet (MuEdcaParameterSet muEdcaParameterSet);
   /**
    * Return the time stamp.
    *
@@ -836,7 +850,7 @@ private:
   HeOperation m_heOperation;         //!< HE operation
   ErpInformation m_erpInformation;     //!< ERP information
   EdcaParameterSet m_edcaParameterSet; //!< EDCA Parameter Set
-  CfParameterSet m_cfParameterSet;     //!< CF parameter set
+  MuEdcaParameterSet m_muEdcaParameterSet; //!< MU EDCA Parameter Set
 };
 
 
@@ -1263,7 +1277,7 @@ public:
    * \return The TypeId.
    */
   static TypeId GetTypeId (void);
-  // Inherited
+
   TypeId GetInstanceTypeId (void) const;
   void Print (std::ostream &os) const;
   uint32_t GetSerializedSize (void) const;
