@@ -24,14 +24,21 @@
 #include "wifi-mac.h"
 #include "qos-txop.h"
 #include "ssid.h"
+#include <set>
+#include <unordered_map>
 
 namespace ns3 {
 
-class MacLow;
 class MacRxMiddle;
 class MacTxMiddle;
 class ChannelAccessManager;
 class ExtendedCapabilities;
+class FrameExchangeManager;
+class WifiPsdu;
+class WifiMacQueue;
+enum WifiTxTimerReason : uint8_t;
+
+typedef std::unordered_map <uint16_t /* staId */, Ptr<WifiPsdu> /* PSDU */> WifiPsduMap;
 
 /**
  * \brief base class for all MAC-level wifi objects.
@@ -54,57 +61,36 @@ public:
   virtual ~RegularWifiMac ();
 
   // Implementations of pure virtual methods.
-  void SetSlot (Time slotTime);
-  void SetSifs (Time sifs);
-  void SetEifsNoDifs (Time eifsNoDifs);
-  void SetPifs (Time pifs);
-  void SetRifs (Time rifs);
-  void SetAckTimeout (Time ackTimeout);
-  void SetShortSlotTimeSupported (bool enable);
-  void SetSsid (Ssid ssid);
-  void SetAddress (Mac48Address address);
-  void SetPromisc (void);
-  Time GetRifs (void) const;
-  Time GetPifs (void) const;
-  Time GetSifs (void) const;
-  Time GetSlot (void) const;
-  Time GetEifsNoDifs (void) const;
-  Time GetAckTimeout (void) const;
-  bool GetShortSlotTimeSupported (void) const;
-  Ssid GetSsid (void) const;
-  Mac48Address GetAddress (void) const;
-  Mac48Address GetBssid (void) const;
-  virtual void Enqueue (Ptr<Packet> packet, Mac48Address to, Mac48Address from);
-  virtual bool SupportsSendFrom (void) const;
-  virtual void SetWifiPhy (const Ptr<WifiPhy> phy);
-  Ptr<WifiPhy> GetWifiPhy (void) const;
-  void ResetWifiPhy (void);
-  virtual void SetWifiRemoteStationManager (const Ptr<WifiRemoteStationManager> stationManager);
-
-  /**
-   * This type defines the callback of a higher layer that a
-   * WifiMac(-derived) object invokes to pass a packet up the stack.
-   *
-   * \param packet the packet that has been received.
-   * \param from the MAC address of the device that sent the packet.
-   * \param to the MAC address of the device that the packet is destined for.
-   */
-  typedef Callback<void, Ptr<const Packet>, Mac48Address, Mac48Address> ForwardUpCallback;
-
-  void SetForwardUpCallback (ForwardUpCallback upCallback);
-  void SetLinkUpCallback (Callback<void> linkUp);
-  void SetLinkDownCallback (Callback<void> linkDown);
-
-  /* Next functions are not pure virtual so non-QoS WifiMacs are not
-   * forced to implement them.
-   */
-  void SetBasicBlockAckTimeout (Time blockAckTimeout);
-  Time GetBasicBlockAckTimeout (void) const;
-  void SetCompressedBlockAckTimeout (Time blockAckTimeout);
-  Time GetCompressedBlockAckTimeout (void) const;
+  void SetShortSlotTimeSupported (bool enable) override;
+  void SetSsid (Ssid ssid) override;
+  void SetAddress (Mac48Address address) override;
+  void SetPromisc (void) override;
+  bool GetShortSlotTimeSupported (void) const override;
+  Ssid GetSsid (void) const override;
+  Mac48Address GetAddress (void) const override;
+  Mac48Address GetBssid (void) const override;
+  void Enqueue (Ptr<Packet> packet, Mac48Address to, Mac48Address from) override;
+  bool SupportsSendFrom (void) const override;
+  void SetWifiPhy (const Ptr<WifiPhy> phy) override;
+  Ptr<WifiPhy> GetWifiPhy (void) const override;
+  void ResetWifiPhy (void) override;
+  void SetWifiRemoteStationManager (const Ptr<WifiRemoteStationManager> stationManager) override;
+  void ConfigureStandard (WifiStandard standard) override;
+  TypeOfStation GetTypeOfStation (void) const override;
+  void SetForwardUpCallback (ForwardUpCallback upCallback) override;
+  void SetLinkUpCallback (Callback<void> linkUp) override;
+  void SetLinkDownCallback (Callback<void> linkDown) override;
+  Ptr<WifiRemoteStationManager> GetWifiRemoteStationManager (void) const override;
 
   // Should be implemented by child classes
-  virtual void Enqueue (Ptr<Packet> packet, Mac48Address to) = 0;
+  void Enqueue (Ptr<Packet> packet, Mac48Address to) override = 0;
+
+  /**
+   * Get the Frame Exchange Manager
+   *
+   * \return the Frame Exchange Manager
+   */
+  Ptr<FrameExchangeManager> GetFrameExchangeManager (void) const;
 
   /**
    * Enable or disable CTS-to-self feature.
@@ -113,31 +99,76 @@ public:
    *               false otherwise
    */
   void SetCtsToSelfSupported (bool enable);
-  /**
-   * Enable or disable RIFS feature.
-   *
-   * \param enable true if RIFS is to be supported,
-   *               false otherwise
-   * \deprecated
-   */
-  void SetRifsSupported (bool enable);
-  /**
-   * \return whether the device supports RIFS capability.
-   *
-   * \return true if short RIFS is supported,
-   *         false otherwise.
-   * \deprecated
-   */
-  bool GetRifsSupported (void) const;
   /**
    * \param bssid the BSSID of the network that this device belongs to.
    */
   void SetBssid (Mac48Address bssid);
 
   /**
-   * \return the station manager attached to this MAC.
+   * Accessor for the DCF object
+   *
+   * \return a smart pointer to Txop
    */
-  Ptr<WifiRemoteStationManager> GetWifiRemoteStationManager (void) const;
+  Ptr<Txop> GetTxop (void) const;
+  /**
+   * Accessor for a specified EDCA object
+   *
+   * \param ac the Access Category
+   * \return a smart pointer to a QosTxop
+   */
+  Ptr<QosTxop> GetQosTxop (AcIndex ac) const;
+  /**
+   * Accessor for a specified EDCA object
+   *
+   * \param tid the Traffic ID
+   * \return a smart pointer to a QosTxop
+   */
+  Ptr<QosTxop> GetQosTxop (uint8_t tid) const;
+  /**
+   * Get the wifi MAC queue of the (Qos)Txop associated with the given AC.
+   *
+   * \param ac the given Access Category
+   * \return the wifi MAC queue of the (Qos)Txop associated with the given AC
+   */
+  virtual Ptr<WifiMacQueue> GetTxopQueue (AcIndex ac) const;
+
+  /**
+   * Return whether the device supports QoS.
+   *
+   * \return true if QoS is supported, false otherwise
+   */
+  bool GetQosSupported () const;
+  /**
+   * Return whether the device supports ERP.
+   *
+   * \return true if ERP is supported, false otherwise
+   */
+  bool GetErpSupported () const;
+  /**
+   * Return whether the device supports DSSS.
+   *
+   * \return true if DSSS is supported, false otherwise
+   */
+  bool GetDsssSupported () const;
+  /**
+   * Return whether the device supports HT.
+   *
+   * \return true if HT is supported, false otherwise
+   */
+  bool GetHtSupported () const;
+  /**
+   * Return whether the device supports VHT.
+   *
+   * \return true if VHT is supported, false otherwise
+   */
+  bool GetVhtSupported () const;
+  /**
+   * Return whether the device supports HE.
+   *
+   * \return true if HE is supported, false otherwise
+   */
+  bool GetHeSupported () const;
+
   /**
    * Return the extended capabilities of the device.
    *
@@ -163,15 +194,31 @@ public:
    */
   HeCapabilities GetHeCapabilities (void) const;
 
-protected:
-  virtual void DoInitialize ();
-  virtual void DoDispose ();
+  /**
+   * Return the maximum A-MPDU size of the given Access Category.
+   *
+   * \param ac Access Category index
+   * \return the maximum A-MPDU size
+   */
+  uint32_t GetMaxAmpduSize (AcIndex ac) const;
+  /**
+   * Return the maximum A-MSDU size of the given Access Category.
+   *
+   * \param ac Access Category index
+   * \return the maximum A-MSDU size
+   */
+  uint16_t GetMaxAmsduSize (AcIndex ac) const;
 
-  Ptr<MacRxMiddle> m_rxMiddle;  //!< RX middle (defragmentation etc.)
-  Ptr<MacTxMiddle> m_txMiddle;  //!< TX middle (aggregation etc.)
-  Ptr<MacLow> m_low;            //!< MacLow (RTS, CTS, Data, Ack etc.)
+protected:
+  void DoInitialize () override;
+  void DoDispose () override;
+  void SetTypeOfStation (TypeOfStation type) override;
+
+  Ptr<MacRxMiddle> m_rxMiddle;                      //!< RX middle (defragmentation etc.)
+  Ptr<MacTxMiddle> m_txMiddle;                      //!< TX middle (aggregation etc.)
   Ptr<ChannelAccessManager> m_channelAccessManager; //!< channel access manager
-  Ptr<WifiPhy> m_phy;           //!< Wifi PHY
+  Ptr<WifiPhy> m_phy;                               //!< Wifi PHY
+  Ptr<FrameExchangeManager> m_feManager;            //!< Frame Exchange Manager
 
   Ptr<WifiRemoteStationManager> m_stationManager; //!< Remote station manager (rate control, RTS/CTS/fragmentation thresholds etc.)
 
@@ -193,13 +240,6 @@ protected:
   channel access function */
   EdcaQueues m_edca;
 
-  /**
-   * Accessor for the DCF object
-   *
-   * \return a smart pointer to Txop
-   */
-  Ptr<Txop> GetTxop (void) const;
-
   /**
    * Accessor for the AC_VO channel access function
    *
@@ -225,20 +265,6 @@ protected:
    */
   Ptr<QosTxop> GetBKQueue (void) const;
 
-  /**
-   * \param standard the PHY standard to be used
-   *
-   * This method is called by ns3::WifiMac::ConfigureStandard to
-   * complete the configuration process for a requested PHY standard.
-   *
-   * This method may be overridden by a derived class (e.g., in order
-   * to apply DCF or EDCA parameters specific to the usage model it is
-   * dealing with), in which case the reimplementation may choose to
-   * deal with certain values in the WifiPhyStandard enumeration, and
-   * chain up to this implementation to deal with the remainder.
-   */
-  void FinishConfigureStandard (WifiPhyStandard standard);
-
   /**
    * \param cwMin the minimum contention window size
    * \param cwMax the maximum contention window size
@@ -248,16 +274,6 @@ protected:
    */
   void ConfigureContentionWindow (uint32_t cwMin, uint32_t cwMax);
 
-  /**
-   * This method is invoked by a subclass to specify what type of
-   * station it is implementing. This is something that the channel
-   * access functions (instantiated within this class as QosTxop's)
-   * need to know.
-   *
-   * \param type the type of station.
-   */
-  void SetTypeOfStation (TypeOfStation type);
-
   /**
    * This method acts as the MacRxMiddle receive callback and is
    * invoked to notify us that a frame has been received. The
@@ -272,20 +288,6 @@ protected:
    * \param mpdu the MPDU that has been received.
    */
   virtual void Receive (Ptr<WifiMacQueueItem> mpdu);
-  /**
-   * The packet we sent was successfully received by the receiver
-   * (i.e. we received an Ack from the receiver).
-   *
-   * \param hdr the header of the packet that we successfully sent
-   */
-  virtual void TxOk (const WifiMacHeader &hdr);
-  /**
-   * The packet we sent was successfully received by the receiver
-   * (i.e. we did not receive an Ack from the receiver).
-   *
-   * \param hdr the header of the packet that we failed to sent
-   */
-  virtual void TxFailed (const WifiMacHeader &hdr);
 
   /**
    * Forward the packet up to the device.
@@ -304,54 +306,18 @@ protected:
    */
   virtual void DeaggregateAmsduAndForward (Ptr<WifiMacQueueItem> mpdu);
 
-  /**
-   * This method can be called to accept a received ADDBA Request. An
-   * ADDBA Response will be constructed and queued for transmission.
-   *
-   * \param reqHdr a pointer to the received ADDBA Request header.
-   * \param originator the MAC address of the originator.
-   */
-  void SendAddBaResponse (const MgtAddBaRequestHeader *reqHdr,
-                          Mac48Address originator);
-
   /**
    * Enable or disable QoS support for the device.
    *
    * \param enable whether QoS is supported
    */
   virtual void SetQosSupported (bool enable);
-  /**
-   * Return whether the device supports QoS.
-   *
-   * \return true if QoS is supported, false otherwise
-   */
-  bool GetQosSupported () const;
 
   /**
-   * Enable or disable HT support for the device.
-   *
-   * \param enable whether HT is supported
+   * Create a Frame Exchange Manager depending on the supported version
+   * of the standard.
    */
-  void SetHtSupported (bool enable);
-  /**
-   * Return whether the device supports HT.
-   *
-   * \return true if HT is supported, false otherwise
-   */
-  bool GetHtSupported () const;
-
-  /**
-   * Enable or disable VHT support for the device.
-   *
-   * \param enable whether VHT is supported
-   */
-  void SetVhtSupported (bool enable);
-  /**
-   * Return whether the device supports VHT.
-   *
-   * \return true if VHT is supported, false otherwise
-   */
-  bool GetVhtSupported () const;
+  void SetupFrameExchangeManager (void);
 
   /**
    * Enable or disable ERP support for the device.
@@ -359,12 +325,6 @@ protected:
    * \param enable whether ERP is supported
    */
   void SetErpSupported (bool enable);
-  /**
-   * Return whether the device supports ERP.
-   *
-   * \return true if ERP is supported, false otherwise
-   */
-  bool GetErpSupported () const;
 
   /**
    * Enable or disable DSSS support for the device.
@@ -372,25 +332,6 @@ protected:
    * \param enable whether DSSS is supported
    */
   void SetDsssSupported (bool enable);
-  /**
-   * Return whether the device supports DSSS.
-   *
-   * \return true if DSSS is supported, false otherwise
-   */
-  bool GetDsssSupported () const;
-
-  /**
-   * Enable or disable HE support for the device.
-   *
-   * \param enable whether HE is supported
-   */
-  void SetHeSupported (bool enable);
-  /**
-   * Return whether the device supports HE.
-   *
-   * \return true if HE is supported, false otherwise
-   */
-  bool GetHeSupported () const;
 
 private:
   /// type conversion operator
@@ -461,6 +402,8 @@ private:
    */
   void SetBkBlockAckInactivityTimeout (uint16_t timeout);
 
+  TypeOfStation m_typeOfStation;                        //!< the type of station
+
   /**
    * This Boolean is set \c true iff this WifiMac is to model
    * 802.11e/WMM style Quality of Service. It is exposed through the
@@ -486,10 +429,8 @@ private:
    */
   bool m_dsssSupported;
 
-  /// Enable aggregation function
-  void EnableAggregation (void);
-  /// Disable aggregation function
-  void DisableAggregation (void);
+  Mac48Address m_address;   ///< MAC address of this station
+  Mac48Address m_bssid;     ///< the BSSID
 
   uint16_t m_voMaxAmsduSize; ///< maximum A-MSDU size for AC_VO (in bytes)
   uint16_t m_viMaxAmsduSize; ///< maximum A-MSDU size for AC_VI (in bytes)
@@ -504,8 +445,89 @@ private:
   TracedCallback<const WifiMacHeader &> m_txOkCallback; ///< transmit OK callback
   TracedCallback<const WifiMacHeader &> m_txErrCallback; ///< transmit error callback
 
+  /// TracedCallback for acked/nacked MPDUs typedef
+  typedef TracedCallback<Ptr<const WifiMacQueueItem>> MpduTracedCallback;
+
+  MpduTracedCallback m_ackedMpduCallback;  ///< ack'ed MPDU callback
+  MpduTracedCallback m_nackedMpduCallback; ///< nack'ed MPDU callback
+
+  /**
+   * TracedCallback signature for MPDU drop events.
+   *
+   * \param reason the reason why the MPDU was dropped (\see WifiMacDropReason)
+   * \param mpdu the dropped MPDU
+   */
+  typedef void (* DroppedMpduCallback)(WifiMacDropReason reason, Ptr<const WifiMacQueueItem> mpdu);
+
+  /// TracedCallback for MPDU drop events typedef
+  typedef TracedCallback<WifiMacDropReason, Ptr<const WifiMacQueueItem>> DroppedMpduTracedCallback;
+
+  /**
+   * This trace indicates that an MPDU was dropped for the given reason.
+   */
+  DroppedMpduTracedCallback m_droppedMpduCallback;
+
+  /**
+   * TracedCallback signature for MPDU response timeout events.
+   *
+   * \param reason the reason why the timer was started
+   * \param mpdu the MPDU whose response was not received before the timeout
+   * \param txVector the TXVECTOR used to transmit the MPDU
+   */
+  typedef void (* MpduResponseTimeoutCallback)(uint8_t reason, Ptr<const WifiMacQueueItem> mpdu,
+                                               const WifiTxVector& txVector);
+
+  /// TracedCallback for MPDU response timeout events typedef
+  typedef TracedCallback<uint8_t, Ptr<const WifiMacQueueItem>, const WifiTxVector&> MpduResponseTimeoutTracedCallback;
+
+  /**
+   * MPDU response timeout traced callback.
+   * This trace source is fed by a WifiTxTimer object.
+   */
+  MpduResponseTimeoutTracedCallback m_mpduResponseTimeoutCallback;
+
+  /**
+   * TracedCallback signature for PSDU response timeout events.
+   *
+   * \param reason the reason why the timer was started
+   * \param psdu the PSDU whose response was not received before the timeout
+   * \param txVector the TXVECTOR used to transmit the PSDU
+   */
+  typedef void (* PsduResponseTimeoutCallback)(uint8_t reason, Ptr<const WifiPsdu> psdu,
+                                               const WifiTxVector& txVector);
+
+  /// TracedCallback for PSDU response timeout events typedef
+  typedef TracedCallback<uint8_t, Ptr<const WifiPsdu>, const WifiTxVector&> PsduResponseTimeoutTracedCallback;
+
+  /**
+   * PSDU response timeout traced callback.
+   * This trace source is fed by a WifiTxTimer object.
+   */
+  PsduResponseTimeoutTracedCallback m_psduResponseTimeoutCallback;
+
+  /**
+   * TracedCallback signature for PSDU map response timeout events.
+   *
+   * \param reason the reason why the timer was started
+   * \param psduMap the PSDU map for which not all responses were received before the timeout
+   * \param missingStations the MAC addresses of the stations that did not respond
+   * \param nTotalStations the total number of stations that had to respond
+   */
+  typedef void (* PsduMapResponseTimeoutCallback)(uint8_t reason, WifiPsduMap* psduMap,
+                                                  const std::set<Mac48Address>* missingStations,
+                                                  std::size_t nTotalStations);
+
+  /// TracedCallback for PSDU map response timeout events typedef
+  typedef TracedCallback<uint8_t, WifiPsduMap*, const std::set<Mac48Address>*, std::size_t> PsduMapResponseTimeoutTracedCallback;
+
+  /**
+   * PSDU map response timeout traced callback.
+   * This trace source is fed by a WifiTxTimer object.
+   */
+  PsduMapResponseTimeoutTracedCallback m_psduMapResponseTimeoutCallback;
+
   bool m_shortSlotTimeSupported; ///< flag whether short slot time is supported
-  bool m_rifsSupported; ///< flag whether RIFS is supported (deprecated)
+  bool m_ctsToSelfSupported;     ///< flag indicating whether CTS-To-Self is supported
 };
 
 } //namespace ns3
