@@ -30,11 +30,14 @@
 #include "ns3/spectrum-channel.h"
 #include "ns3/spectrum-model.h"
 #include "wifi-phy.h"
+#include <map>
+
+class SpectrumWifiPhyFilterTest;
 
 namespace ns3 {
 
 class WifiSpectrumPhyInterface;
-class WifiPpdu;
+struct WifiSpectrumSignalParameters;
 
 /**
  * \brief 802.11 PHY layer model
@@ -51,6 +54,9 @@ class WifiPpdu;
 class SpectrumWifiPhy : public WifiPhy
 {
 public:
+  /// allow SpectrumWifiPhyFilterTest class access
+  friend class ::SpectrumWifiPhyFilterTest;
+
   /**
    * \brief Get the type ID.
    * \return the object TypeId
@@ -61,8 +67,10 @@ public:
   virtual ~SpectrumWifiPhy ();
 
   // Implementation of pure virtual method.
-  void StartTx (Ptr<WifiPpdu> ppdu);
-  Ptr<Channel> GetChannel (void) const;
+  void StartTx (Ptr<WifiPpdu> ppdu) override;
+  Ptr<Channel> GetChannel (void) const override;
+  uint16_t GetGuardBandwidth (uint16_t currentChannelWidth) const override;
+  std::tuple<double, double, double> GetTxMaskRejectionParams (void) const override;
 
   /**
    * Set the SpectrumChannel this SpectrumWifiPhy is to be connected to.
@@ -79,16 +87,6 @@ public:
    */
   void StartRx (Ptr<SpectrumSignalParameters> rxParams);
 
-  /**
-   * Get the center frequency of the channel corresponding the current TxVector rather than
-   * that of the supported channel width.
-   * Consider that this "primary channel" is on the lower part for the time being.
-   *
-   * \param txVector the TXVECTOR that has the channel width that is to be used
-   * \return the center frequency in MHz corresponding to the channel width to be used
-   */
-  uint16_t GetCenterFrequencyForChannelWidth (WifiTxVector txVector) const;
-
   /**
    * Method to encapsulate the creation of the WifiSpectrumPhyInterface
    * object (used to bind the WifiSpectrumPhy to a SpectrumChannel) and
@@ -120,26 +118,13 @@ public:
    *         for all SpectrumValues that are passed to StartRx. If 0 is
    *         returned, it means that any model will be accepted.
    */
-  Ptr<const SpectrumModel> GetRxSpectrumModel () const;
+  Ptr<const SpectrumModel> GetRxSpectrumModel ();
 
   /**
    * \return the width of each band (Hz)
    */
   uint32_t GetBandBandwidth (void) const;
 
-  /**
-   * \param currentChannelWidth channel width of the current transmission (MHz)
-   * \return the width of the guard band (MHz)
-   *
-   * Note: in order to properly model out of band transmissions for OFDM, the guard
-   * band has been configured so as to expand the modeled spectrum up to the
-   * outermost referenced point in "Transmit spectrum mask" sections' PSDs of
-   * each PHY specification of 802.11-2016 standard. It thus ultimately corresponds
-   * to the current channel bandwidth (which can be different from devices max
-   * channel width).
-   */
-  uint16_t GetGuardBandwidth (uint16_t currentChannelWidth) const;
-
   /**
    * Callback invoked when the PHY model starts to process a signal
    *
@@ -152,43 +137,73 @@ public:
 
   // The following four methods call to the base WifiPhy class method
   // but also generate a new SpectrumModel if called during runtime
-  virtual void SetChannelNumber (uint8_t id);
-  virtual void SetFrequency (uint16_t freq);
-  virtual void SetChannelWidth (uint16_t channelwidth);
-  virtual void ConfigureStandard (WifiPhyStandard standard);
+  void SetChannelNumber (uint8_t id) override;
+  void SetFrequency (uint16_t freq) override;
+  void SetChannelWidth (uint16_t channelwidth) override;
+  void ConfigureStandardAndBand (WifiPhyStandard standard, WifiPhyBand band) override;
+
+  /**
+   * This function is sending the signal to the Spectrum channel
+   * after finishing the configuration of the transmit parameters.
+   *
+   * \param txParams the parameters to be provided to the Spectrum channel
+   */
+  void Transmit (Ptr<WifiSpectrumSignalParameters> txParams);
 
 protected:
-  // Inherited
-  void DoDispose (void);
-  void DoInitialize (void);
+  void DoDispose (void) override;
+  void DoInitialize (void) override;
 
+  /**
+   * Get the start band index and the stop band index for a given band
+   *
+   * \param bandWidth the width of the band to be returned (MHz)
+   * \param bandIndex the index of the band to be returned
+   *
+   * \return a pair of start and stop indexes that defines the band
+   */
+  WifiSpectrumBand GetBand (uint16_t bandWidth, uint8_t bandIndex = 0) override;
 
 private:
   /**
-   * \param centerFrequency center frequency (MHz)
-   * \param channelWidth channel width (MHz) of the channel for the current transmission
-   * \param txPowerW power in W to spread across the bands
-   * \param modulationClass the modulation class
-   * \return Pointer to SpectrumValue
+   * \param bandWidth the width (MHz) of the band used for the OFDMA transmission. Must be
+   *                  a multiple of 20 MHz
+   * \param guardBandwidth width of the guard band (MHz)
+   * \param range the subcarrier range of the HE RU
+   * \param bandIndex the index (starting at 0) of the band within the operating channel
+   * \return the converted subcarriers
    *
-   * This is a helper function to create the right TX PSD corresponding
-   * to the standard in use.
+   * This is a helper function to convert HE RU subcarriers, which are relative to the center frequency subcarrier, to the indexes used by the Spectrum model.
    */
-  Ptr<SpectrumValue> GetTxPowerSpectralDensity (uint16_t centerFrequency, uint16_t channelWidth, double txPowerW, WifiModulationClass modulationClass) const;
+  WifiSpectrumBand ConvertHeRuSubcarriers (uint16_t bandWidth, uint16_t guardBandwidth,
+                                           HeRu::SubcarrierRange range, uint8_t bandIndex = 0) const override;
 
   /**
    * Perform run-time spectrum model change
    */
   void ResetSpectrumModel (void);
+  /**
+   * This function is called to update the bands handled by the InterferenceHelper.
+   */
+  void UpdateInterferenceHelperBands (void);
 
-  Ptr<SpectrumChannel> m_channel;        //!< SpectrumChannel that this SpectrumWifiPhy is connected to
+  Ptr<SpectrumChannel> m_channel; //!< SpectrumChannel that this SpectrumWifiPhy is connected to
 
   Ptr<WifiSpectrumPhyInterface> m_wifiSpectrumPhyInterface; //!< Spectrum PHY interface
   Ptr<AntennaModel> m_antenna;                              //!< antenna model
   mutable Ptr<const SpectrumModel> m_rxSpectrumModel;       //!< receive spectrum model
+
+  /// Map a spectrum band associated with an RU to the RU specification
+  typedef std::map<WifiSpectrumBand, HeRu::RuSpec> RuBand;
+
+  std::map<uint16_t, RuBand> m_ruBands;  /**< For each channel width, store all the distinct spectrum
+                                              bands associated with every RU in a channel of that width */
   bool m_disableWifiReception;                              //!< forces this PHY to fail to sync on any signal
   TracedCallback<bool, uint32_t, double, Time> m_signalCb;  //!< Signal callback
 
+  double m_txMaskInnerBandMinimumRejection; //!< The minimum rejection (in dBr) for the inner band of the transmit spectrum mask
+  double m_txMaskOuterBandMinimumRejection; //!< The minimum rejection (in dBr) for the outer band of the transmit spectrum mask
+  double m_txMaskOuterBandMaximumRejection; //!< The maximum rejection (in dBr) for the outer band of the transmit spectrum mask
 };
 
 } //namespace ns3
