@@ -47,9 +47,10 @@ public:
    * \return the object TypeId
    */
   static TypeId GetTypeId ();
-  TypeId GetInstanceTypeId () const;
-  virtual uint32_t GetSerializedSize () const;
-  virtual void Serialize (Buffer::Iterator start) const;
+
+  TypeId GetInstanceTypeId () const override;
+  uint32_t GetSerializedSize () const override;
+  void Serialize (Buffer::Iterator start) const override;
   /**
    * \attention This variant should not be used but is implemented due to
    * backward compatibility reasons
@@ -57,7 +58,7 @@ public:
    * \param start buffer location to start deserializing from
    * \return number of bytes deserialized
    */
-  virtual uint32_t Deserialize (Buffer::Iterator start);
+  uint32_t Deserialize (Buffer::Iterator start) override;
   /**
    * Deserialize a number of WifiInformationElements 
    *
@@ -67,8 +68,8 @@ public:
    * \param end ending buffer location
    * \return number of bytes deserialized
    */
-  virtual uint32_t Deserialize (Buffer::Iterator start, Buffer::Iterator end);
-  virtual void Print (std::ostream &os) const;
+  uint32_t Deserialize (Buffer::Iterator start, Buffer::Iterator end) override;
+  void Print (std::ostream &os) const override;
 
   /**
    * \brief Needed when you try to deserialize a lonely IE inside other header
