@@ -190,6 +190,8 @@ typedef uint8_t WifiInformationElementId;
 
 #define IE_EXT_HE_CAPABILITIES                  ((WifiInformationElementId)35)
 #define IE_EXT_HE_OPERATION                     ((WifiInformationElementId)36)
+#define IE_EXT_UORA_PARAMETER_SET               ((WifiInformationElementId)37)
+#define IE_EXT_MU_EDCA_PARAMETER_SET            ((WifiInformationElementId)38)
 
 /**
  * \brief Information element, as defined in 802.11-2007 standard
@@ -239,7 +241,7 @@ public:
    *
    * \return an iterator
    */
-  Buffer::Iterator Serialize (Buffer::Iterator i) const;
+  virtual Buffer::Iterator Serialize (Buffer::Iterator i) const;
   /**
    * Deserialize entire IE, which must be present. The iterator
    * passed in must be pointing at the Element ID (i.e., the very
@@ -268,7 +270,7 @@ public:
    *
    * \return the size of the serialized IE in bytes
    */
-  uint16_t GetSerializedSize () const;
+  virtual uint16_t GetSerializedSize () const;
 
   // Each subclass must implement these pure virtual functions:
   /**
