@@ -39,7 +39,12 @@ enum
 /// subtype enumeration
 enum
 {
-  //Reserved: 0 - 6
+  //Reserved: 0 - 1
+  SUBTYPE_CTL_TRIGGER = 2,
+  //Reserved: 3
+  SUBTYPE_CTL_BEAMFORMINGRPOLL = 4,
+  SUBTYPE_CTL_NDPANNOUNCE = 5,
+  SUBTYPE_CTL_CTLFRAMEEXT = 6,
   SUBTYPE_CTL_CTLWRAPPER = 7,
   SUBTYPE_CTL_BACKREQ = 8,
   SUBTYPE_CTL_BACKRESP = 9,
@@ -51,13 +56,26 @@ enum
 };
 
 WifiMacHeader::WifiMacHeader ()
-  : m_ctrlMoreData (0),
+  : m_ctrlMoreFrag (0),
+    m_ctrlRetry (0),
+    m_ctrlMoreData (0),
     m_ctrlWep (0),
     m_ctrlOrder (0),
+    m_duration (0),
+    m_seqFrag (0),
+    m_seqSeq (0),
+    m_qosEosp (0),
+    m_qosAckPolicy (0),  // Normal Ack
     m_amsduPresent (0)
 {
 }
 
+WifiMacHeader::WifiMacHeader (WifiMacType type)
+  : WifiMacHeader ()
+{
+  SetType (type);
+}
+
 WifiMacHeader::~WifiMacHeader ()
 {
 }
@@ -115,6 +133,10 @@ WifiMacHeader::SetType (WifiMacType type, bool resetToDsFromDs)
 {
   switch (type)
     {
+    case WIFI_MAC_CTL_TRIGGER:
+      m_ctrlType = TYPE_CTL;
+      m_ctrlSubtype = SUBTYPE_CTL_TRIGGER;
+      break;
     case WIFI_MAC_CTL_CTLWRAPPER:
       m_ctrlType = TYPE_CTL;
       m_ctrlSubtype = SUBTYPE_CTL_CTLWRAPPER;
@@ -376,6 +398,13 @@ void WifiMacHeader::SetQosTxopLimit (uint8_t txop)
   m_qosStuff = txop;
 }
 
+void
+WifiMacHeader::SetQosQueueSize (uint8_t size)
+{
+  m_qosEosp = 1;
+  m_qosStuff = size;
+}
+
 void WifiMacHeader::SetQosMeshControlPresent (void)
 {
   //Mark bit 0 of this variable instead of bit 8, since m_qosStuff is
@@ -454,6 +483,8 @@ WifiMacHeader::GetType (void) const
     case TYPE_CTL:
       switch (m_ctrlSubtype)
         {
+        case SUBTYPE_CTL_TRIGGER:
+          return WIFI_MAC_CTL_TRIGGER;
         case SUBTYPE_CTL_BACKREQ:
           return WIFI_MAC_CTL_BACKREQ;
         case SUBTYPE_CTL_BACKRESP:
@@ -718,6 +749,12 @@ WifiMacHeader::IsBlockAck (void) const
   return (GetType () == WIFI_MAC_CTL_BACKRESP) ? true : false;
 }
 
+bool
+WifiMacHeader::IsTrigger (void) const
+{
+  return (GetType () == WIFI_MAC_CTL_TRIGGER) ? true : false;
+}
+
 uint16_t
 WifiMacHeader::GetRawDuration (void) const
 {
@@ -828,6 +865,13 @@ WifiMacHeader::GetQosTid (void) const
   return m_qosTid;
 }
 
+uint8_t
+WifiMacHeader::GetQosQueueSize (void) const
+{
+  NS_ASSERT (m_qosEosp == 1);
+  return m_qosStuff;
+}
+
 uint16_t
 WifiMacHeader::GetFrameControl (void) const
 {
@@ -900,6 +944,7 @@ WifiMacHeader::GetSize (void) const
         case SUBTYPE_CTL_RTS:
         case SUBTYPE_CTL_BACKREQ:
         case SUBTYPE_CTL_BACKRESP:
+        case SUBTYPE_CTL_TRIGGER:
         case SUBTYPE_CTL_END:
         case SUBTYPE_CTL_END_ACK:
           size = 2 + 2 + 6 + 6;
@@ -945,6 +990,7 @@ case WIFI_MAC_ ## x: \
       FOO (CTL_BACKRESP);
       FOO (CTL_END);
       FOO (CTL_END_ACK);
+      FOO (CTL_TRIGGER);
 
       FOO (MGT_BEACON);
       FOO (MGT_ASSOCIATION_REQUEST);
@@ -1018,6 +1064,7 @@ WifiMacHeader::Print (std::ostream &os) const
   switch (GetType ())
     {
     case WIFI_MAC_CTL_RTS:
+    case WIFI_MAC_CTL_TRIGGER:
       os << "Duration/ID=" << m_duration << "us"
          << ", RA=" << m_addr1 << ", TA=" << m_addr2;
       break;
@@ -1127,6 +1174,7 @@ WifiMacHeader::Serialize (Buffer::Iterator i) const
       switch (m_ctrlSubtype)
         {
         case SUBTYPE_CTL_RTS:
+        case SUBTYPE_CTL_TRIGGER:
         case SUBTYPE_CTL_BACKREQ:
         case SUBTYPE_CTL_BACKRESP:
         case SUBTYPE_CTL_END:
@@ -1182,6 +1230,7 @@ WifiMacHeader::Deserialize (Buffer::Iterator start)
       switch (m_ctrlSubtype)
         {
         case SUBTYPE_CTL_RTS:
+        case SUBTYPE_CTL_TRIGGER:
         case SUBTYPE_CTL_BACKREQ:
         case SUBTYPE_CTL_BACKRESP:
         case SUBTYPE_CTL_END:
