@@ -22,6 +22,7 @@
 #define WIFI_REMOTE_STATION_MANAGER_H
 
 #include <array>
+#include <unordered_map>
 #include "ns3/traced-callback.h"
 #include "ns3/object.h"
 #include "ns3/data-rate.h"
@@ -30,9 +31,9 @@
 #include "wifi-utils.h"
 #include "qos-utils.h"
 #include "wifi-remote-station-info.h"
-#include "ht-capabilities.h"
-#include "vht-capabilities.h"
-#include "he-capabilities.h"
+#include "ns3/ht-capabilities.h"
+#include "ns3/vht-capabilities.h"
+#include "ns3/he-capabilities.h"
 
 namespace ns3 {
 
@@ -40,9 +41,11 @@ class WifiPhy;
 class WifiMac;
 class WifiMacHeader;
 class Packet;
+class WifiMacQueueItem;
 class WifiTxVector;
 
 struct WifiRemoteStationState;
+struct RxSignalInfo;
 
 /**
  * \brief hold per-remote-station state.
@@ -58,7 +61,8 @@ struct WifiRemoteStationState;
 struct WifiRemoteStation
 {
   virtual ~WifiRemoteStation () {};
-  WifiRemoteStationState *m_state;  //!< Remote station state
+  WifiRemoteStationState *m_state;                 //!< Remote station state
+  std::pair<double, Time> m_rssiAndUpdateTimePair; //!< RSSI (in dBm) of the most recent packet received from the remote station along with update time
 };
 
 /**
@@ -89,11 +93,15 @@ struct WifiRemoteStationState
   WifiModeList m_operationalRateSet; //!< operational rate set
   WifiModeList m_operationalMcsSet;  //!< operational MCS set
   Mac48Address m_address;            //!< Mac48Address of the remote station
+  uint16_t m_aid;                    /**< AID of the remote station (unused if this object
+                                          is installed on a non-AP station) */
   WifiRemoteStationInfo m_info;      //!< remote station info
+  bool m_dsssSupported;              //!< Flag if DSSS is supported by the remote station
+  bool m_erpOfdmSupported;           //!< Flag if ERP OFDM is supported by the remote station
+  bool m_ofdmSupported;              //!< Flag if OFDM is supported by the remote station
   Ptr<const HtCapabilities> m_htCapabilities;   //!< remote station HT capabilities
   Ptr<const VhtCapabilities> m_vhtCapabilities; //!< remote station VHT capabilities
   Ptr<const HeCapabilities> m_heCapabilities;   //!< remote station HE capabilities
-
   uint16_t m_channelWidth;    //!< Channel width (in MHz) supported by the remote station
   uint16_t m_guardInterval;   //!< HE Guard interval duration (in nanoseconds) supported by the remote station
   uint8_t m_ness;             //!< Number of extended spatial streams of the remote station
@@ -129,13 +137,13 @@ public:
   };
 
   /**
-   * A vector of WifiRemoteStations
+   * A map of WifiRemoteStations with Mac48Address as key
    */
-  typedef std::vector <WifiRemoteStation *> Stations;
+  using Stations = std::unordered_map <Mac48Address, WifiRemoteStation *, WifiAddressHash>;
   /**
-   * A vector of WifiRemoteStationStates
+   * A map of WifiRemoteStationStates with Mac48Address as key
    */
-  typedef std::vector <WifiRemoteStationState *> StationStates;
+  using StationStates = std::unordered_map <Mac48Address, WifiRemoteStationState *, WifiAddressHash>;
 
   /**
    * Set up PHY associated with this device since it is the object that
@@ -152,6 +160,16 @@ public:
    */
   virtual void SetupMac (const Ptr<WifiMac> mac);
 
+  /**
+   * Assign a fixed random variable stream number to the random variables
+   * used by this model.  Return the number of streams (possibly zero) that
+   * have been assigned.
+   *
+   * \param stream first stream index to use
+   * \return the number of stream indices assigned by this model
+   */
+  virtual int64_t AssignStreams (int64_t stream);
+
   /**
    * Sets the maximum STA short retry count (SSRC).
    *
@@ -184,12 +202,14 @@ public:
    * \param threshold the fragmentation threshold
    */
   void SetFragmentationThreshold (uint32_t threshold);
-  /**
-   * Typically called to update the fragmentation threshold at the start of a new transmission.
-   * This avoid that the fragmentation threshold gets changed during a transmission (see bug 730).
-   */
-  void UpdateFragmentationThreshold (void);
 
+  /**
+   * Record the AID of a remote station. Should only be called by APs.
+   *
+   * \param remoteAddress the MAC address of the remote station
+   * \param aid the Association ID
+   */
+  void SetAssociationId (Mac48Address remoteAddress, uint16_t aid);
   /**
    * Records QoS support of the remote station.
    *
@@ -258,23 +278,11 @@ public:
    */
   bool GetHeSupported (void) const;
   /**
-   * Enable or disable PCF capability support.
+   * Return whether the device has LDPC support enabled.
    *
-   * \param enable enable or disable PCF capability support
+   * \return true if LDPC support is enabled, false otherwise
    */
-  void SetPcfSupported (bool enable);
-  /**
-   * Return whether the device has PCF capability support enabled.
-   *
-   * \return true if PCF capability support is enabled, false otherwise
-   */
-  bool GetPcfSupported (void) const;
-  /**
-   * Return whether the device has HT Greenfield support enabled.
-   *
-   * \return true if HT Grenfield support is enabled, false otherwise
-   */
-  bool GetGreenfieldSupported (void) const;
+  bool GetLdpcSupported (void) const;
   /**
    * Return whether the device has SGI support enabled.
    *
@@ -313,19 +321,6 @@ public:
    *         false otherwise
    */
   bool GetUseNonHtProtection (void) const;
-  /**
-   * Enable or disable protection for stations that do not support HT Greenfield format.
-   *
-   * \param enable enable or disable protection for stations that do not support HT Greenfield format
-   */
-  void SetUseGreenfieldProtection (bool enable);
-  /**
-   * Return whether protection for stations that do not support HT Greenfield format is enabled.
-   *
-   * \return true if protection for stations that do not support HT Greenfield is enabled,
-   *         false otherwise
-   */
-  bool GetUseGreenfieldProtection (void) const;
   /**
    * Enable or disable short PHY preambles.
    *
@@ -352,19 +347,6 @@ public:
    *         false otherwise
    */
   bool GetShortSlotTimeEnabled (void) const;
-  /**
-   * Permit or prohibit RIFS.
-   *
-   * \param allow permit or prohibit RIFS
-   */
-  void SetRifsPermitted (bool allow);
-  /**
-   * Return whether the device can use RIFS.
-   *
-   * \return true if RIFS is permitted,
-   *         false otherwise
-   */
-  bool GetRifsPermitted (void) const;
 
   /**
    * Reset the station, invoked in a STA upon dis-association or in an AP upon reboot.
@@ -414,14 +396,14 @@ public:
    */
   WifiMode GetNonErpBasicMode (uint8_t i) const;
   /**
-   * Return whether the station supports Greenfield or not.
+   * Return whether the station supports LDPC or not.
    *
    * \param address the address of the station
    *
-   * \return true if Greenfield is supported by the station,
+   * \return true if LDPC is supported by the station,
    *         false otherwise
    */
-  bool GetGreenfieldSupported (Mac48Address address) const;
+  bool GetLdpcSupported (Mac48Address address) const;
   /**
    * Return whether the station supports short PHY preamble or not.
    *
@@ -449,6 +431,13 @@ public:
    *         false otherwise
    */
   bool GetQosSupported (Mac48Address address) const;
+  /**
+   * Get the AID of a remote station. Should only be called by APs.
+   *
+   * \param remoteAddress the MAC address of the remote station
+   * \return the Association ID if the station is associated, SU_STA_ID otherwise
+   */
+  uint16_t GetAssociationId (Mac48Address remoteAddress) const;
   /**
    * Add a given Modulation and Coding Scheme (MCS) index to
    * the set of basic MCS.
@@ -516,6 +505,33 @@ public:
    * \return the number of MCS supported by the station
    */
   uint8_t GetNMcsSupported (Mac48Address address) const;
+  /**
+   * Return whether the station supports DSSS or not.
+   *
+   * \param address the address of the station
+   *
+   * \return true if DSSS is supported by the station,
+   *         false otherwise
+   */
+  bool GetDsssSupported (const Mac48Address& address) const;
+  /**
+   * Return whether the station supports ERP OFDM or not.
+   *
+   * \param address the address of the station
+   *
+   * \return true if ERP OFDM is supported by the station,
+   *         false otherwise
+   */
+  bool GetErpOfdmSupported (const Mac48Address& address) const;
+  /**
+   * Return whether the station supports OFDM or not.
+   *
+   * \param address the address of the station
+   *
+   * \return true if OFDM is supported by the station,
+   *         false otherwise
+   */
+  bool GetOfdmSupported (const Mac48Address& address) const;
   /**
    * Return whether the station supports HT or not.
    *
@@ -666,6 +682,15 @@ public:
    *         transmission of the data packet itself.
    */
   WifiTxVector GetRtsTxVector (Mac48Address address);
+  /**
+   * Return a TXVECTOR for the CTS frame given the destination and the mode of the RTS
+   * used by the sender.
+   *
+   * \param to the MAC address of the CTS receiver
+   * \param rtsTxMode the mode of the RTS used by the sender
+   * \return TXVECTOR for the CTS
+   */
+  WifiTxVector GetCtsTxVector (Mac48Address to, WifiMode rtsTxMode) const;
   /**
    * Since CTS-to-self parameters are not dependent on the station,
    * it is implemented in wifi remote station manager
@@ -674,72 +699,84 @@ public:
    *         transmission of the data packet itself.
    */
   WifiTxVector GetCtsToSelfTxVector (void);
+  /**
+   * Return a TXVECTOR for the Ack frame given the destination and the mode of the Data
+   * used by the sender.
+   *
+   * \param to the MAC address of the Ack receiver
+   * \param dataTxVector the TXVECTOR of the Data used by the sender
+   * \return TXVECTOR for the Ack
+   */
+  WifiTxVector GetAckTxVector (Mac48Address to, const WifiTxVector& dataTxVector) const;
+  /**
+   * Return a TXVECTOR for the BlockAck frame given the destination and the mode of the Data
+   * used by the sender.
+   *
+   * \param to the MAC address of the BlockAck receiver
+   * \param dataTxVector the TXVECTOR of the Data used by the sender
+   * \return TXVECTOR for the BlockAck
+   */
+  WifiTxVector GetBlockAckTxVector (Mac48Address to, const WifiTxVector& dataTxVector) const;
+  /**
+   * Get control answer mode function.
+   *
+   * \param reqMode request mode
+   * \return control answer mode
+   */
+  WifiMode GetControlAnswerMode (WifiMode reqMode) const;
 
   /**
    * Should be invoked whenever the RtsTimeout associated to a transmission
    * attempt expires.
    *
-   * \param address the address of the receiver
    * \param header MAC header of the DATA packet
    */
-  void ReportRtsFailed (Mac48Address address, const WifiMacHeader *header);
+  void ReportRtsFailed (const WifiMacHeader& header);
   /**
    * Should be invoked whenever the AckTimeout associated to a transmission
    * attempt expires.
    *
-   * \param address the address of the receiver
-   * \param header MAC header of the DATA packet
-   * \param packetSize the size of the DATA packet
+   * \param mpdu the MPDU whose transmission failed
    */
-  void ReportDataFailed (Mac48Address address, const WifiMacHeader *header,
-                         uint32_t packetSize);
+  void ReportDataFailed (Ptr<const WifiMacQueueItem> mpdu);
   /**
    * Should be invoked whenever we receive the CTS associated to an RTS
    * we just sent. Note that we also get the SNR of the RTS we sent since
    * the receiver put a SnrTag in the CTS.
    *
-   * \param address the address of the receiver
    * \param header MAC header of the DATA packet
    * \param ctsSnr the SNR of the CTS we received
    * \param ctsMode the WifiMode the receiver used to send the CTS
    * \param rtsSnr the SNR of the RTS we sent
    */
-  void ReportRtsOk (Mac48Address address, const WifiMacHeader *header,
+  void ReportRtsOk (const WifiMacHeader& header,
                     double ctsSnr, WifiMode ctsMode, double rtsSnr);
   /**
    * Should be invoked whenever we receive the ACK associated to a data packet
    * we just sent.
    *
-   * \param address the address of the receiver
-   * \param header MAC header of the DATA packet
+   * \param mpdu the MPDU
    * \param ackSnr the SNR of the ACK we received
    * \param ackMode the WifiMode the receiver used to send the ACK
    * \param dataSnr the SNR of the DATA we sent
    * \param dataTxVector the TXVECTOR of the DATA we sent
-   * \param packetSize the size of the DATA packet
    */
-  void ReportDataOk (Mac48Address address, const WifiMacHeader *header,
-                     double ackSnr, WifiMode ackMode,
-                     double dataSnr, WifiTxVector dataTxVector,
-                     uint32_t packetSize);
+  void ReportDataOk (Ptr<const WifiMacQueueItem> mpdu, double ackSnr,
+                     WifiMode ackMode, double dataSnr, WifiTxVector dataTxVector);
   /**
    * Should be invoked after calling ReportRtsFailed if
    * NeedRetransmission returns false
    *
-   * \param address the address of the receiver
    * \param header MAC header of the DATA packet
    */
-  void ReportFinalRtsFailed (Mac48Address address, const WifiMacHeader *header);
+  void ReportFinalRtsFailed (const WifiMacHeader& header);
   /**
    * Should be invoked after calling ReportDataFailed if
    * NeedRetransmission returns false
    *
-   * \param address the address of the receiver
-   * \param header MAC header of the DATA packet
-   * \param packetSize the size of the DATA packet
+   * \param mpdu the MPDU which was discarded
    */
-  void ReportFinalDataFailed (Mac48Address address, const WifiMacHeader *header,
-                              uint32_t packetSize);
+  void ReportFinalDataFailed (Ptr<const WifiMacQueueItem> mpdu);
   /**
    * Typically called per A-MPDU, either when a Block ACK was successfully
    * received or when a BlockAckTimeout has elapsed.
@@ -752,17 +789,17 @@ public:
    * \param dataSnr data SNR reported by remote station
    * \param dataTxVector the TXVECTOR of the MPDUs we sent
    */
-  void ReportAmpduTxStatus (Mac48Address address, uint8_t nSuccessfulMpdus, uint8_t nFailedMpdus,
+  void ReportAmpduTxStatus (Mac48Address address, uint16_t nSuccessfulMpdus, uint16_t nFailedMpdus,
                             double rxSnr, double dataSnr, WifiTxVector dataTxVector);
 
   /**
    * \param address remote address
-   * \param rxSnr the SNR of the packet received
-   * \param txMode the transmission mode used for the packet received
+   * \param rxSignalInfo the info on the received signal (\see RxSignalInfo)
+   * \param txVector the TXVECTOR used for the packet received
    *
    * Should be invoked whenever a packet is successfully received.
    */
-  void ReportRxOk (Mac48Address address, double rxSnr, WifiMode txMode);
+  void ReportRxOk (Mac48Address address, RxSignalInfo rxSignalInfo, WifiTxVector txVector);
 
   /**
    * \param header MAC header
@@ -783,55 +820,40 @@ public:
   bool NeedCtsToSelf (WifiTxVector txVector);
 
   /**
-   * \param address remote address
-   * \param header MAC header
-   * \param packet the packet to send
+   * \param mpdu the MPDU to send
    *
    * \return true if we want to resend a packet after a failed transmission attempt,
    *         false otherwise.
    */
-  bool NeedRetransmission (Mac48Address address, const WifiMacHeader *header,
-                           Ptr<const Packet> packet);
+  bool NeedRetransmission (Ptr<const WifiMacQueueItem> mpdu);
   /**
-   * \param address remote address
-   * \param header MAC header
-   * \param packet the packet to send
+   * \param mpdu the MPDU to send
    *
    * \return true if this packet should be fragmented,
    *         false otherwise.
    */
-  bool NeedFragmentation (Mac48Address address, const WifiMacHeader *header,
-                          Ptr<const Packet> packet);
+  bool NeedFragmentation (Ptr<const WifiMacQueueItem> mpdu);
   /**
-   * \param address remote address
-   * \param header MAC header
-   * \param packet the packet to send
+   * \param mpdu the MPDU to send
    * \param fragmentNumber the fragment index of the next fragment to send (starts at zero).
    *
    * \return the size of the corresponding fragment.
    */
-  uint32_t GetFragmentSize (Mac48Address address, const WifiMacHeader *header,
-                            Ptr<const Packet> packet, uint32_t fragmentNumber);
+  uint32_t GetFragmentSize (Ptr<const WifiMacQueueItem> mpdu, uint32_t fragmentNumber);
   /**
-   * \param address remote address
-   * \param header MAC header
-   * \param packet the packet to send
+   * \param mpdu the packet to send
    * \param fragmentNumber the fragment index of the next fragment to send (starts at zero).
    *
    * \return the offset within the original packet where this fragment starts.
    */
-  uint32_t GetFragmentOffset (Mac48Address address, const WifiMacHeader *header,
-                              Ptr<const Packet> packet, uint32_t fragmentNumber);
+  uint32_t GetFragmentOffset (Ptr<const WifiMacQueueItem> mpdu, uint32_t fragmentNumber);
   /**
-   * \param address remote address
-   * \param header MAC header
-   * \param packet the packet to send
+   * \param mpdu the packet to send
    * \param fragmentNumber the fragment index of the next fragment to send (starts at zero).
    *
    * \return true if this is the last fragment, false otherwise.
    */
-  bool IsLastFragment (Mac48Address address, const WifiMacHeader *header,
-                       Ptr<const Packet> packet, uint32_t fragmentNumber);
+  bool IsLastFragment (Ptr<const WifiMacQueueItem> mpdu, uint32_t fragmentNumber);
 
   /**
    * \return the default transmission power
@@ -843,6 +865,16 @@ public:
    * \return information regarding the remote station associated with the given address
    */
   WifiRemoteStationInfo GetInfo (Mac48Address address);
+  /**
+   * \param address of the remote station
+   *
+   * \return the RSSI (in dBm) of the most recent packet received from the remote station (irrespective of TID)
+   *
+   * This method is typically used when the device needs
+   * to estimate the target UL RSSI info to put in the
+   * Trigger frame to send to the remote station.
+   */
+  double GetMostRecentRssi (Mac48Address address) const;
   /**
    * Set the default transmission power level
    *
@@ -858,13 +890,13 @@ public:
    */
   uint8_t GetMaxNumberOfTransmitStreams (void) const;
   /**
-   * \returns whether HT greenfield should be used for a given destination address.
+   * \returns whether LDPC should be used for a given destination address.
    *
    * \param dest the destination address
    *
-   * \return whether HT greenfield should be used for a given destination address
+   * \return whether LDPC should be used for a given destination address
    */
-  bool UseGreenfieldForDestination (Mac48Address dest) const;
+  bool UseLdpcForDestination (Mac48Address dest) const;
 
   /**
    * TracedCallback signature for power change events.
@@ -884,6 +916,19 @@ public:
    */
   typedef void (*RateChangeTracedCallback)(DataRate oldRate, DataRate newRate, Mac48Address remoteAddress);
 
+  /**
+   * Return the WifiPhy.
+   *
+   * \return a pointer to the WifiPhy
+   */
+  Ptr<WifiPhy> GetPhy (void) const;
+  /**
+   * Return the WifiMac.
+   *
+   * \return a pointer to the WifiMac
+   */
+  Ptr<WifiMac> GetMac (void) const;
+
 
 protected:
   virtual void DoDispose (void);
@@ -1017,15 +1062,6 @@ protected:
    *         false otherwise
    */
   bool GetAggregation (const WifiRemoteStation *station) const;
-  /**
-   * Return whether the station supports Greenfield or not.
-   *
-   * \param station the station being queried
-   *
-   * \return true if Greenfield is supported by the station,
-   *         false otherwise
-   */
-  bool GetGreenfield (const WifiRemoteStation *station) const;
 
   /**
    * Return the number of supported streams the station has.
@@ -1044,21 +1080,19 @@ protected:
    */
   uint8_t GetNess (const WifiRemoteStation *station) const;
 
-  /**
-   * Return the WifiPhy.
-   *
-   * \return a pointer to the WifiPhy
-   */
-  Ptr<WifiPhy> GetPhy (void) const;
-  /**
-   * Return the WifiMac.
-   *
-   * \return a pointer to the WifiMac
-   */
-  Ptr<WifiMac> GetMac (void) const;
-
 
 private:
+  /**
+   * If the given TXVECTOR is used for a MU transmission, return the STAID of
+   * the station with the given address if we are an AP or our own STAID if we
+   * are a STA associated with some AP. Otherwise, return SU_STA_ID.
+   *
+   * \param address the address of the station
+   * \param txVector the TXVECTOR used for a MU transmission
+   * \return the STA-ID of the station
+   */
+  uint16_t GetStaId (Mac48Address address, const WifiTxVector& txVector) const;
+
   /**
    * \param station the station that we need to communicate
    * \param size the size of the frame to send in bytes
@@ -1198,7 +1232,7 @@ private:
    * \param dataChannelWidth the channel width (in MHz) of the A-MPDU we sent
    * \param dataNss the number of spatial streams used to send the A-MPDU
    */
-  virtual void DoReportAmpduTxStatus (WifiRemoteStation *station, uint8_t nSuccessfulMpdus, uint8_t nFailedMpdus,
+  virtual void DoReportAmpduTxStatus (WifiRemoteStation *station, uint16_t nSuccessfulMpdus, uint16_t nFailedMpdus,
                                       double rxSnr, double dataSnr, uint16_t dataChannelWidth, uint8_t dataNss);
 
   /**
@@ -1233,12 +1267,11 @@ private:
   /**
    * Return the number of fragments needed for the given packet.
    *
-   * \param header MAC header
-   * \param packet the packet to be fragmented
+   * \param mpdu the packet to be fragmented
    *
    * \return the number of fragments needed
    */
-  uint32_t GetNFragments (const WifiMacHeader *header, Ptr<const Packet> packet);
+  uint32_t GetNFragments (Ptr<const WifiMacQueueItem> mpdu);
 
   /**
    * This is a pointer to the WifiPhy associated with this
@@ -1275,20 +1308,16 @@ private:
   WifiMode m_defaultTxMode; //!< The default transmission mode
   WifiMode m_defaultTxMcs;  //!< The default transmission modulation-coding scheme (MCS)
 
-  bool m_pcfSupported; //!< Flag if PCF capability is supported
   uint32_t m_maxSsrc;  //!< Maximum STA short retry count (SSRC)
   uint32_t m_maxSlrc;  //!< Maximum STA long retry count (SLRC)
   uint32_t m_rtsCtsThreshold;             //!< Threshold for RTS/CTS
   uint32_t m_fragmentationThreshold;      //!< Current threshold for fragmentation
-  uint32_t m_nextFragmentationThreshold;  //!< Threshold for fragmentation that will be used for the next transmission
   uint8_t m_defaultTxPowerLevel;          //!< Default transmission power level
   WifiMode m_nonUnicastMode;      //!< Transmission mode for non-unicast Data frames
   bool m_useNonErpProtection;     //!< flag if protection for non-ERP stations against ERP transmissions is enabled
   bool m_useNonHtProtection;      //!< flag if protection for non-HT stations against HT transmissions is enabled
-  bool m_useGreenfieldProtection; //!< flag if protection for stations that do not support HT Greenfield format is enabled
   bool m_shortPreambleEnabled;    //!< flag if short PHY preamble is enabled
   bool m_shortSlotTimeEnabled;    //!< flag if short slot time is enabled
-  bool m_rifsPermitted;           //!< flag if RIFS is enabled
   ProtectionMode m_erpProtectionMode; //!< Protection mode for ERP stations when non-ERP stations are detected
   ProtectionMode m_htProtectionMode;  //!< Protection mode for HT stations when non-HT stations are detected
 
