@@ -21,7 +21,6 @@
 
 #include "ns3/log.h"
 #include "yans-error-rate-model.h"
-#include "dsss-error-rate-model.h"
 #include "wifi-utils.h"
 #include "wifi-phy.h"
 
@@ -180,15 +179,20 @@ YansErrorRateModel::GetFecQamBer (double snr, uint64_t nbits,
 }
 
 double
-YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, double snr, uint64_t nbits) const
+YansErrorRateModel::DoGetChunkSuccessRate (WifiMode mode, const WifiTxVector& txVector, double snr, uint64_t nbits, uint8_t numRxAntennas, WifiPpduField field, uint16_t staId) const
 {
-  NS_LOG_FUNCTION (this << mode << txVector.GetMode () << snr << nbits);
-  if (mode.GetModulationClass () == WIFI_MOD_CLASS_ERP_OFDM
-      || mode.GetModulationClass () == WIFI_MOD_CLASS_OFDM
-      || mode.GetModulationClass () == WIFI_MOD_CLASS_HT
-      || mode.GetModulationClass () == WIFI_MOD_CLASS_VHT
-      || mode.GetModulationClass () == WIFI_MOD_CLASS_HE)
+  NS_LOG_FUNCTION (this << mode << txVector << snr << nbits << +numRxAntennas << field << staId);
+  if (mode.GetModulationClass () >= WIFI_MOD_CLASS_ERP_OFDM)
     {
+      uint64_t phyRate;
+      if ((txVector.IsMu () && (staId == SU_STA_ID)) || (mode != txVector.GetMode ()))
+        {
+          phyRate = mode.GetPhyRate (txVector.GetChannelWidth () >= 40 ? 20 : txVector.GetChannelWidth ()); //This is the PHY header
+        }
+      else
+        {
+          phyRate = mode.GetPhyRate (txVector, staId);
+        }
       if (mode.GetConstellationSize () == 2)
         {
           if (mode.GetCodeRate () == WIFI_CODE_RATE_1_2)
@@ -196,7 +200,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecBpskBer (snr,
                                     nbits,
                                     txVector.GetChannelWidth () * 1000000, //signal spread
-                                    mode.GetPhyRate (txVector), //PHY rate
+                                    phyRate, //PHY rate
                                     10, //dFree
                                     11); //adFree
             }
@@ -205,7 +209,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecBpskBer (snr,
                                     nbits,
                                     txVector.GetChannelWidth () * 1000000, //signal spread
-                                    mode.GetPhyRate (txVector), //PHY rate
+                                    phyRate, //PHY rate
                                     5, //dFree
                                     8); //adFree
             }
@@ -217,7 +221,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecQamBer (snr,
                                    nbits,
                                    txVector.GetChannelWidth () * 1000000, //signal spread
-                                   mode.GetPhyRate (txVector), //PHY rate
+                                   phyRate, //PHY rate
                                    4, //m
                                    10, //dFree
                                    11, //adFree
@@ -228,7 +232,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecQamBer (snr,
                                    nbits,
                                    txVector.GetChannelWidth () * 1000000, //signal spread
-                                   mode.GetPhyRate (txVector), //PHY rate
+                                   phyRate, //PHY rate
                                    4, //m
                                    5, //dFree
                                    8, //adFree
@@ -242,7 +246,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecQamBer (snr,
                                    nbits,
                                    txVector.GetChannelWidth () * 1000000, //signal spread
-                                   mode.GetPhyRate (txVector), //PHY rate
+                                   phyRate, //PHY rate
                                    16, //m
                                    10, //dFree
                                    11, //adFree
@@ -253,7 +257,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecQamBer (snr,
                                    nbits,
                                    txVector.GetChannelWidth () * 1000000, //signal spread
-                                   mode.GetPhyRate (txVector), //PHY rate
+                                   phyRate, //PHY rate
                                    16, //m
                                    5, //dFree
                                    8, //adFree
@@ -267,7 +271,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecQamBer (snr,
                                    nbits,
                                    txVector.GetChannelWidth () * 1000000, //signal spread
-                                   mode.GetPhyRate (txVector), //PHY rate
+                                   phyRate, //PHY rate
                                    64, //m
                                    6, //dFree
                                    1, //adFree
@@ -279,7 +283,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecQamBer (snr,
                                    nbits,
                                    txVector.GetChannelWidth () * 1000000, //signal spread
-                                   mode.GetPhyRate (txVector), //PHY rate
+                                   phyRate, //PHY rate
                                    64, //m
                                    4, //dFree
                                    14, //adFree
@@ -290,7 +294,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecQamBer (snr,
                                    nbits,
                                    txVector.GetChannelWidth () * 1000000, //signal spread
-                                   mode.GetPhyRate (txVector), //PHY rate
+                                   phyRate, //PHY rate
                                    64, //m
                                    5, //dFree
                                    8, //adFree
@@ -304,7 +308,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecQamBer (snr,
                                    nbits,
                                    txVector.GetChannelWidth () * 1000000, // signal spread
-                                   mode.GetPhyRate (txVector), //PHY rate
+                                   phyRate, //PHY rate
                                    256, // m
                                    4,  // dFree
                                    14,  // adFree
@@ -316,7 +320,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecQamBer (snr,
                                    nbits,
                                    txVector.GetChannelWidth () * 1000000, // signal spread
-                                   mode.GetPhyRate (txVector), //PHY rate
+                                   phyRate, //PHY rate
                                    256, // m
                                    5,  // dFree
                                    8,  // adFree
@@ -331,7 +335,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecQamBer (snr,
                                    nbits,
                                    txVector.GetChannelWidth () * 1000000, // signal spread
-                                   mode.GetPhyRate (txVector), //PHY rate
+                                   phyRate, //PHY rate
                                    1024, // m
                                    4,  // dFree
                                    14,  // adFree
@@ -343,7 +347,7 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
               return GetFecQamBer (snr,
                                    nbits,
                                    txVector.GetChannelWidth () * 1000000, // signal spread
-                                   mode.GetPhyRate (txVector), //PHY rate
+                                   phyRate, //PHY rate
                                    1024, // m
                                    5,  // dFree
                                    8,  // adFree
@@ -351,21 +355,32 @@ YansErrorRateModel::GetChunkSuccessRate (WifiMode mode, WifiTxVector txVector, d
                                    );
             }
         }
-    }
-  else if (mode.GetModulationClass () == WIFI_MOD_CLASS_DSSS || mode.GetModulationClass () == WIFI_MOD_CLASS_HR_DSSS)
-    {
-      switch (mode.GetDataRate (20))
+      else if (mode.GetConstellationSize () == 4096)
         {
-        case 1000000:
-          return DsssErrorRateModel::GetDsssDbpskSuccessRate (snr, nbits);
-        case 2000000:
-          return DsssErrorRateModel::GetDsssDqpskSuccessRate (snr, nbits);
-        case 5500000:
-          return DsssErrorRateModel::GetDsssDqpskCck5_5SuccessRate (snr, nbits);
-        case 11000000:
-          return DsssErrorRateModel::GetDsssDqpskCck11SuccessRate (snr, nbits);
-        default:
-          NS_ASSERT ("undefined DSSS/HR-DSSS datarate");
+          if (mode.GetCodeRate () == WIFI_CODE_RATE_5_6)
+            {
+              return GetFecQamBer (snr,
+                                   nbits,
+                                   txVector.GetChannelWidth () * 1000000, // signal spread
+                                   mode.GetPhyRate (txVector), //PHY rate
+                                   4096, // m
+                                   4,  // dFree
+                                   14,  // adFree
+                                   69  // adFreePlusOne
+                                   );
+            }
+          else
+            {
+              return GetFecQamBer (snr,
+                                   nbits,
+                                   txVector.GetChannelWidth () * 1000000, // signal spread
+                                   mode.GetPhyRate (txVector), //PHY rate
+                                   4096, // m
+                                   5,  // dFree
+                                   8,  // adFree
+                                   31  // adFreePlusOne
+                                   );
+            }
         }
     }
   return 0;
