@@ -54,9 +54,8 @@ public:
   YansWifiChannel ();
   virtual ~YansWifiChannel ();
 
-  //inherited from Channel.
-  virtual std::size_t GetNDevices (void) const;
-  virtual Ptr<NetDevice> GetDevice (std::size_t i) const;
+  std::size_t GetNDevices (void) const override;
+  Ptr<NetDevice> GetDevice (std::size_t i) const override;
 
   /**
    * Adds the given YansWifiPhy to the PHY list
