@@ -28,7 +28,6 @@
 namespace ns3 {
 
 class YansWifiChannel;
-class WifiPpdu;
 
 /**
  * \brief 802.11 PHY layer model
@@ -58,8 +57,10 @@ public:
   virtual ~YansWifiPhy ();
 
   // Implementation of pure virtual method.
-  void StartTx (Ptr<WifiPpdu> ppdu);
-  virtual Ptr<Channel> GetChannel (void) const;
+  void StartTx (Ptr<WifiPpdu> ppdu) override;
+  Ptr<Channel> GetChannel (void) const override;
+  uint16_t GetGuardBandwidth (uint16_t currentChannelWidth) const override;
+  std::tuple<double, double, double> GetTxMaskRejectionParams (void) const override;
 
   /**
    * Set the YansWifiChannel this YansWifiPhy is to be connected to.
@@ -69,8 +70,7 @@ public:
   void SetChannel (const Ptr<YansWifiChannel> channel);
 
 protected:
-  // Inherited
-  virtual void DoDispose (void);
+  void DoDispose (void) override;
 
 
 private:
