@@ -26,6 +26,9 @@
 #include "ns3/constant-position-mobility-model.h"
 #include "ns3/simulator.h"
 #include "ns3/test.h"
+#include "ns3/frame-exchange-manager.h"
+#include "ns3/wifi-default-protection-manager.h"
+#include "ns3/wifi-default-ack-manager.h"
 
 using namespace ns3;
 
@@ -40,7 +43,7 @@ class PowerRateAdaptationTest : public TestCase
 public:
   PowerRateAdaptationTest ();
 
-  virtual void DoRun (void);
+  void DoRun (void) override;
 private:
   /// Test parf function
   void TestParf ();
@@ -76,7 +79,16 @@ PowerRateAdaptationTest::ConfigureNode ()
   Ptr<WifiNetDevice> dev = CreateObject<WifiNetDevice> ();
   Ptr<AdhocWifiMac> mac = CreateObject<AdhocWifiMac> ();
   mac->SetDevice (dev);
-  mac->ConfigureStandard (WIFI_PHY_STANDARD_80211a);
+  mac->ConfigureStandard (WIFI_STANDARD_80211a);
+  Ptr<FrameExchangeManager> fem = mac->GetFrameExchangeManager ();
+
+  Ptr<WifiProtectionManager> protectionManager = CreateObject<WifiDefaultProtectionManager> ();
+  protectionManager->SetWifiMac (mac);
+  fem->SetProtectionManager (protectionManager);
+
+  Ptr<WifiAckManager> ackManager = CreateObject<WifiDefaultAckManager> ();
+  ackManager->SetWifiMac (mac);
+  fem->SetAckManager (ackManager);
 
   /*
    * Create mobility model. Is needed by the phy layer for transmission.
@@ -90,7 +102,7 @@ PowerRateAdaptationTest::ConfigureNode ()
   phy->SetChannel (channel);
   phy->SetDevice (dev);
   phy->SetMobility (mobility);
-  phy->ConfigureStandard (WIFI_PHY_STANDARD_80211a);
+  phy->ConfigureStandardAndBand (WIFI_PHY_STANDARD_80211a, WIFI_PHY_BAND_5GHZ);
 
   /*
    * Configure power control parameters.
@@ -140,6 +152,7 @@ PowerRateAdaptationTest::TestParf ()
   packetHeader.SetType (WIFI_MAC_DATA);
   packetHeader.SetQosTid (0);
   Ptr<Packet> packet = Create<Packet> (10);
+  Ptr<WifiMacQueueItem> mpdu = Create<WifiMacQueueItem> (packet, packetHeader);
   WifiMode ackMode;
 
   /*
@@ -168,7 +181,7 @@ PowerRateAdaptationTest::TestParf ()
    */
   for (int i = 0; i < 10; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -184,7 +197,7 @@ PowerRateAdaptationTest::TestParf ()
    * As we are using recovery power, one failure make power increase.
    *
    */
-  manager->ReportDataFailed (remoteAddress, &packetHeader, packet->GetSize ());
+  manager->ReportDataFailed (mpdu);
 
   txVector = manager->GetDataTxVector (packetHeader);
   mode = txVector.GetMode ();
@@ -201,10 +214,10 @@ PowerRateAdaptationTest::TestParf ()
    */
   for (int i = 0; i < 7; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
-      manager->ReportDataFailed (remoteAddress, &packetHeader, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
+      manager->ReportDataFailed (mpdu);
     }
-  manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+  manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
 
   txVector = manager->GetDataTxVector (packetHeader);
   mode = txVector.GetMode ();
@@ -219,7 +232,7 @@ PowerRateAdaptationTest::TestParf ()
    * As we are using recovery power, one failure make power increase. recoveryPower=false.
    */
 
-  manager->ReportDataFailed (remoteAddress, &packetHeader, packet->GetSize ());
+  manager->ReportDataFailed (mpdu);
 
   txVector = manager->GetDataTxVector (packetHeader);
   mode = txVector.GetMode ();
@@ -234,8 +247,8 @@ PowerRateAdaptationTest::TestParf ()
    * After two consecutive fails the rate is decreased or the power increased.
    * As we are at maximal power, the rate should be decreased.
    */
-  manager->ReportDataFailed (remoteAddress, &packetHeader, packet->GetSize ());
-  manager->ReportDataFailed (remoteAddress, &packetHeader, packet->GetSize ());
+  manager->ReportDataFailed (mpdu);
+  manager->ReportDataFailed (mpdu);
 
   txVector = manager->GetDataTxVector (packetHeader);
   mode = txVector.GetMode ();
@@ -252,7 +265,7 @@ PowerRateAdaptationTest::TestParf ()
    */
   for (int i = 0; i < 10; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -268,7 +281,7 @@ PowerRateAdaptationTest::TestParf ()
    * As we are using recovery rate, one failure make rate decrease. recoveryRate=false.
    */
 
-  manager->ReportDataFailed (remoteAddress, &packetHeader, packet->GetSize ());
+  manager->ReportDataFailed (mpdu);
 
   txVector = manager->GetDataTxVector (packetHeader);
   mode = txVector.GetMode ();
@@ -285,7 +298,7 @@ PowerRateAdaptationTest::TestParf ()
    */
   for (int i = 0; i < 10; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -303,7 +316,7 @@ PowerRateAdaptationTest::TestParf ()
    */
   for (int i = 0; i < 10; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -319,11 +332,11 @@ PowerRateAdaptationTest::TestParf ()
    * One successful transmissions after a power decrease make recoverPower=false.
    * So we need two consecutive failures to increase power again.
    */
-  manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+  manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
 
   for (int i = 0; i < 2; i++)
     {
-      manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+      manager->ReportDataFailed (mpdu);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -361,6 +374,7 @@ PowerRateAdaptationTest::TestAparf ()
   packetHeader.SetType (WIFI_MAC_DATA);
   packetHeader.SetQosTid (0);
   Ptr<Packet> packet = Create<Packet> (10);
+  Ptr<WifiMacQueueItem> mpdu = Create<WifiMacQueueItem> (packet, packetHeader);
   WifiMode ackMode;
 
   /*
@@ -390,7 +404,7 @@ PowerRateAdaptationTest::TestAparf ()
    */
   for (int i = 0; i < 3; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -406,7 +420,7 @@ PowerRateAdaptationTest::TestAparf ()
    * One failure make the power to be increased again.
    * Change to state Low.
    */
-  manager->ReportDataFailed (remoteAddress, &packetHeader, packet->GetSize ());
+  manager->ReportDataFailed (mpdu);
 
   txVector = manager->GetDataTxVector (packetHeader);
   mode = txVector.GetMode ();
@@ -424,7 +438,7 @@ PowerRateAdaptationTest::TestAparf ()
    */
   for (int i = 0; i < 10; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -443,7 +457,7 @@ PowerRateAdaptationTest::TestAparf ()
 
   for (int i = 0; i < 3; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -461,7 +475,7 @@ PowerRateAdaptationTest::TestAparf ()
    */
   for (int i = 0; i < 16 * 3; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -477,7 +491,7 @@ PowerRateAdaptationTest::TestAparf ()
    * After one fail the rate is decreased or the power increased.
    * As we are at minimal power, the power should be increased.
    */
-  manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+  manager->ReportDataFailed (mpdu);
 
   txVector = manager->GetDataTxVector (packetHeader);
   mode = txVector.GetMode ();
@@ -494,7 +508,7 @@ PowerRateAdaptationTest::TestAparf ()
    */
   for (int i = 0; i < 16; i++)
     {
-      manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+      manager->ReportDataFailed (mpdu);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -511,7 +525,7 @@ PowerRateAdaptationTest::TestAparf ()
    * As we are at maximal power, the rate should be decreased.
    * Set critical rate to 54 Mbps.
    */
-  manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+  manager->ReportDataFailed (mpdu);
 
   txVector = manager->GetDataTxVector (packetHeader);
   mode = txVector.GetMode ();
@@ -528,7 +542,7 @@ PowerRateAdaptationTest::TestAparf ()
    */
   for (int i = 0; i < 3; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -548,7 +562,7 @@ PowerRateAdaptationTest::TestAparf ()
    */
   for (int i = 0; i < 9 * 3; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -560,7 +574,7 @@ PowerRateAdaptationTest::TestAparf ()
 
   for (int i = 0; i < 3; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -604,6 +618,7 @@ PowerRateAdaptationTest::TestRrpaa ()
   packetHeader.SetType (WIFI_MAC_DATA);
   packetHeader.SetQosTid (0);
   Ptr<Packet> packet = Create<Packet> (10);
+  Ptr<WifiMacQueueItem> mpdu = Create<WifiMacQueueItem> (packet, packetHeader);
   WifiMode ackMode;
 
   /*
@@ -662,7 +677,7 @@ PowerRateAdaptationTest::TestRrpaa ()
    */
   for (int i = 0; i < 6; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -675,7 +690,7 @@ PowerRateAdaptationTest::TestRrpaa ()
   /**
    * Test that 7 is enough.
    */
-  manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+  manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
 
   txVector = manager->GetDataTxVector (packetHeader);
   mode = txVector.GetMode ();
@@ -692,7 +707,7 @@ PowerRateAdaptationTest::TestRrpaa ()
    */
   for (int i = 0; i < 4; i++)
     {
-      manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+      manager->ReportDataFailed (mpdu);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -702,7 +717,7 @@ PowerRateAdaptationTest::TestRrpaa ()
   NS_TEST_ASSERT_MSG_EQ (mode.GetDataRate (txVector.GetChannelWidth (), txVector.GetGuardInterval (), 1), 9000000, "RRPAA: Incorrect vale of data rate");
   NS_TEST_ASSERT_MSG_EQ (power, 17, "RRPAA: Incorrect value of power level");
 
-  manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+  manager->ReportDataFailed (mpdu);
 
   txVector = manager->GetDataTxVector (packetHeader);
   mode = txVector.GetMode ();
@@ -719,7 +734,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 7; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -731,7 +746,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 10; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -743,7 +758,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 13; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -755,7 +770,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 19; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -767,7 +782,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 23; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -779,7 +794,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 33; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -791,7 +806,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 43; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -811,7 +826,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 49; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -821,7 +836,7 @@ PowerRateAdaptationTest::TestRrpaa ()
   NS_TEST_ASSERT_MSG_EQ (mode.GetDataRate (txVector.GetChannelWidth (), txVector.GetGuardInterval (), 1), 54000000, "RRPAA: Incorrect vale of data rate");
   NS_TEST_ASSERT_MSG_EQ (power, 17, "RRPAA: Incorrect value of power level");
 
-  manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+  manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
 
   txVector = manager->GetDataTxVector (packetHeader);
   mode = txVector.GetMode ();
@@ -839,7 +854,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 16 * 50; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -857,7 +872,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 6; i++)
     {
-      manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+      manager->ReportDataFailed (mpdu);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -875,7 +890,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 16 * 6; i++)
     {
-      manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+      manager->ReportDataFailed (mpdu);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -893,7 +908,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 6; i++)
     {
-      manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+      manager->ReportDataFailed (mpdu);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -909,7 +924,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 11; i++)
     {
-      manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+      manager->ReportDataFailed (mpdu);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -929,7 +944,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 25; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -941,7 +956,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 5; i++)
     {
-      manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+      manager->ReportDataFailed (mpdu);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -953,7 +968,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 5; i++)
     {
-      manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+      manager->ReportDataFailed (mpdu);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -965,7 +980,7 @@ PowerRateAdaptationTest::TestRrpaa ()
 
   for (int i = 0; i < 25; i++)
     {
-      manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+      manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
     }
 
   txVector = manager->GetDataTxVector (packetHeader);
@@ -985,12 +1000,12 @@ PowerRateAdaptationTest::TestRrpaa ()
     {
       for (int j = 0; j < 25; j++)
         {
-          manager->ReportDataOk (remoteAddress, &packetHeader, 0, ackMode, 0, txVector, packet->GetSize ());
+          manager->ReportDataOk (mpdu, 0, ackMode, 0, txVector);
         }
 
       for (int j = 0; j < 5; j++)
         {
-          manager->ReportDataFailed (remoteAddress,&packetHeader, packet->GetSize ());
+          manager->ReportDataFailed (mpdu);
         }
     }
 
