@@ -342,6 +342,27 @@ public:
    */
   void SetServiceFlowManager (Ptr<SsServiceFlowManager> sfm);
 
+  /// Callback for logging packets on ASCII traces
+  typedef Callback<void, std::string, Ptr<const Packet> > AsciiTraceCallback;
+
+  /**
+   * Set the Enqueue callback for ASCII tracing
+   * \param cb callback for ASCII tracing
+   */
+  void SetAsciiTxQueueEnqueueCallback (AsciiTraceCallback cb);
+
+  /**
+   * Set the Dequeue callback for ASCII tracing
+   * \param cb callback for ASCII tracing
+   */
+  void SetAsciiTxQueueDequeueCallback (AsciiTraceCallback cb);
+
+  /**
+   * Set the Drop callback for ASCII tracing
+   * \param cb callback for ASCII tracing
+   */
+  void SetAsciiTxQueueDropCallback (AsciiTraceCallback cb);
+
 private:
   /**
    * Get default lost DL map interval
@@ -483,6 +504,13 @@ private:
    * \see class CallBackTraceSource
    */
   TracedCallback<Ptr<const Packet> > m_ssRxDropTrace;
+
+  /// Bound callback to perform ASCII logging for Enqueue events
+  AsciiTraceCallback m_asciiTxQueueEnqueueCb;
+  /// Bound callback to perform ASCII logging for Dequeue events
+  AsciiTraceCallback m_asciiTxQueueDequeueCb;
+  /// Bound callback to perform ASCII logging for Drop events
+  AsciiTraceCallback m_asciiTxQueueDropCb;
 };
 
 } // namespace ns3
