@@ -1511,6 +1511,7 @@ PrintAttributeImplementations (std::ostream & os)
       { "Address",        "Address",        true,  "address.h"          },
       { "Box",            "Box",            true,  "box.h"              },
       { "DataRate",       "DataRate",       true,  "data-rate.h"        },
+      { "Length",         "Length",         true,  "length.h"           },
       { "IeMeshId",       "IeMeshId",       true,  "ie-dot11s-id.h"     },
       { "Ipv4Address",    "Ipv4Address",    true,  "ipv4-address.h"     },
       { "Ipv4Mask",       "Ipv4Mask",       true,  "ipv4-address.h"     },
@@ -1570,7 +1571,14 @@ PrintAttributeImplementations (std::ostream & os)
   PrintAttributeValueSection  (os, "ObjectMap", false);
   PrintMakeAccessors          (os, "ObjectMap");
   PrintMakeChecker            (os, "ObjectMap", "object-map.h");
+
+  PrintAttributeValueSection  (os, "Pair", false);
+  PrintAttributeValueWithName (os, "Pair", "std::pair<A, B>", "pair.h");
+  PrintMakeChecker            (os, "Pair",  "pair.h");
   
+  PrintAttributeValueSection  (os, "AttributeContainer", false);
+  PrintAttributeValueWithName (os, "AttributeContainer", "AttributeContainer", "attribute-container.h");
+  PrintMakeChecker            (os, "AttributeContainer",  "attribute-container.h");
 }  // PrintAttributeImplementations ()
 
 
