@@ -178,6 +178,10 @@ def get_run_program(program_string, command_template=None):
         argv = shlex.split(program_string)
         #print "%r ==shlex.split==> %r" % (program_string, argv)
         program_name = argv[0]
+        
+        # if the script name ends with .cc - strip it
+        if program_name.endswith('.cc'):
+            program_name = program_name.rsplit('.', 1)[0]
 
         try:
             program_obj = find_program(program_name, env)
@@ -195,6 +199,11 @@ def get_run_program(program_string, command_template=None):
     else:
 
         program_name = program_string
+        
+        # if the script name ends with .cc - strip it
+        if program_name.endswith('.cc'):
+            program_name = program_name.rsplit('.', 1)[0]
+
         try:
             program_obj = find_program(program_name, env)
         except ValueError as ex:
