@@ -4,7 +4,7 @@ import sys
 
 import pybindgen
 from pybindgen import FileCodeSink
-from pybindgen.gccxmlparser import ModuleParser
+from pybindgen.castxmlparser import ModuleParser
 
 def my_module_gen():
     module_parser = ModuleParser('a1', '::')
