@@ -8,6 +8,7 @@
 #include <sstream>
 #include <vector>
 #include <map>
+#include <unordered_map>
 #include <set>
 #include <exception>
 #include <algorithm>
@@ -651,7 +652,7 @@ public:
             return new AbstractBaseClassImpl;
         }
 
-    // This method will be scanned by gccxmlparser and generate an error
+    // This method will be scanned by castxmlparser and generate an error
     // that is only detected in code generation time.
     // -#- @return(caller_owns_return=false) -#-
     static AbstractBaseClass* get_abstract_base_class_ptr2 ()
@@ -675,7 +676,7 @@ inline AbstractBaseClass* get_abstract_base_class_ptr1 ()
     return AbstractBaseClassImpl::get_abstract_base_class_ptr1 ();
 }
 
-// This function will be scanned by gccxmlparser and generate an error
+// This function will be scanned by castxmlparser and generate an error
 // that is only detected in code generation time.
 // -#- @return(caller_owns_return=false) -#-
 inline AbstractBaseClass* get_abstract_base_class_ptr2 ()
@@ -806,6 +807,7 @@ struct simple_struct_t
 typedef std::vector<simple_struct_t> SimpleStructList;
 typedef std::vector<simple_struct_t> SimpleStructVec;
 typedef std::map<std::string, simple_struct_t> SimpleStructMap;
+typedef std::unordered_map<std::string, simple_struct_t> SimpleStructUnorderedMap;
 
 
 SimpleStructList get_simple_list ();
@@ -838,6 +840,9 @@ public:
     virtual SimpleStructMap get_simple_map ();
     virtual int set_simple_map (SimpleStructMap map);
 
+    virtual SimpleStructUnorderedMap get_simple_unordered_map ();
+    virtual int set_simple_unordered_map (SimpleStructUnorderedMap map);
+
     // -#- @outVec(direction=out) -#-
     void get_vec (std::vector<std::string> &outVec);
 
@@ -850,6 +855,7 @@ public:
 private:
     SimpleStructList m_simpleList;
     SimpleStructMap m_simpleMap;
+    SimpleStructUnorderedMap m_simpleUnorderedMap;
 
     std::vector<std::string> *m_vec;
 
@@ -1393,4 +1399,10 @@ ToBeFreed *return_class_to_be_freed(int size);
 // -#- name=return_class_to_not_be_freed; @return(free_after_copy=false) -#-
 ToBeFreed *return_class_to_not_be_freed(int size);
 
+
+void Add (const std::string filePath,
+          double defaultZ = 0,
+          char delimiter = ',');
+
+
 #endif 	    /* !FOO_H_ */
